@@ -6,13 +6,23 @@
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://www.hdfgroup.org/licenses.               *
+ * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
+#ifdef OLD_HEADER_FILENAME
+#include <iostream.h>
+#else
+#include <iostream>
+#endif
 #include <string>
 
+using std::cerr;
+using std::endl;
+
+//#include <string>
+
 #include "H5Include.h"
 #include "H5Exception.h"
 #include "H5IdComponent.h"
@@ -27,7 +37,7 @@ namespace H5 {
 // in "H5PredType.cpp" for information.
 
 // Initialize a pointer for the constant
-FileAccPropList *FileAccPropList::DEFAULT_ = 0;
+FileAccPropList* FileAccPropList::DEFAULT_ = 0;
 
 //--------------------------------------------------------------------------
 // Function:    FileAccPropList::getConstant
@@ -40,13 +50,13 @@ FileAccPropList *FileAccPropList::DEFAULT_ = 0;
 //              happen.
 // Programmer   Binh-Minh Ribler - 2015
 //--------------------------------------------------------------------------
-FileAccPropList *
-FileAccPropList::getConstant()
+FileAccPropList* FileAccPropList::getConstant()
 {
     // Tell the C library not to clean up, H5Library::termH5cpp will call
     // H5close - more dependency if use H5Library::dontAtExit()
-    if (!IdComponent::H5dontAtexit_called) {
-        (void)H5dont_atexit();
+    if (!IdComponent::H5dontAtexit_called)
+    {
+        (void) H5dont_atexit();
         IdComponent::H5dontAtexit_called = true;
     }
 
@@ -55,73 +65,65 @@ FileAccPropList::getConstant()
     if (DEFAULT_ == 0)
         DEFAULT_ = new FileAccPropList(H5P_FILE_ACCESS);
     else
-        throw PropListIException("FileAccPropList::getConstant",
-                                 "FileAccPropList::getConstant is being invoked on an allocated DEFAULT_");
-    return (DEFAULT_);
+        throw PropListIException("FileAccPropList::getConstant", "FileAccPropList::getConstant is being invoked on an allocated DEFAULT_");
+    return(DEFAULT_);
 }
 
 //--------------------------------------------------------------------------
 // Function:    FileAccPropList::deleteConstants
-// Purpose:     Deletes the constant object that FileAccPropList::DEFAULT_
+// Purpose     Deletes the constant object that FileAccPropList::DEFAULT_
 //              points to.
 // exception    H5::PropListIException
 // Programmer   Binh-Minh Ribler - 2015
 //--------------------------------------------------------------------------
-void
-FileAccPropList::deleteConstants()
+void FileAccPropList::deleteConstants()
 {
     if (DEFAULT_ != 0)
         delete DEFAULT_;
 }
 
 //--------------------------------------------------------------------------
-// Purpose:     Constant for default property
+// Purpose     Constant for default property
 //--------------------------------------------------------------------------
-const FileAccPropList &FileAccPropList::DEFAULT = *getConstant();
+const FileAccPropList& FileAccPropList::DEFAULT = *getConstant();
 
 #endif // DOXYGEN_SHOULD_SKIP_THIS
 
 //--------------------------------------------------------------------------
 // Function:    Default Constructor
 ///\brief       Creates a file access property list
-// Programmer:  Binh-Minh Ribler - 2000
+// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-FileAccPropList::FileAccPropList() : PropList(H5P_FILE_ACCESS)
-{
-}
+FileAccPropList::FileAccPropList() : PropList(H5P_FILE_ACCESS) {}
 
 //--------------------------------------------------------------------------
 // Function:    FileAccPropList copy constructor
-///\brief       Copy Constructor: makes a copy of the original
+///\brief       Copy constructor: same HDF5 object as \a original
 ///\param       original - IN: FileAccPropList instance to copy
-// Programmer:  Binh-Minh Ribler - 2000
+// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-FileAccPropList::FileAccPropList(const FileAccPropList &original) : PropList(original)
-{
-}
+FileAccPropList::FileAccPropList(const FileAccPropList& original) : PropList(original) {}
 
 //--------------------------------------------------------------------------
 // Function:    FileAccPropList overloaded constructor
 ///\brief       Creates a file access property list using the id of an
 ///             existing one.
-// Programmer:  Binh-Minh Ribler - 2000
+// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-FileAccPropList::FileAccPropList(const hid_t plist_id) : PropList(plist_id)
-{
-}
+FileAccPropList::FileAccPropList(const hid_t plist_id) : PropList(plist_id) {}
 
 //--------------------------------------------------------------------------
 // Function:    FileAccPropList::setStdio
 ///\brief       Modifies this property list to use the \c H5FD_STDIO driver.
 ///
 ///\exception   H5::PropListIException
-// Programmer:  Binh-Minh Ribler - April, 2004
+// Programmer   Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
-void
-FileAccPropList::setStdio() const
+void FileAccPropList::setStdio() const
 {
     herr_t ret_value = H5Pset_fapl_stdio(id);
-    if (ret_value < 0) {
+    if (ret_value < 0)
+    {
         throw PropListIException("FileAccPropList::setStdio", "H5Pset_fapl_stdio failed");
     }
 }
@@ -132,19 +134,19 @@ FileAccPropList::setStdio() const
 ///\return      A low-level driver ID which is the same ID used when the
 ///             driver was set for the property list.  The driver ID is
 ///             only valid as long as the file driver remains registered.
-///             Valid driver identifiers can be found at:
-/// https://support.hdfgroup.org/HDF5/doc/RM/RM_H5P.html#Property-GetDriver
+///             For detail on valid driver identifiers, please refer to the
+///             H5Pget_driver API in the HDF5 C Reference Manual.
 ///\exception   H5::PropListIException
-// Programmer:  Binh-Minh Ribler - April, 2004
+// Programmer   Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
-hid_t
-FileAccPropList::getDriver() const
+hid_t FileAccPropList::getDriver() const
 {
     hid_t driver = H5Pget_driver(id);
-    if (driver < 0) {
+    if (driver < 0)
+    {
         throw PropListIException("FileAccPropList::getDriver", "H5Pget_driver failed");
     }
-    return (driver);
+   return(driver);
 }
 
 //--------------------------------------------------------------------------
@@ -154,16 +156,15 @@ FileAccPropList::getDriver() const
 ///\param       new_driver_info - IN: Struct containing the driver-specific properites
 ///\exception   H5::PropListIException
 ///\par Description
-///             For a list of valid driver identifiers, please see the C
-///             layer Reference Manual at:
-/// https://support.hdfgroup.org/HDF5/doc/RM/RM_H5P.html#Property-SetDriver
-// Programmer:  Binh-Minh Ribler - April, 2004
+///             For information, please refer to the H5Pset_driver API in
+///             the HDF5 C Reference Manual.
+// Programmer   Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
-void
-FileAccPropList::setDriver(hid_t new_driver_id, const void *new_driver_info) const
+void FileAccPropList::setDriver(hid_t new_driver_id, const void *new_driver_info) const
 {
     herr_t ret_value = H5Pset_driver(id, new_driver_id, new_driver_info);
-    if (ret_value < 0) {
+    if (ret_value < 0)
+    {
         throw PropListIException("FileAccPropList::setDriver", "H5Pset_driver failed");
     }
 }
@@ -173,13 +174,13 @@ FileAccPropList::setDriver(hid_t new_driver_id, const void *new_driver_info) con
 ///\brief       Sets offset for family driver.
 ///\param       offset - IN: offset value
 ///\exception   H5::PropListIException
-// Programmer:  Binh-Minh Ribler - April, 2004
+// Programmer   Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
-void
-FileAccPropList::setFamilyOffset(hsize_t offset) const
+void FileAccPropList::setFamilyOffset(hsize_t offset) const
 {
     herr_t ret_value = H5Pset_family_offset(id, offset);
-    if (ret_value < 0) {
+    if (ret_value < 0)
+    {
         throw PropListIException("FileAccPropList::setFamilyOffset", "H5Pset_family_offset failed");
     }
 }
@@ -189,17 +190,17 @@ FileAccPropList::setFamilyOffset(hsize_t offset) const
 ///\brief       Get offset for family driver.
 ///\return      Offset for family driver
 ///\exception   H5::PropListIException
-// Programmer:  Binh-Minh Ribler - April, 2004
+// Programmer   Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
-hsize_t
-FileAccPropList::getFamilyOffset() const
+hsize_t FileAccPropList::getFamilyOffset() const
 {
     hsize_t offset;
-    herr_t  ret_value = H5Pget_family_offset(id, &offset);
-    if (ret_value < 0) {
+    herr_t ret_value = H5Pget_family_offset(id, &offset);
+    if (ret_value < 0)
+    {
         throw PropListIException("FileAccPropList::getFamilyOffset", "H5Pget_family_offset failed");
     }
-    return (offset);
+   return(offset);
 }
 
 //--------------------------------------------------------------------------
@@ -209,20 +210,19 @@ FileAccPropList::getFamilyOffset() const
 ///\param       increment - IN: Specifies how much memory to increase each
 ///                             time more memory is needed, in bytes
 ///\param       backing_store - IN: Indicating whether to write the file
-///                             contents to disk when the file is closed
+///                                 contents to disk when the file is closed
 ///\exception   H5::PropListIException
 ///\par Description
 ///             For more details on the use of \c H5FD_CORE driver, please
-///             refer to
-/// https://support.hdfgroup.org/HDF5/doc/RM/RM_H5P.html#Property-SetFaplCore
-// Programmer:  Binh-Minh Ribler - April, 2004
+///             refer to the H5Pset_fapl_core API in the HDF5 C Reference Manual.
+// Programmer   Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
-void
-FileAccPropList::setCore(size_t increment, hbool_t backing_store) const
+void FileAccPropList::setCore (size_t increment, hbool_t backing_store) const
 {
-    herr_t ret_value = H5Pset_fapl_core(id, increment, backing_store);
-    if (ret_value < 0) {
-        throw PropListIException("FileAccPropList::setCore", "H5Pset_fapl_core failed");
+    herr_t ret_value = H5Pset_fapl_core (id, increment, backing_store);
+    if (ret_value < 0)
+    {
+        throw PropListIException ("FileAccPropList::setCore", "H5Pset_fapl_core failed");
     }
 }
 
@@ -231,15 +231,15 @@ FileAccPropList::setCore(size_t increment, hbool_t backing_store) const
 ///\brief       Queries core file driver properties.
 ///\param       increment - OUT: Size of memory increment, in bytes
 ///\param       backing_store - OUT: Indicating whether to write the file
-///                             contents to disk when the file is closed
+///                                  contents to disk when the file is closed
 ///\exception   H5::PropListIException
-// Programmer:  Binh-Minh Ribler - April, 2004
+// Programmer   Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
-void
-FileAccPropList::getCore(size_t &increment, hbool_t &backing_store) const
+void FileAccPropList::getCore (size_t& increment, hbool_t& backing_store) const
 {
     herr_t ret_value = H5Pget_fapl_core(id, &increment, &backing_store);
-    if (ret_value < 0) {
+    if (ret_value < 0)
+    {
         throw PropListIException("FileAccPropList::getCore", "H5Pget_fapl_core failed");
     }
 }
@@ -249,17 +249,17 @@ FileAccPropList::getCore(size_t &increment, hbool_t &backing_store) const
 ///\brief       Sets this file access property list to use the family driver.
 ///\param       memb_size  - IN: Size in bytes of each file member
 ///\param       memb_plist - IN: File access property list to be used for
-///                                     each family member
+///                              each family member
 ///\exception   H5::PropListIException
 ///\par Description
 ///             Note that \a memb_size is used only when creating a new file.
-// Programmer:  Binh-Minh Ribler - April, 2004
+// Programmer   Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
-void
-FileAccPropList::setFamily(hsize_t memb_size, const FileAccPropList &memb_plist) const
+void FileAccPropList::setFamily(hsize_t memb_size, const FileAccPropList& memb_plist) const
 {
-    herr_t ret_value = H5Pset_fapl_family(id, memb_size, memb_plist.getId());
-    if (ret_value < 0) {
+    herr_t ret_value = H5Pset_fapl_family (id, memb_size, memb_plist.getId());
+    if (ret_value < 0)
+    {
         throw PropListIException("FileAccPropList::setFamily", "H5Pset_fapl_family failed");
     }
 }
@@ -272,14 +272,14 @@ FileAccPropList::setFamily(hsize_t memb_size, const FileAccPropList &memb_plist)
 ///\param       memb_plist - OUT: Retrieved file access property list for each
 ///                               file member
 ///\exception   H5::PropListIException
-// Programmer:  Binh-Minh Ribler - April, 2004
+// Programmer   Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
-void
-FileAccPropList::getFamily(hsize_t &memb_size, FileAccPropList &memb_plist) const
+void FileAccPropList::getFamily(hsize_t& memb_size, FileAccPropList& memb_plist) const
 {
-    hid_t  memb_plist_id;
+    hid_t memb_plist_id;
     herr_t ret_value = H5Pget_fapl_family(id, &memb_size, &memb_plist_id);
-    if (ret_value < 0) {
+    if (ret_value < 0)
+    {
         throw PropListIException("FileAccPropList::getFamily", "H5Pget_fapl_family failed");
     }
     memb_plist.p_setId(memb_plist_id);
@@ -293,18 +293,18 @@ FileAccPropList::getFamily(hsize_t &memb_size, FileAccPropList &memb_plist) cons
 ///\param       memb_size  - OUT: Size in bytes of each file member
 ///\return      The file access property list for each file member
 ///\exception   H5::PropListIException
-// Programmer:  Binh-Minh Ribler - April, 2004
+// Programmer   Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
-FileAccPropList
-FileAccPropList::getFamily(hsize_t &memb_size) const
+FileAccPropList FileAccPropList::getFamily(hsize_t& memb_size) const
 {
-    hid_t  memb_plist_id;
+    hid_t memb_plist_id;
     herr_t ret_value = H5Pget_fapl_family(id, &memb_size, &memb_plist_id);
-    if (ret_value < 0) {
+    if (ret_value < 0)
+    {
         throw PropListIException("FileAccPropList::getFamily", "H5Pget_fapl_family failed");
     }
     FileAccPropList memb_plist(memb_plist_id);
-    return (memb_plist);
+    return(memb_plist);
 }
 
 //--------------------------------------------------------------------------
@@ -317,20 +317,17 @@ FileAccPropList::getFamily(hsize_t &memb_size) const
 ///\param       raw_ext     - IN: Raw data filename extension as \c char*
 ///\exception   H5::PropListIException
 ///\par Description
-///             Temporary - For information, please refer to:
-/// https://support.hdfgroup.org/HDF5/doc/RM/RM_H5P.html#Property-SetFaplSplit
-// Programmer:  Binh-Minh Ribler - April, 2004
-// Modification
-//              Replaced the version without const parameter - Apr, 2014
+///             For information, please refer to the H5Pset_fapl_split API in
+///             the HDF5 C Reference Manual.
+// Programmer   Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
-void
-FileAccPropList::setSplit(const FileAccPropList &meta_plist, const FileAccPropList &raw_plist,
-                          const char *meta_ext, const char *raw_ext) const
+void FileAccPropList::setSplit(const FileAccPropList& meta_plist, const FileAccPropList& raw_plist, const char* meta_ext, const char* raw_ext) const
 {
-    hid_t  meta_pid  = meta_plist.getId();
-    hid_t  raw_pid   = raw_plist.getId();
+    hid_t meta_pid = meta_plist.getId();
+    hid_t raw_pid = raw_plist.getId();
     herr_t ret_value = H5Pset_fapl_split(id, meta_ext, meta_pid, raw_ext, raw_pid);
-    if (ret_value < 0) {
+    if (ret_value < 0)
+    {
         throw PropListIException("FileAccPropList::setSplit", "H5Pset_fapl_split failed");
     }
 }
@@ -344,13 +341,9 @@ FileAccPropList::setSplit(const FileAccPropList &meta_plist, const FileAccPropLi
 ///\param       meta_ext    - IN: Metadata filename extension as \c H5std_string
 ///\param       raw_ext     - IN: Raw data filename extension as \c H5std_string
 ///\exception   H5::PropListIException
-// Programmer:  Binh-Minh Ribler - April, 2004
-// Modification
-//              Replaced the version without const parameter - Apr, 2014
+// Programmer   Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
-void
-FileAccPropList::setSplit(const FileAccPropList &meta_plist, const FileAccPropList &raw_plist,
-                          const H5std_string &meta_ext, const H5std_string &raw_ext) const
+void FileAccPropList::setSplit(const FileAccPropList& meta_plist, const FileAccPropList& raw_plist, const H5std_string& meta_ext, const H5std_string& raw_ext) const
 {
     setSplit(meta_plist, raw_plist, meta_ext.c_str(), raw_ext.c_str());
 }
@@ -365,17 +358,17 @@ FileAccPropList::setSplit(const FileAccPropList &meta_plist, const FileAccPropLi
 ///             property from this property list.
 ///\return      Data sieve buffer size, in bytes
 ///\exception   H5::PropListIException
-// Programmer:  Binh-Minh Ribler - April, 2004
+// Programmer   Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
-size_t
-FileAccPropList::getSieveBufSize() const
+size_t FileAccPropList::getSieveBufSize() const
 {
     size_t bufsize;
     herr_t ret_value = H5Pget_sieve_buf_size(id, &bufsize);
-    if (ret_value < 0) {
+    if (ret_value < 0)
+    {
         throw PropListIException("FileAccPropList::getSieveBufSize", "H5Pget_sieve_buf_size failed");
     }
-    return (bufsize);
+    return(bufsize);
 }
 
 //--------------------------------------------------------------------------
@@ -384,15 +377,15 @@ FileAccPropList::getSieveBufSize() const
 ///\param       bufsize - IN: Maximum size, in bytes, of data sieve buffer
 ///\exception   H5::PropListIException
 ///\par Description
-///             For detail on data sieving, please refer to
-/// https://support.hdfgroup.org/HDF5/doc/RM/RM_H5P.html#Property-SetSieveBufSize
-// Programmer:  Binh-Minh Ribler - April, 2004
+///             For more detail, please refer to the H5Pset_sieve_buf_size
+///             API in the HDF5 C Reference Manual.
+// Programmer   Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
-void
-FileAccPropList::setSieveBufSize(size_t bufsize) const
+void FileAccPropList::setSieveBufSize(size_t bufsize) const
 {
     herr_t ret_value = H5Pset_sieve_buf_size(id, bufsize);
-    if (ret_value < 0) {
+    if (ret_value < 0)
+    {
         throw PropListIException("FileAccPropList::getSieveBufSize", "H5Pget_sieve_buf_size failed");
     }
 }
@@ -404,15 +397,15 @@ FileAccPropList::setSieveBufSize(size_t bufsize) const
 ///             block allocations
 ///\exception   H5::PropListIException
 ///\par Description
-///             For more detail, please see the C layer Reference Manual at:
-/// https://support.hdfgroup.org/HDF5/doc/RM/RM_H5P.html#Property-SetMetaBlockSize
-// Programmer:  Binh-Minh Ribler - April, 2004
+///             For information, please refer to the H5Pset_meta_block_size
+///             API in the HDF5 C Reference Manual.
+// Programmer   Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
-void
-FileAccPropList::setMetaBlockSize(hsize_t &block_size) const
+void FileAccPropList::setMetaBlockSize(hsize_t &block_size) const
 {
     herr_t ret_value = H5Pset_meta_block_size(id, block_size);
-    if (ret_value < 0) {
+    if (ret_value < 0)
+    {
         throw PropListIException("FileAccPropList::setMetaBlockSize", "H5Pset_meta_block_size failed");
     }
 }
@@ -422,17 +415,17 @@ FileAccPropList::setMetaBlockSize(hsize_t &block_size) const
 ///\brief       Returns the current metadata block size setting.
 ///\return      Metadata block size
 ///\exception   H5::PropListIException
-// Programmer:  Binh-Minh Ribler - April, 2004
+// Programmer   Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
-hsize_t
-FileAccPropList::getMetaBlockSize() const
+hsize_t FileAccPropList::getMetaBlockSize() const
 {
     hsize_t block_size;
-    herr_t  ret_value = H5Pget_meta_block_size(id, &block_size);
-    if (ret_value < 0) {
+    herr_t ret_value = H5Pget_meta_block_size(id, &block_size);
+    if (ret_value < 0)
+    {
         throw PropListIException("FileAccPropList::getMetaBlockSize", "H5Pget_meta_block_size failed");
     }
-    return (block_size);
+    return(block_size);
 }
 
 //--------------------------------------------------------------------------
@@ -444,15 +437,15 @@ FileAccPropList::getMetaBlockSize() const
 ///\param       buf_size - IN: Size of the logging buffer
 ///\exception   H5::PropListIException
 ///\par Description
-///             For detail on \a flags, please refer to
-/// https://support.hdfgroup.org/HDF5/doc/RM/RM_H5P.html#Property-SetFaplLog
-// Programmer:  Binh-Minh Ribler - April, 2004
+///             For information, please refer to the H5Pset_fapl_log API in
+///             the HDF5 C Reference Manual.
+// Programmer   Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
-void
-FileAccPropList::setLog(const char *logfile, unsigned flags, size_t buf_size) const
+void FileAccPropList::setLog(const char *logfile, unsigned flags, size_t buf_size) const
 {
     herr_t ret_value = H5Pset_fapl_log(id, logfile, flags, buf_size);
-    if (ret_value < 0) {
+    if (ret_value < 0)
+    {
         throw PropListIException("FileAccPropList::setLog", "H5Pset_fapl_log failed");
     }
 }
@@ -465,10 +458,9 @@ FileAccPropList::setLog(const char *logfile, unsigned flags, size_t buf_size) co
 ///\param       logfile  - IN: Name of the log file - string
 ///\param       flags    - IN: Flags specifying the types of logging activity
 ///\param       buf_size - IN: Size of the logging buffer
-// Programmer:  Binh-Minh Ribler - April, 2004
+// Programmer   Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
-void
-FileAccPropList::setLog(const H5std_string &logfile, unsigned flags, size_t buf_size) const
+void FileAccPropList::setLog(const H5std_string& logfile, unsigned flags, size_t buf_size) const
 {
     setLog(logfile.c_str(), flags, buf_size);
 }
@@ -479,13 +471,13 @@ FileAccPropList::setLog(const H5std_string &logfile, unsigned flags, size_t buf_
 ///             driver.
 ///
 ///\exception   H5::PropListIException
-// Programmer:  Binh-Minh Ribler - April, 2004
+// Programmer   Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
-void
-FileAccPropList::setSec2() const
+void FileAccPropList::setSec2() const
 {
     herr_t ret_value = H5Pset_fapl_sec2(id);
-    if (ret_value < 0) {
+    if (ret_value < 0)
+    {
         throw PropListIException("FileAccPropList::setSec2", "H5Pset_fapl_sec2 failed");
     }
 }
@@ -502,15 +494,15 @@ FileAccPropList::setSec2() const
 ///             effect of a special case, forcing everything to be aligned.
 ///             The parameter \a alignment must have a positive value.
 ///
-///             For detail on \a setting alignment, please refer to
-/// https://support.hdfgroup.org/HDF5/doc/RM/RM_H5P.html#Property-SetAlignment
-// Programmer:  Binh-Minh Ribler - 2000
+///             For more detail, please refer to the H5Pset_alignment API in
+///             the HDF5 C Reference Manual.
+// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-void
-FileAccPropList::setAlignment(hsize_t threshold, hsize_t alignment) const
+void FileAccPropList::setAlignment(hsize_t threshold, hsize_t alignment) const
 {
     herr_t ret_value = H5Pset_alignment(id, threshold, alignment);
-    if (ret_value < 0) {
+    if (ret_value < 0)
+    {
         throw PropListIException("FileAccPropList::setAlignment", "H5Pset_alignment failed");
     }
 }
@@ -522,13 +514,13 @@ FileAccPropList::setAlignment(hsize_t threshold, hsize_t alignment) const
 ///\param       threshold - OUT: Retrieved threshold value for file object size
 ///\param       alignment - OUT: Retrieved alignment value
 ///\exception   H5::PropListIException
-// Programmer:  Binh-Minh Ribler - 2000
+// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-void
-FileAccPropList::getAlignment(hsize_t &threshold, hsize_t &alignment) const
+void FileAccPropList::getAlignment(hsize_t &threshold, hsize_t &alignment) const
 {
     herr_t ret_value = H5Pget_alignment(id, &threshold, &alignment);
-    if (ret_value < 0) {
+    if (ret_value < 0)
+    {
         throw PropListIException("FileAccPropList::getAlignment", "H5Pget_alignment failed");
     }
 }
@@ -539,15 +531,15 @@ FileAccPropList::getAlignment(hsize_t &threshold, hsize_t &alignment) const
 ///\param       dtype - IN: Type of data
 ///\exception   H5::PropListIException
 ///\par Description
-///             More details and valid values for \a dtype can be found at:
-/// https://support.hdfgroup.org/HDF5/doc/RM/RM_H5P.html#Property-SetMultiType
-// Programmer:  Binh-Minh Ribler - April, 2004
+///             For information, please refer to the H5Pset_multi_type API in
+///             the HDF5 C Reference Manual.
+// Programmer   Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
-void
-FileAccPropList::setMultiType(H5FD_mem_t dtype) const
+void FileAccPropList::setMultiType(H5FD_mem_t dtype) const
 {
     herr_t ret_value = H5Pset_multi_type(id, dtype);
-    if (ret_value < 0) {
+    if (ret_value < 0)
+    {
         throw PropListIException("FileAccPropList::setMultiType", "H5Pset_multi_type failed");
     }
 }
@@ -558,19 +550,19 @@ FileAccPropList::setMultiType(H5FD_mem_t dtype) const
 ///\return      The data type property
 ///\exception   H5::PropListIException
 ///\par Description
-///             More details and possible returned values can be found at:
-/// https://support.hdfgroup.org/HDF5/doc/RM/RM_H5P.html#Property-GetMultiType
-// Programmer:  Binh-Minh Ribler - April, 2004
+///             For information, please refer to the H5Pget_multi_type API in
+///             the HDF5 C Reference Manual.
+// Programmer   Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
-H5FD_mem_t
-FileAccPropList::getMultiType() const
+H5FD_mem_t FileAccPropList::getMultiType() const
 {
     H5FD_mem_t dtype;
-    herr_t     ret_value = H5Pget_multi_type(id, &dtype);
-    if (ret_value < 0) {
+    herr_t ret_value = H5Pget_multi_type(id, &dtype);
+    if (ret_value < 0)
+    {
         throw PropListIException("FileAccPropList::getMultiType", "H5Pget_multi_type failed");
     }
-    return (dtype);
+    return(dtype);
 }
 
 //--------------------------------------------------------------------------
@@ -588,13 +580,13 @@ FileAccPropList::getMultiType() const
 ///             means fully read chunks are treated no differently than other
 ///             chunks (the preemption is strictly LRU) while a value of one
 ///             means fully read chunks are always preempted before other chunks.
-// Programmer:  Binh-Minh Ribler - 2000
+// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-void
-FileAccPropList::setCache(int mdc_nelmts, size_t rdcc_nelmts, size_t rdcc_nbytes, double rdcc_w0) const
+void FileAccPropList::setCache(int mdc_nelmts, size_t rdcc_nelmts, size_t rdcc_nbytes, double rdcc_w0) const
 {
     herr_t ret_value = H5Pset_cache(id, mdc_nelmts, rdcc_nelmts, rdcc_nbytes, rdcc_w0);
-    if (ret_value < 0) {
+    if (ret_value < 0)
+    {
         throw PropListIException("FileAccPropList::setCache", "H5Pset_cache failed");
     }
 }
@@ -607,13 +599,13 @@ FileAccPropList::setCache(int mdc_nelmts, size_t rdcc_nelmts, size_t rdcc_nbytes
 ///\param       rdcc_nbytes - OUT: Total size of the raw data chunk cache, in bytes
 ///\param       rdcc_w0 - OUT: Preemption policy
 ///\exception   H5::PropListIException
-// Programmer:  Binh-Minh Ribler - 2000
+// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-void
-FileAccPropList::getCache(int &mdc_nelmts, size_t &rdcc_nelmts, size_t &rdcc_nbytes, double &rdcc_w0) const
+void FileAccPropList::getCache(int& mdc_nelmts, size_t& rdcc_nelmts, size_t& rdcc_nbytes, double& rdcc_w0) const
 {
     herr_t ret_value = H5Pget_cache(id, &mdc_nelmts, &rdcc_nelmts, &rdcc_nbytes, &rdcc_w0);
-    if (ret_value < 0) {
+    if (ret_value < 0)
+    {
         throw PropListIException("FileAccPropList::getCache", "H5Pget_cache failed");
     }
 }
@@ -623,13 +615,13 @@ FileAccPropList::getCache(int &mdc_nelmts, size_t &rdcc_nelmts, size_t &rdcc_nby
 ///\brief       Sets the degree for the file close behavior.
 ///\param       degree - IN:
 ///\exception   H5::PropListIException
-// Programmer:  Binh-Minh Ribler - April, 2004
+// Programmer   Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
-void
-FileAccPropList::setFcloseDegree(H5F_close_degree_t degree) const
+void FileAccPropList::setFcloseDegree(H5F_close_degree_t degree) const
 {
     herr_t ret_value = H5Pset_fclose_degree(id, degree);
-    if (ret_value < 0) {
+    if (ret_value < 0)
+    {
         throw PropListIException("FileAccPropList::setFcloseDegree", "H5Pset_fclose_degree failed");
     }
 }
@@ -639,35 +631,35 @@ FileAccPropList::setFcloseDegree(H5F_close_degree_t degree) const
 ///\brief       Returns the degree for the file close behavior.
 ///\return      The degree for the file close behavior
 ///\exception   H5::PropListIException
-// Programmer:  Binh-Minh Ribler - April, 2004
+// Programmer   Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
-H5F_close_degree_t
-FileAccPropList::getFcloseDegree() const
+H5F_close_degree_t FileAccPropList::getFcloseDegree() const
 {
     H5F_close_degree_t degree;
-    herr_t             ret_value = H5Pget_fclose_degree(id, &degree);
-    if (ret_value < 0) {
+    herr_t ret_value = H5Pget_fclose_degree(id, &degree);
+    if (ret_value < 0)
+    {
         throw PropListIException("FileAccPropList::getFcloseDegree", "H5Pget_fclose_degree failed");
     }
-    return (degree);
+    return(degree);
 }
 
 //--------------------------------------------------------------------------
 // Function:    FileAccPropList::setGcReferences
 ///\brief       Sets garbage collecting references flag.
 ///\param       gc_ref - IN: Flag setting reference garbage collection to
-///                             on (1) or off (0).
+///                          on (1) or off (0).
 ///\exception   H5::PropListIException
 ///\par Description
-///             For detail on \a fapl, please refer to
-/// https://support.hdfgroup.org/HDF5/doc/RM/RM_H5P.html#Property-SetGCReferences
-// Programmer:  Binh-Minh Ribler - 2000
+///             For information, please refer to the H5Pset_gc_references API in
+///             the HDF5 C Reference Manual.
+// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-void
-FileAccPropList::setGcReferences(unsigned gc_ref) const
+void FileAccPropList::setGcReferences(unsigned gc_ref) const
 {
     herr_t ret_value = H5Pset_gc_references(id, gc_ref);
-    if (ret_value < 0) {
+    if (ret_value < 0)
+    {
         throw PropListIException("FileAccPropList::setGcReferences", "H5Pset_gc_references failed");
     }
 }
@@ -677,19 +669,19 @@ FileAccPropList::setGcReferences(unsigned gc_ref) const
 ///\brief       Returns the garbage collecting references setting.
 ///\return      Garbage collecting references setting, 0 (off) or 1 (on)
 ///\exception   H5::PropListIException
-// Programmer:  Binh-Minh Ribler - 2000
+// Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-unsigned
-FileAccPropList::getGcReferences() const
+unsigned FileAccPropList::getGcReferences() const
 {
     unsigned gc_ref;
 
     // the name of this routine will be changed to H5Pget_gc_references???
     herr_t ret_value = H5Pget_gc_references(id, &gc_ref);
-    if (ret_value < 0) {
+    if (ret_value < 0)
+    {
         throw PropListIException("FileAccPropList::getGcReferences", "H5Pget_gc_references failed");
     }
-    return (gc_ref);
+    return(gc_ref);
 }
 
 //--------------------------------------------------------------------------
@@ -704,21 +696,25 @@ FileAccPropList::getGcReferences() const
 ///             Valid values of \a libver_low are as follows:
 ///             \li \c H5F_LIBVER_EARLIEST   (Default)
 ///             \li \c H5F_LIBVER_18
+///             \li \c H5F_LIBVER_110
+///             \li \c H5F_LIBVER_112
 ///             \li \c H5F_LIBVER_LATEST
 ///
 ///             Valid values of \a libver_high are as follows:
 ///             \li \c H5F_LIBVER_18
+///             \li \c H5F_LIBVER_110
+///             \li \c H5F_LIBVER_112
 ///             \li \c H5F_LIBVER_LATEST   (Default)
 ///
-///             For more details, please refer to
-/// https://support.hdfgroup.org/HDF5/doc/RM/RM_H5P.html#Property-SetLibverBounds
-// Programmer:  Binh-Minh Ribler - March, 2015
+///             For more detail, please refer to the H5Pset_libver_bounds API in
+///             the HDF5 C Reference Manual.
+// Programmer   Binh-Minh Ribler - March, 2015
 //--------------------------------------------------------------------------
-void
-FileAccPropList::setLibverBounds(H5F_libver_t libver_low, H5F_libver_t libver_high) const
+void FileAccPropList::setLibverBounds(H5F_libver_t libver_low, H5F_libver_t libver_high) const
 {
     herr_t ret_value = H5Pset_libver_bounds(id, libver_low, libver_high);
-    if (ret_value < 0) {
+    if (ret_value < 0)
+    {
         throw PropListIException("FileAccPropList::setLibverBounds", "H5Pset_libver_bounds failed");
     }
 }
@@ -737,18 +733,22 @@ FileAccPropList::setLibverBounds(H5F_libver_t libver_low, H5F_libver_t libver_hi
 ///             values:
 ///             \li \c H5F_LIBVER_EARLIEST
 ///             \li \c H5F_LIBVER_18
+///             \li \c H5F_LIBVER_110
+///             \li \c H5F_LIBVER_112
 ///             \li \c H5F_LIBVER_LATEST
 ///
 ///             and \a libver_high:
 ///             \li \c H5F_LIBVER_18
+///             \li \c H5F_LIBVER_110
+///             \li \c H5F_LIBVER_112
 ///             \li \c H5F_LIBVER_LATEST
-// Programmer:  Binh-Minh Ribler - March, 2015
+// Programmer   Binh-Minh Ribler - March, 2015
 //--------------------------------------------------------------------------
-void
-FileAccPropList::getLibverBounds(H5F_libver_t &libver_low, H5F_libver_t &libver_high) const
+void FileAccPropList::getLibverBounds(H5F_libver_t& libver_low, H5F_libver_t& libver_high) const
 {
     herr_t ret_value = H5Pget_libver_bounds(id, &libver_low, &libver_high);
-    if (ret_value < 0) {
+    if (ret_value < 0)
+    {
         throw PropListIException("FileAccPropList::getLibverBounds", "H5Pget_libver_bounds failed");
     }
 }
@@ -758,8 +758,6 @@ FileAccPropList::getLibverBounds(H5F_libver_t &libver_low, H5F_libver_t &libver_
 ///\brief       Noop destructor
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-FileAccPropList::~FileAccPropList()
-{
-}
+FileAccPropList::~FileAccPropList() {}
 
-} // namespace H5
+} // end namespace
