@@ -6,7 +6,7 @@
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://www.hdfgroup.org/licenses.               *
+ * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -19,17 +19,16 @@
 
 #include <string>
 
-#include "H5private.h" // for HDmemset
+#include "H5private.h"        // for HDmemset
 #include "H5Include.h"
 #include "H5Exception.h"
 #include "H5IdComponent.h"
 #include "H5PropList.h"
 
+
 namespace H5 {
-#ifndef H5_NO_STD
-using std::cerr;
-using std::endl;
-#endif // H5_NO_STD
+    using std::cerr;
+    using std::endl;
 
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
 // This DOXYGEN_SHOULD_SKIP_THIS block is a work-around approach to control
@@ -37,11 +36,11 @@ using std::endl;
 // in "H5PredType.cpp" for information.
 
 // Initialize a pointer for the constant
-PropList *PropList::DEFAULT_ = 0;
+PropList* PropList::DEFAULT_ = 0;
 
 //--------------------------------------------------------------------------
 // Function:    PropList::getConstant
-// Purpose:     Creates a PropList object representing the HDF5 constant
+// Purpose      Creates a PropList object representing the HDF5 constant
 //              H5P_DEFAULT, pointed to by PropList::DEFAULT_.
 // Exception    H5::PropListIException
 // Description
@@ -49,13 +48,13 @@ PropList *PropList::DEFAULT_ = 0;
 //              throw a PropListIException.  This scenario should not happen.
 // Programmer   Binh-Minh Ribler - 2015
 //--------------------------------------------------------------------------
-PropList *
-PropList::getConstant()
+PropList* PropList::getConstant()
 {
     // Tell the C library not to clean up, H5Library::termH5cpp will call
     // H5close - more dependency if use H5Library::dontAtExit()
-    if (!IdComponent::H5dontAtexit_called) {
-        (void)H5dont_atexit();
+    if (!IdComponent::H5dontAtexit_called)
+    {
+        (void) H5dont_atexit();
         IdComponent::H5dontAtexit_called = true;
     }
 
@@ -64,18 +63,16 @@ PropList::getConstant()
     if (DEFAULT_ == 0)
         DEFAULT_ = new PropList(H5P_DEFAULT);
     else
-        throw PropListIException("PropList::getConstant",
-                                 "PropList::getConstant is being invoked on an allocated DEFAULT_");
-    return (DEFAULT_);
+        throw PropListIException("PropList::getConstant", "PropList::getConstant is being invoked on an allocated DEFAULT_");
+    return(DEFAULT_);
 }
 
 //--------------------------------------------------------------------------
 // Function:    PropList::deleteConstants
-// Purpose:     Deletes the constant object that PropList::DEFAULT_ points to.
+// Purpose      Deletes the constant object that PropList::DEFAULT_ points to.
 // Programmer   Binh-Minh Ribler - 2015
 //--------------------------------------------------------------------------
-void
-PropList::deleteConstants()
+void PropList::deleteConstants()
 {
     if (DEFAULT_ != 0)
         delete DEFAULT_;
@@ -84,26 +81,24 @@ PropList::deleteConstants()
 //--------------------------------------------------------------------------
 // Purpose      Constant for default property.
 //--------------------------------------------------------------------------
-const PropList &PropList::DEFAULT = *getConstant();
+const PropList& PropList::DEFAULT = *getConstant();
 
 #endif // DOXYGEN_SHOULD_SKIP_THIS
 
 //--------------------------------------------------------------------------
-// Function     Default constructor
+// Function:    Default constructor
 ///\brief       Default constructor: creates a stub property list object.
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-PropList::PropList() : IdComponent(), id(H5P_DEFAULT)
-{
-}
+PropList::PropList() : IdComponent(), id(H5P_DEFAULT) {}
 
 //--------------------------------------------------------------------------
 // Function:    PropList copy constructor
-///\brief       Copy constructor
+///\brief       Copy constructor: same HDF5 object as \a original
 ///\param       original - IN: The original property list to copy
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-PropList::PropList(const PropList &original) : IdComponent(), id(original.id)
+PropList::PropList(const PropList& original) : IdComponent(), id(original.id)
 {
     incRefCount(); // increment number of references to this id
 }
@@ -128,22 +123,42 @@ PropList::PropList(const hid_t plist_id) : IdComponent()
     H5I_type_t id_type = H5Iget_type(plist_id);
     switch (id_type) {
         case H5I_GENPROP_CLS:
-            // call C routine to create a new property from the given prop class
-            id = H5Pcreate(plist_id);
-            if (id < 0) {
-                throw PropListIException("PropList constructor", "H5Pcreate failed");
-            }
-            break;
+          // call C routine to create a new property from the given prop class
+          id = H5Pcreate(plist_id);
+          if (id < 0)
+          {
+              throw PropListIException("PropList constructor", "H5Pcreate failed");
+          }
+          break;
         case H5I_GENPROP_LST:
-            // call C routine to make a copy of the given property list
-            id = H5Pcopy(plist_id);
-            if (id < 0) {
-                throw PropListIException("PropList constructor", "H5Pcopy failed");
-            }
-            break;
+          // call C routine to make a copy of the given property list
+          id = H5Pcopy(plist_id);
+          if (id < 0)
+          {
+              throw PropListIException("PropList constructor", "H5Pcopy failed");
+          }
+          break;
+        /* These should really be error cases, but changing that breaks
+         * the stated behavior and causes test failures.
+         * (DER, July 2017)
+         */
+        case H5I_BADID:
+        case H5I_FILE:
+        case H5I_GROUP:
+        case H5I_DATATYPE:
+        case H5I_DATASPACE:
+        case H5I_DATASET:
+        case H5I_ATTR:
+        case H5I_VFL:
+        case H5I_VOL:
+        case H5I_ERROR_CLASS:
+        case H5I_ERROR_MSG:
+        case H5I_ERROR_STACK:
+        case H5I_NTYPES:
+        case H5I_UNINIT:
         default:
-            id = H5P_DEFAULT;
-            break;
+          id = H5P_DEFAULT;
+          break;
     }
 }
 
@@ -159,15 +174,14 @@ PropList::PropList(const hid_t plist_id) : IdComponent()
 //              - Replaced decRefCount with close() to let the C library
 //              handle the reference counting - BMR, Jun 1, 2006
 //--------------------------------------------------------------------------
-void
-PropList::copy(const PropList &like_plist)
+void PropList::copy(const PropList& like_plist)
 {
     // If this object is representing an hdf5 object, close it before
     // copying like_plist to it
     try {
         close();
     }
-    catch (Exception &close_error) {
+    catch (Exception& close_error) {
         throw PropListIException(inMemFunc("copy"), close_error.getDetailMsg());
     }
 
@@ -188,12 +202,11 @@ PropList::copy(const PropList &like_plist)
 //              and stores the new id in the left hand side object.
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-PropList &
-PropList::operator=(const PropList &rhs)
+PropList& PropList::operator=(const PropList& rhs)
 {
     if (this != &rhs)
         copy(rhs);
-    return (*this);
+    return(*this);
 }
 
 //--------------------------------------------------------------------------
@@ -204,12 +217,12 @@ PropList::operator=(const PropList &rhs)
 ///\exception   H5::PropListIException
 // Programmer   Binh-Minh Ribler - Jul, 2005
 //--------------------------------------------------------------------------
-void
-PropList::copyProp(PropList &dest, const char *name) const
+void PropList::copyProp(PropList& dest, const char *name) const
 {
-    hid_t  dst_id    = dest.getId();
+    hid_t dst_id = dest.getId();
     herr_t ret_value = H5Pcopy_prop(dst_id, id, name);
-    if (ret_value < 0) {
+    if (ret_value < 0)
+    {
         throw PropListIException(inMemFunc("copyProp"), "H5Pcopy_prop failed");
     }
 }
@@ -223,8 +236,7 @@ PropList::copyProp(PropList &dest, const char *name) const
 ///\param       name - IN: Name of the property to copy - \c H5std_string
 // Programmer   Binh-Minh Ribler - Jul, 2005
 //--------------------------------------------------------------------------
-void
-PropList::copyProp(PropList &dest, const H5std_string &name) const
+void PropList::copyProp(PropList& dest, const H5std_string& name) const
 {
     copyProp(dest, name.c_str());
 }
@@ -239,15 +251,16 @@ PropList::copyProp(PropList &dest, const H5std_string &name) const
 ///\exception   H5::PropListIException
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-void
-PropList::copyProp(PropList &dest, PropList &src, const char *name) const
+void PropList::copyProp(PropList& dest, PropList& src, const char *name) const
 {
-    hid_t  dst_id    = dest.getId();
-    hid_t  src_id    = src.getId();
+    hid_t dst_id = dest.getId();
+    hid_t src_id = src.getId();
     herr_t ret_value = H5Pcopy_prop(dst_id, src_id, name);
-    if (ret_value < 0) {
+    if (ret_value < 0)
+    {
         throw PropListIException(inMemFunc("copyProp"), "H5Pcopy_prop failed");
     }
+
 }
 
 //--------------------------------------------------------------------------
@@ -260,8 +273,7 @@ PropList::copyProp(PropList &dest, PropList &src, const char *name) const
 ///\param       name - IN: Name of the property to copy - \c H5std_string
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-void
-PropList::copyProp(PropList &dest, PropList &src, const H5std_string &name) const
+void PropList::copyProp(PropList& dest, PropList& src, const H5std_string& name) const
 {
     copyProp(dest, src, name.c_str());
 }
@@ -277,10 +289,9 @@ PropList::copyProp(PropList &dest, PropList &src, const H5std_string &name) cons
 //              IdComponent::getId now becomes pure virtual function.
 // Programmer   Binh-Minh Ribler - May, 2008
 //--------------------------------------------------------------------------
-hid_t
-PropList::getId() const
+hid_t PropList::getId() const
 {
-    return (id);
+    return(id);
 }
 
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
@@ -296,18 +307,17 @@ PropList::getId() const
 //              Then the object's id is reset to the new id.
 // Programmer   Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-void
-PropList::p_setId(const hid_t new_id)
+void PropList::p_setId(const hid_t new_id)
 {
     // handling references to this old id
     try {
         close();
     }
-    catch (Exception &close_error) {
+    catch (Exception& close_error) {
         throw PropListIException(inMemFunc("p_setId"), close_error.getDetailMsg());
     }
-    // reset object's id to the given id
-    id = new_id;
+   // reset object's id to the given id
+   id = new_id;
 }
 
 #endif // DOXYGEN_SHOULD_SKIP_THIS
@@ -319,12 +329,13 @@ PropList::p_setId(const hid_t new_id)
 ///\exception   H5::PropListIException
 // Programmer   Binh-Minh Ribler - Mar 9, 2005
 //--------------------------------------------------------------------------
-void
-PropList::close()
+void PropList::close()
 {
-    if (p_valid_id(id)) {
+    if (p_valid_id(id))
+    {
         herr_t ret_value = H5Pclose(id);
-        if (ret_value < 0) {
+        if (ret_value < 0)
+        {
             throw PropListIException(inMemFunc("close"), "H5Pclose failed");
         }
         // reset the id
@@ -339,19 +350,20 @@ PropList::close()
 ///\exception   H5::PropListIException
 // Programmer   Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
-hid_t
-PropList::getClass() const
+hid_t PropList::getClass() const
 {
     hid_t plist_class = H5Pget_class(id);
-    if (plist_class == H5P_ROOT) {
-        throw PropListIException(inMemFunc("getClass"), "H5Pget_class failed - returned H5P_ROOT");
+    if (plist_class == H5P_ROOT)
+    {
+        throw PropListIException(inMemFunc("getClass"),
+            "H5Pget_class failed - returned H5P_ROOT");
     }
-    return (plist_class);
+   return(plist_class);
 }
 
 //--------------------------------------------------------------------------
 // Function:    PropList::propExist
-///\brief       Query the existance of a property in a property object.
+///\brief       Queries the existence of a property in a property object.
 ///\param       name - IN: Name of property to check for - \c char pointer
 ///\return      true if the property exists in the property object, and
 ///             false, otherwise.
@@ -361,8 +373,7 @@ PropList::getClass() const
 ///             list or class.
 // Programmer:  Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
-bool
-PropList::propExist(const char *name) const
+bool PropList::propExist(const char* name) const
 {
     // Calls C routine H5Pexist to determine whether a property exists
     // within a property list or class.  It returns a positive value, 0,
@@ -385,10 +396,9 @@ PropList::propExist(const char *name) const
 ///\param       name - IN: Name of property to check for - \c H5std_string
 // Programmer:  Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
-bool
-PropList::propExist(const H5std_string &name) const
+bool PropList::propExist(const H5std_string& name) const
 {
-    return (propExist(name.c_str()));
+    return(propExist( name.c_str()));
 }
 
 //--------------------------------------------------------------------------
@@ -401,11 +411,11 @@ PropList::propExist(const H5std_string &name) const
 ///             list class hierarchy.
 // Programmer:  Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
-void
-PropList::closeClass() const
+void PropList::closeClass() const
 {
     herr_t ret_value = H5Pclose_class(id);
-    if (ret_value < 0) {
+    if (ret_value < 0)
+    {
         throw PropListIException(inMemFunc("closeClass"), "H5Pclose_class failed");
     }
 }
@@ -422,11 +432,11 @@ PropList::closeClass() const
 ///             throw an exception.
 // Programmer:  Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
-void
-PropList::getProperty(const char *name, void *value) const
+void PropList::getProperty(const char* name, void* value) const
 {
     herr_t ret_value = H5Pget(id, name, value);
-    if (ret_value < 0) {
+    if (ret_value < 0)
+    {
         throw PropListIException(inMemFunc("getProperty"), "H5Pget failed");
     }
 }
@@ -440,27 +450,27 @@ PropList::getProperty(const char *name, void *value) const
 ///\exception   H5::PropListIException
 // Programmer:  Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
-H5std_string
-PropList::getProperty(const char *name) const
+H5std_string PropList::getProperty(const char* name) const
 {
     // Get property size first
     size_t size = getPropSize(name);
 
     // Allocate buffer then get the property
-    char *prop_strg_C = new char[size + 1]; // temporary C-string for C API
-    HDmemset(prop_strg_C, 0, size + 1);     // clear buffer
+    char* prop_strg_C = new char[size+1];  // temporary C-string for C API
+    HDmemset(prop_strg_C, 0, size+1); // clear buffer
 
     herr_t ret_value = H5Pget(id, name, prop_strg_C); // call C API
 
     // Throw exception if H5Pget returns failure
-    if (ret_value < 0) {
-        delete[] prop_strg_C;
+    if (ret_value < 0)
+    {
+      delete []prop_strg_C;
         throw PropListIException(inMemFunc("getProperty"), "H5Pget failed");
     }
 
-    // Return propety value as a string after deleting temp C-string
+    // Return property value as a string after deleting temp C-string
     H5std_string prop_strg(prop_strg_C);
-    delete[] prop_strg_C;
+    delete []prop_strg_C;
     return (prop_strg);
 }
 //--------------------------------------------------------------------------
@@ -472,8 +482,7 @@ PropList::getProperty(const char *name) const
 ///\param       value - OUT: Pointer to the buffer for the property value
 // Programmer:  Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
-void
-PropList::getProperty(const H5std_string &name, void *value) const
+void PropList::getProperty(const H5std_string& name, void* value) const
 {
     getProperty(name.c_str(), value);
 }
@@ -486,8 +495,7 @@ PropList::getProperty(const H5std_string &name, void *value) const
 ///\return      The property that is a \c H5std_string.
 // Programmer:  Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
-H5std_string
-PropList::getProperty(const H5std_string &name) const
+H5std_string PropList::getProperty(const H5std_string& name) const
 {
     return (getProperty(name.c_str()));
 }
@@ -505,15 +513,15 @@ PropList::getProperty(const H5std_string &name) const
 ///             lists and classes.
 // Programmer:  Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
-size_t
-PropList::getPropSize(const char *name) const
+size_t PropList::getPropSize(const char *name) const
 {
     size_t prop_size;
     herr_t ret_value = H5Pget_size(id, name, &prop_size);
-    if (ret_value < 0) {
+    if (ret_value < 0)
+    {
         throw PropListIException(inMemFunc("getPropSize"), "H5Pget_size failed");
     }
-    return (prop_size);
+    return(prop_size);
 }
 //--------------------------------------------------------------------------
 // Function:    PropList::getPropSize
@@ -524,8 +532,7 @@ PropList::getPropSize(const char *name) const
 ///
 // Programmer:  Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
-size_t
-PropList::getPropSize(const H5std_string &name) const
+size_t PropList::getPropSize(const H5std_string& name) const
 {
     return (getPropSize(name.c_str()));
 }
@@ -534,25 +541,22 @@ PropList::getPropSize(const H5std_string &name) const
 // Function:    PropList::getClassName
 ///\brief       Return the name of a generic property list class.
 ///\return      A string containing the class name, if success, otherwise,
-///             an empty string.
+///             a NULL string.
 // Programmer:  Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
-H5std_string
-PropList::getClassName() const
+H5std_string PropList::getClassName() const
 {
-    char *temp_str;
-    temp_str = H5Pget_class_name(id); // this API specified that temp_str must
-                                      // be freed.
-
-    if (temp_str != NULL) {
+    char* temp_str;
+    temp_str = H5Pget_class_name(id);
+    if (temp_str != NULL)
+    {
         H5std_string class_name(temp_str);
         H5free_memory(temp_str);
-        return (class_name);
+        return(class_name);
     }
     else
-        return "";
+        return 0;
 }
-
 //--------------------------------------------------------------------------
 // Function:    PropList::getNumProps
 ///\brief       Returns the number of properties in this property list or class.
@@ -560,12 +564,12 @@ PropList::getClassName() const
 ///\exception   H5::PropListIException
 // Programmer:  Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
-size_t
-PropList::getNumProps() const
+size_t PropList::getNumProps() const
 {
     size_t nprops;
-    herr_t ret_value = H5Pget_nprops(id, &nprops);
-    if (ret_value < 0) {
+    herr_t ret_value = H5Pget_nprops (id, &nprops);
+    if (ret_value < 0)
+    {
         throw PropListIException(inMemFunc("getNumProps"), "H5Pget_nprops failed");
     }
     return (nprops);
@@ -577,16 +581,36 @@ PropList::getNumProps() const
 ///\param       name  - IN: Name of property to set - \c char pointer
 ///\param       value - IN: Void pointer to the value for the property
 ///\exception   H5::PropListIException
+// Description
+//              Revision svn r29815 changed 'value' to const, hence, deprecated
+//              the non-const setProperty.
 // Programmer:  Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
-void
-PropList::setProperty(const char *name, void *value) const
+void PropList::setProperty(const char* name, const void* value) const
 {
     herr_t ret_value = H5Pset(id, name, value);
-    if (ret_value < 0) {
+    if (ret_value < 0)
+    {
         throw PropListIException(inMemFunc("setProperty"), "H5Pset failed");
     }
 }
+
+//--------------------------------------------------------------------------
+// Function:    PropList::setProperty
+///\brief       Deprecated due to missing const in prototype. (1.10.1)
+// Programmer:  Binh-Minh Ribler - March, 2017
+// Modification
+//              Planned for removal. -BMR, 2017/03/17 1.10.1
+//--------------------------------------------------------------------------
+void PropList::setProperty(const char* name, void* value) const
+{
+    herr_t ret_value = H5Pset(id, name, value);
+    if (ret_value < 0)
+    {
+        throw PropListIException(inMemFunc("setProperty"), "H5Pset failed");
+    }
+}
+
 //--------------------------------------------------------------------------
 // Function:    PropList::setProperty
 ///\brief       This is an overloaded member function, provided for convenience.
@@ -594,13 +618,16 @@ PropList::setProperty(const char *name, void *value) const
 ///             accepts.
 ///\param       name    - IN: Name of property to set - \c char pointer
 ///\param       charptr - IN: Char pointer to the value for the property
+// Description
+//              Revision svn r29815 changed 'value' to const, hence, deprecated
+//              the non-const setProperty.
 // Programmer:  Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
-void
-PropList::setProperty(const char *name, const char *charptr) const
+void PropList::setProperty(const char* name, const char* charptr) const
 {
-    herr_t ret_value = H5Pset(id, name, (void *)charptr);
-    if (ret_value < 0) {
+    herr_t ret_value = H5Pset(id, name, (const void*)charptr);
+    if (ret_value < 0)
+    {
         throw PropListIException(inMemFunc("setProperty"), "H5Pset failed");
     }
 }
@@ -613,8 +640,19 @@ PropList::setProperty(const char *name, const char *charptr) const
 ///\param       strg - IN: Value for the property is a \c H5std_string
 // Programmer:  Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
-void
-PropList::setProperty(const char *name, H5std_string &strg) const
+void PropList::setProperty(const char* name, const H5std_string& strg) const
+{
+    setProperty(name, strg.c_str());
+}
+
+//--------------------------------------------------------------------------
+// Function:    PropList::setProperty
+///\brief       Deprecated due to missing const in prototype. (1.10.1)
+// Programmer:  Binh-Minh Ribler - March, 2017
+// Modification
+//              Planned for removal. -BMR, 2017/03/17 1.10.1
+//--------------------------------------------------------------------------
+void PropList::setProperty(const char* name, H5std_string& strg) const
 {
     setProperty(name, strg.c_str());
 }
@@ -628,8 +666,19 @@ PropList::setProperty(const char *name, H5std_string &strg) const
 ///\param       value - IN: Void pointer to the value for the property
 // Programmer:  Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
-void
-PropList::setProperty(const H5std_string &name, void *value) const
+void PropList::setProperty(const H5std_string& name, const void* value) const
+{
+    setProperty(name.c_str(), value);
+}
+
+//--------------------------------------------------------------------------
+// Function:    PropList::setProperty
+///\brief       Deprecated due to missing const in prototype. (1.10.1)
+// Programmer:  Binh-Minh Ribler - March, 2017
+// Modification
+//              Planned for removal. -BMR, 2017/03/17 1.10.1
+//--------------------------------------------------------------------------
+void PropList::setProperty(const H5std_string& name, void* value) const
 {
     setProperty(name.c_str(), value);
 }
@@ -643,8 +692,19 @@ PropList::setProperty(const H5std_string &name, void *value) const
 ///\param       strg - IN: Value for the property is a \c H5std_string
 // Programmer:  Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
-void
-PropList::setProperty(const H5std_string &name, H5std_string &strg) const
+void PropList::setProperty(const H5std_string& name, const H5std_string& strg) const
+{
+    setProperty(name.c_str(), strg.c_str());
+}
+
+//--------------------------------------------------------------------------
+// Function:    PropList::setProperty
+///\brief       Deprecated due to missing const in prototype. (1.10.1)
+// Programmer:  Binh-Minh Ribler - March, 2017
+// Modification
+//              Planned for removal. -BMR, 2017/03/17 1.10.1
+//--------------------------------------------------------------------------
+void PropList::setProperty(const H5std_string& name, H5std_string& strg) const
 {
     setProperty(name.c_str(), strg.c_str());
 }
@@ -658,8 +718,7 @@ PropList::setProperty(const H5std_string &name, H5std_string &strg) const
 ///\exception   H5::PropListIException
 // Programmer:  Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
-bool
-PropList::isAClass(const PropList &prop_class) const
+bool PropList::isAClass(const PropList& prop_class) const
 {
     htri_t ret_value = H5Pisa_class(id, prop_class.getId());
     if (ret_value > 0)
@@ -679,11 +738,11 @@ PropList::isAClass(const PropList &prop_class) const
 ///\exception   H5::PropListIException
 // Programmer:  Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
-void
-PropList::removeProp(const char *name) const
+void PropList::removeProp(const char *name) const
 {
     herr_t ret_value = H5Premove(id, name);
-    if (ret_value < 0) {
+    if (ret_value < 0)
+    {
         throw PropListIException(inMemFunc("removeProp"), "H5Premove failed");
     }
 }
@@ -696,8 +755,7 @@ PropList::removeProp(const char *name) const
 ///\param       name - IN: Name of property to remove - \c H5std_string
 // Programmer:  Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
-void
-PropList::removeProp(const H5std_string &name) const
+void PropList::removeProp(const H5std_string& name) const
 {
     removeProp(name.c_str());
 }
@@ -711,8 +769,7 @@ PropList::removeProp(const H5std_string &name) const
 ///\exception   H5::PropListIException
 // Programmer:  Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
-bool
-PropList::operator==(const PropList &rhs) const
+bool PropList::operator==(const PropList& rhs) const
 {
     htri_t ret_value = H5Pequal(id, rhs.getId());
     if (ret_value > 0)
@@ -732,15 +789,15 @@ PropList::operator==(const PropList &rhs) const
 ///\exception   H5::PropListIException
 // Programmer:  Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
-PropList
-PropList::getClassParent() const
+PropList PropList::getClassParent() const
 {
     hid_t class_id = H5Pget_class_parent(id);
-    if (class_id < 0) {
+    if (class_id < 0)
+    {
         throw PropListIException(inMemFunc("getClassParent"), "H5Pget_class_parent failed");
     }
     PropList pclass(class_id);
-    return (pclass);
+    return(pclass);
 }
 
 //--------------------------------------------------------------------------
@@ -758,8 +815,9 @@ PropList::~PropList()
     try {
         close();
     }
-    catch (Exception &close_error) {
+    catch (Exception& close_error) {
         cerr << "PropList::~PropList - " << close_error.getDetailMsg() << endl;
     }
 }
-} // namespace H5
+
+} // end namespace
