@@ -76,9 +76,8 @@ const H5std_string    FILE4("tfile4.h5");
  *                     cases.  Since there are no operator<< for 'long long'
  *                     or int64 in VS C++ ostream, I casted the hsize_t values
  *                     passed to verify_val to 'long' as well.  If problems
- *                     arises later, this will have to be specificly handled
+ *                     arises later, this will have to be specifically handled
  *                     with a special routine.
- *
  *-------------------------------------------------------------------------
  */
 static void test_file_create()
@@ -283,9 +282,8 @@ static void test_file_create()
  *                     cases.  Since there are no operator<< for 'long long'
  *                     or int64 in VS C++ ostream, I casted the hsize_t values
  *                     passed to verify_val to 'long' as well.  If problems
- *                     arises later, this will have to be specificly handled
+ *                     arises later, this will have to be specifically handled
  *                     with a special routine.
- *
  *-------------------------------------------------------------------------
  */
 static void test_file_open()
@@ -360,9 +358,6 @@ static void test_file_open()
  *
  * Programmer   Raymond Lu
  *              June, 2004
- *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 static void test_file_size()
@@ -415,6 +410,64 @@ static void test_file_size()
 
 }   // test_file_size()
 
+
+/*-------------------------------------------------------------------------
+ * Function:    test_file_num
+ *
+ * Purpose      Test file number.
+ *
+ * Return       None
+ *
+ * Programmer   Quincey Koziol
+ *              April, 2019
+ *-------------------------------------------------------------------------
+ */
+static void test_file_num()
+{
+    // Output message about test being performed
+    SUBTEST("File Number");
+
+    hid_t        fapl_id;
+    fapl_id = h5_fileaccess(); // in h5test.c, returns a file access template
+
+    try {
+        // Use the file access template id to create a file access prop.
+        // list object to pass in H5File::H5File
+        FileAccPropList fapl(fapl_id);
+
+        // Create two files
+        H5File file1(FILE1, H5F_ACC_TRUNC, FileCreatPropList::DEFAULT, fapl);
+        H5File file2(FILE2, H5F_ACC_TRUNC, FileCreatPropList::DEFAULT, fapl);
+
+        // Open the first file again
+        H5File file3(FILE1, H5F_ACC_RDWR);
+
+        // Get file numbers
+        unsigned long file_num1 = file1.getFileNum();
+        unsigned long file_num2 = file2.getFileNum();
+        unsigned long file_num3 = file3.getFileNum();
+
+        // Check file numbers
+        if (file_num1 == file_num2)
+            issue_fail_msg("test_file_num()", __LINE__, __FILE__, "getFileNum() returned wrong value");
+        if (file_num1 != file_num3)
+            issue_fail_msg("test_file_num()", __LINE__, __FILE__, "getFileNum() returned wrong value");
+
+        PASSED();
+    }   // end of try block
+
+    catch (Exception& E)
+    {
+        issue_fail_msg("test_file_num()", __LINE__, __FILE__, E.getCDetailMsg());
+    }
+
+    // use C test utility routine to close property list.
+    herr_t ret = H5Pclose(fapl_id);
+    if (ret < 0)
+        issue_fail_msg("test_file_num()", __LINE__, __FILE__, "H5Pclose failed");
+
+}   // test_file_num()
+
 
 /*-------------------------------------------------------------------------
  * Function:    test_file_name
@@ -425,9 +478,6 @@ static void test_file_size()
  *
  * Programmer   Binh-Minh Ribler
  *              July, 2004
- *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 const int        RANK = 2;
@@ -507,6 +557,15 @@ static void test_file_name()
 }   // test_file_name()
 
 
+/*-------------------------------------------------------------------------
+ *
+ * Function:    test_file_attribute
+ *
+ * Purpose      Test file attributes
+ *
+ * Return       None
+ *-------------------------------------------------------------------------
+ */
 const int        RANK1 = 1;
 const int        ATTR1_DIM1 = 3;
 const H5std_string        FILE5("tfattrs.h5");
@@ -618,11 +677,6 @@ static void test_file_attribute()
 }   // test_file_attribute()
 
 
-const H5std_string        FILE6("tfile5.h5");
-const H5std_string        ROOTGROUP("/");
-const H5std_string        GROUP1("/G1");
-const H5std_string        SUBGROUP3("/G1/G3");
-
 /*-------------------------------------------------------------------------
  * Function:    test_libver_bounds_real
  *
@@ -634,9 +688,13 @@ const H5std_string        SUBGROUP3("/G1/G3");
  *
  * Programmer   Binh-Minh Ribler (use C version)
  *              March, 2015
- *
  *-------------------------------------------------------------------------
  */
+const H5std_string        FILE6("tfile5.h5");
+const H5std_string        ROOTGROUP("/");
+const H5std_string        GROUP1("/G1");
+const H5std_string        SUBGROUP3("/G1/G3");
+
 static void test_libver_bounds_real(
                 H5F_libver_t libver_create, unsigned oh_vers_create,
                 H5F_libver_t libver_mod, unsigned oh_vers_mod)
@@ -657,8 +715,15 @@ static void test_libver_bounds_real(
     unsigned obj_version = file.childObjVersion(ROOTGROUP);
     verify_val(obj_version, oh_vers_create, "H5File::childObjVersion", __LINE__, __FILE__);
 
+    // Verify object header version another way
+    H5O_native_info_t ninfo;
+    HDmemset(&ninfo, 0, sizeof(ninfo));
+    file.getNativeObjinfo(ninfo, H5O_NATIVE_INFO_HDR);
+    verify_val(ninfo.hdr.version, oh_vers_create, "H5File::getNativeObjinfo", __LINE__, __FILE__);
+
     /*
-     * Reopen the file and make sure the root group still has the correct version
+     * Reopen the file and make sure the root group still has the correct
+     * version
      */
     file.close();
 
@@ -678,6 +743,11 @@ static void test_libver_bounds_real(
     obj_version = group.objVersion();
     verify_val(obj_version, oh_vers_mod, "Group::objVersion", __LINE__, __FILE__);
 
+    // Verify object header version another way
+    HDmemset(&ninfo, 0, sizeof(ninfo));
+    group.getNativeObjinfo(ninfo, H5O_NATIVE_INFO_HDR);
+    verify_val(ninfo.hdr.version, oh_vers_mod, "Group::getNativeObjinfo", __LINE__, __FILE__);
+
     group.close(); // close "/G1"
 
     /*
@@ -707,6 +777,7 @@ static void test_libver_bounds_real(
 
 } /* end test_libver_bounds_real() */
 
+
 /*-------------------------------------------------------------------------
  *
  * Function:    test_libver_bounds
@@ -718,7 +789,6 @@ static void test_libver_bounds_real(
  *
  * Programmer   Binh-Minh Ribler (use C version)
  *              March 2015
- *
  *-------------------------------------------------------------------------
  */
 static void test_libver_bounds()
@@ -731,9 +801,10 @@ static void test_libver_bounds()
     test_libver_bounds_real(H5F_LIBVER_LATEST, H5O_VERSION_2, H5F_LIBVER_EARLIEST, H5O_VERSION_2);
     PASSED();
 } /* end test_libver_bounds() */
+
 
 /*-------------------------------------------------------------------------
- * Function:        test_commonfg
+ * Function:    test_commonfg
  *
  * Purpose      Verify that H5File works as a root group.
  *
@@ -741,7 +812,6 @@ static void test_libver_bounds()
  *
  * Programmer   Binh-Minh Ribler (use C version)
  *              March, 2015
- *
  *-------------------------------------------------------------------------
  */
 static void test_commonfg()
@@ -793,9 +863,8 @@ static void test_commonfg()
     }
 
 } /* end test_commonfg() */
-
-const H5std_string        FILE7("tfile7.h5");
 
+
 /*-------------------------------------------------------------------------
  * Function:    test_file_info
  *
@@ -807,11 +876,12 @@ const H5std_string        FILE7("tfile7.h5");
  *
  * Programmer   Binh-Minh Ribler
  *              February, 2017
- *
  *-------------------------------------------------------------------------
  */
+const H5std_string FILE7("tfile7.h5");
 const hsize_t FSP_SIZE_DEF = 4096;
 const hsize_t FSP_SIZE512 = 512;
+
 static void test_file_info()
 {
     // Output message about test being performed
@@ -932,6 +1002,7 @@ static void test_file_info()
         issue_fail_msg("test_filespace_info()", __LINE__, __FILE__, E.getCDetailMsg());
     }
 }  /* test_file_info() */
+
 
 /*-------------------------------------------------------------------------
  * Function:    test_file
@@ -942,9 +1013,6 @@ static void test_file_info()
  *
  * Programmer   Binh-Minh Ribler (use C version)
  *              January 2001
- *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 extern "C"
@@ -956,6 +1024,7 @@ void test_file()
     test_file_create();      // Test file creation (also creation templates)
     test_file_open();        // Test file opening
     test_file_size();        // Test file size
+    test_file_num();         // Test file number
     test_file_name();        // Test getting file's name
     test_file_attribute();   // Test file attribute feature
     test_libver_bounds();    // Test format version
@@ -970,11 +1039,6 @@ void test_file()
  * Purpose      Cleanup temporary test files
  *
  * Return       none
- *
- * Programmer   (use C version)
- *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 #ifdef __cplusplus
