@@ -143,7 +143,7 @@ void writeToFilesChr(const char* c_typedef, const char* fortran_type, const char
 int main(void)
 {
   int i;
-  char chrA[32],chrB[32];
+  char chrA[64],chrB[64];
 
   int IntKinds[] = H5_FORTRAN_INTEGER_KINDS;
   int IntKinds_SizeOf[] = H5_FORTRAN_INTEGER_KINDS_SIZEOF;
@@ -153,7 +153,9 @@ int main(void)
   
   int FORTRAN_NUM_INTEGER_KINDS=H5_FORTRAN_NUM_INTEGER_KINDS;
   int H5_FORTRAN_NUM_REAL_KINDS;
+#if H5_FORTRAN_HAVE_C_LONG_DOUBLE!=0
   int found_long_double = 0;
+#endif
 
   /* Open target files */
   c_header = fopen(CFILE, "w");
@@ -347,8 +349,8 @@ int main(void)
 
   for(i=0;i<H5_FORTRAN_NUM_REAL_KINDS;i++) {
     if (RealKinds[i] > 0) {
-      sprintf(chrA, "Fortran_REAL_%s", Real_C_TYPES[i]);
-      sprintf(chrB, "real_%s_f", Real_C_TYPES[i]);
+      snprintf(chrA, sizeof(chrA), "Fortran_REAL_%s", Real_C_TYPES[i]);
+      snprintf(chrB, sizeof(chrB), "real_%s_f", Real_C_TYPES[i]);
       writeToFiles("float",chrA, chrB, RealKinds[i]);
     }
   }
@@ -414,13 +416,19 @@ int main(void)
     return -1;
   }
 
-  /* Need the buffer size for the fortran derive type 'hdset_reg_ref_t_f03'
+  /* Need the buffer size for the fortran derived type 'hdset_reg_ref_t_f03'
    * in order to be interoperable with C's structure, the C buffer size
    * H5R_DSET_REG_REF_BUF_SIZE is (sizeof(haddr_t)+4)
    */
-    
+
     fprintf(fort_header, "        INTEGER, PARAMETER :: H5R_DSET_REG_REF_BUF_SIZE_F = %u\n", H5_SIZEOF_HADDR_T + 4 );
 
+  /* Need the buffer size for the fortran derived type 'h5o_token_t'
+   * in order to be interoperable with C's structure.
+   */
+
+    fprintf(fort_header, "        INTEGER, PARAMETER :: H5O_MAX_TOKEN_SIZE_F = %u\n", H5O_MAX_TOKEN_SIZE);
+
   /* Close files */
   endCfile();
   endFfile();
