@@ -1,11 +1,12 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://www.hdfgroup.org/licenses.               *
+ * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -38,10 +39,11 @@ extern "C" {
  * Signature: (Ljava/lang/String;IJ)J
  */
 JNIEXPORT jlong JNICALL
-Java_hdf_hdf5lib_H5__1H5Fopen(JNIEnv *env, jclass clss, jstring name, jint flags, jlong access_id)
+Java_hdf_hdf5lib_H5__1H5Fopen
+    (JNIEnv *env, jclass clss, jstring name, jint flags, jlong access_id)
 {
     const char *fileName = NULL;
-    hid_t       status   = H5I_INVALID_HID;
+    hid_t       status = H5I_INVALID_HID;
 
     UNUSED(clss);
 
@@ -66,11 +68,11 @@ done:
  * Signature: (Ljava/lang/String;IJJ)J
  */
 JNIEXPORT jlong JNICALL
-Java_hdf_hdf5lib_H5__1H5Fcreate(JNIEnv *env, jclass clss, jstring name, jint flags, jlong create_id,
-                                jlong access_id)
+Java_hdf_hdf5lib_H5__1H5Fcreate
+    (JNIEnv *env, jclass clss, jstring name, jint flags, jlong create_id, jlong access_id)
 {
     const char *fileName = NULL;
-    hid_t       status   = H5I_INVALID_HID;
+    hid_t       status = H5I_INVALID_HID;
 
     UNUSED(clss);
 
@@ -95,7 +97,8 @@ done:
  * Signature: (JI)I
  */
 JNIEXPORT jint JNICALL
-Java_hdf_hdf5lib_H5_H5Fflush(JNIEnv *env, jclass clss, jlong object_id, jint scope)
+Java_hdf_hdf5lib_H5_H5Fflush
+    (JNIEnv *env, jclass clss, jlong object_id, jint scope)
 {
     herr_t retVal = FAIL;
 
@@ -114,11 +117,12 @@ done:
  * Signature: (J)Ljava/lang/String;
  */
 JNIEXPORT jstring JNICALL
-Java_hdf_hdf5lib_H5_H5Fget_1name(JNIEnv *env, jclass clss, jlong file_id)
+Java_hdf_hdf5lib_H5_H5Fget_1name
+    (JNIEnv *env, jclass clss, jlong file_id)
 {
-    jstring str = NULL;
-    ssize_t buf_size;
-    char   *namePtr = NULL;
+    jstring  str = NULL;
+    ssize_t  buf_size;
+    char    *namePtr = NULL;
 
     UNUSED(clss);
 
@@ -126,7 +130,7 @@ Java_hdf_hdf5lib_H5_H5Fget_1name(JNIEnv *env, jclass clss, jlong file_id)
     if ((buf_size = H5Fget_name((hid_t)file_id, NULL, 0)) < 0)
         H5_LIBRARY_ERROR(ENVONLY);
 
-    if (NULL == (namePtr = (char *)HDmalloc(sizeof(char) * (size_t)buf_size + 1)))
+    if (NULL == (namePtr = (char *) HDmalloc(sizeof(char) * (size_t)buf_size + 1)))
         H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Fget_name: malloc failed");
 
     if ((H5Fget_name((hid_t)file_id, namePtr, (size_t)buf_size + 1)) < 0)
@@ -149,13 +153,20 @@ done:
  * Signature: (Ljava/lang/String;)Z
  */
 JNIEXPORT jboolean JNICALL
-Java_hdf_hdf5lib_H5_H5Fis_1hdf5(JNIEnv *env, jclass clss, jstring name)
+Java_hdf_hdf5lib_H5_H5Fis_1hdf5
+    (JNIEnv *env, jclass clss, jstring name)
 {
+#ifndef H5_NO_DEPRECATED_SYMBOLS
     const char *fileName = NULL;
-    htri_t      bval     = JNI_FALSE;
+#endif
+    htri_t      bval = JNI_FALSE;
 
     UNUSED(clss);
 
+#ifdef H5_NO_DEPRECATED_SYMBOLS
+    UNUSED(name);
+    H5_UNIMPLEMENTED(ENVONLY, "H5Fis_hdf5: not implemented");
+#else
     if (NULL == name)
         H5_NULL_ARGUMENT_ERROR(ENVONLY, "H5Fis_hdf5: file name is NULL");
 
@@ -165,13 +176,47 @@ Java_hdf_hdf5lib_H5_H5Fis_1hdf5(JNIEnv *env, jclass clss, jstring name)
         H5_LIBRARY_ERROR(ENVONLY);
 
     bval = (bval > 0) ? JNI_TRUE : JNI_FALSE;
+#endif
+
+done:
+#ifndef H5_NO_DEPRECATED_SYMBOLS
+    if (fileName)
+        UNPIN_JAVA_STRING(ENVONLY, name, fileName);
+#endif
+
+    return (jboolean)bval;
+} /* end Java_hdf_hdf5lib_H5_H5Fis_1hdf5 */
+
+/*
+ * Class:     hdf_hdf5lib_H5
+ * Method:    H5Fis_accessible
+ * Signature: (Ljava/lang/String;J)Z
+ */
+JNIEXPORT jboolean JNICALL
+Java_hdf_hdf5lib_H5_H5Fis_1accessible
+    (JNIEnv *env, jclass clss, jstring name, jlong file_id)
+{
+    const char *fileName = NULL;
+    htri_t      bval = JNI_FALSE;
+
+    UNUSED(clss);
+
+    if (NULL == name)
+        H5_NULL_ARGUMENT_ERROR(ENVONLY, "H5Fis_accessible: file name is NULL");
+
+    PIN_JAVA_STRING(ENVONLY, name, fileName, NULL, "H5Fis_accessible: file name not pinned");
+
+    if ((bval = H5Fis_accessible(fileName, (hid_t)file_id)) < 0)
+        H5_LIBRARY_ERROR(ENVONLY);
+
+    bval = (bval > 0) ? JNI_TRUE : JNI_FALSE;
 
 done:
     if (fileName)
         UNPIN_JAVA_STRING(ENVONLY, name, fileName);
 
     return (jboolean)bval;
-} /* end Java_hdf_hdf5lib_H5_H5Fis_1hdf5 */
+} /* end Java_hdf_hdf5lib_H5_H5Fis_1accessible */
 
 /*
  * Class:     hdf_hdf5lib_H5
@@ -179,7 +224,8 @@ done:
  * Signature: (J)J
  */
 JNIEXPORT jlong JNICALL
-Java_hdf_hdf5lib_H5__1H5Fget_1create_1plist(JNIEnv *env, jclass clss, jlong file_id)
+Java_hdf_hdf5lib_H5__1H5Fget_1create_1plist
+    (JNIEnv *env, jclass clss, jlong file_id)
 {
     hid_t retVal = H5I_INVALID_HID;
 
@@ -198,7 +244,8 @@ done:
  * Signature: (J)J
  */
 JNIEXPORT jlong JNICALL
-Java_hdf_hdf5lib_H5__1H5Fget_1access_1plist(JNIEnv *env, jclass clss, jlong file_id)
+Java_hdf_hdf5lib_H5__1H5Fget_1access_1plist
+    (JNIEnv *env, jclass clss, jlong file_id)
 {
     hid_t retVal = H5I_INVALID_HID;
 
@@ -217,7 +264,8 @@ done:
  * Signature: (J)I
  */
 JNIEXPORT jint JNICALL
-Java_hdf_hdf5lib_H5_H5Fget_1intent(JNIEnv *env, jclass clss, jlong file_id)
+Java_hdf_hdf5lib_H5_H5Fget_1intent
+    (JNIEnv *env, jclass clss, jlong file_id)
 {
     unsigned intent = 0;
 
@@ -230,13 +278,34 @@ done:
     return (jint)intent;
 } /* end Java_hdf_hdf5lib_H5_H5Fget_1intent */
 
+/*
+ * Class:     hdf_hdf5lib_H5
+ * Method:    H5Fget_fileno
+ * Signature: (J)J
+ */
+JNIEXPORT jlong JNICALL
+Java_hdf_hdf5lib_H5_H5Fget_1fileno
+    (JNIEnv *env, jclass clss, jlong file_id)
+{
+    unsigned long fileno = 0;
+
+    UNUSED(clss);
+
+    if (H5Fget_fileno((hid_t)file_id, &fileno) < 0)
+        H5_LIBRARY_ERROR(ENVONLY);
+
+done:
+    return (jlong)fileno;
+} /* end Java_hdf_hdf5lib_H5_H5Fget_1fileno */
+
 /*
  * Class:     hdf_hdf5lib_H5
  * Method:    H5Fclose
  * Signature: (J)I
  */
 JNIEXPORT jint JNICALL
-Java_hdf_hdf5lib_H5__1H5Fclose(JNIEnv *env, jclass clss, jlong file_id)
+Java_hdf_hdf5lib_H5__1H5Fclose
+    (JNIEnv *env, jclass clss, jlong file_id)
 {
     herr_t status = FAIL;
 
@@ -255,11 +324,11 @@ done:
  * Signature: (JLjava/lang/String;JJ)I
  */
 JNIEXPORT jint JNICALL
-Java_hdf_hdf5lib_H5_H5Fmount(JNIEnv *env, jclass clss, jlong loc_id, jstring name, jlong child_id,
-                             jlong plist_id)
+Java_hdf_hdf5lib_H5_H5Fmount
+    (JNIEnv *env, jclass clss, jlong loc_id, jstring name, jlong child_id, jlong plist_id)
 {
     const char *fileName = NULL;
-    herr_t      status   = FAIL;
+    herr_t      status = FAIL;
 
     UNUSED(clss);
 
@@ -284,10 +353,11 @@ done:
  * Signature: (JLjava/lang/String;)I
  */
 JNIEXPORT jint JNICALL
-Java_hdf_hdf5lib_H5_H5Funmount(JNIEnv *env, jclass clss, jlong loc_id, jstring name)
+Java_hdf_hdf5lib_H5_H5Funmount
+    (JNIEnv *env, jclass clss, jlong loc_id, jstring name)
 {
     const char *fileName = NULL;
-    herr_t      status   = FAIL;
+    herr_t      status = FAIL;
 
     UNUSED(clss);
 
@@ -312,7 +382,8 @@ done:
  * Signature: (J)J
  */
 JNIEXPORT jlong JNICALL
-Java_hdf_hdf5lib_H5_H5Fget_1freespace(JNIEnv *env, jclass clss, jlong file_id)
+Java_hdf_hdf5lib_H5_H5Fget_1freespace
+    (JNIEnv *env, jclass clss, jlong file_id)
 {
     hssize_t ret_val = -1;
 
@@ -331,7 +402,8 @@ done:
  * Signature: (J)J
  */
 JNIEXPORT jlong JNICALL
-Java_hdf_hdf5lib_H5__1H5Freopen(JNIEnv *env, jclass clss, jlong file_id)
+Java_hdf_hdf5lib_H5__1H5Freopen
+    (JNIEnv *env, jclass clss, jlong file_id)
 {
     hid_t retVal = H5I_INVALID_HID;
 
@@ -350,15 +422,16 @@ done:
  * Signature: (JIJ[J)J
  */
 JNIEXPORT jlong JNICALL
-Java_hdf_hdf5lib_H5_H5Fget_1obj_1ids(JNIEnv *env, jclass clss, jlong file_id, jint types, jlong maxObjs,
-                                     jlongArray obj_id_list)
+Java_hdf_hdf5lib_H5_H5Fget_1obj_1ids
+    (JNIEnv *env, jclass clss, jlong file_id, jint types, jlong maxObjs,
+          jlongArray obj_id_list)
 {
-    jboolean isCopy;
-    ssize_t  ret_val = -1;
-    size_t   i;
-    jsize    rank;
-    jlong   *obj_id_listP = NULL;
-    hid_t   *id_list      = NULL;
+    jboolean  isCopy;
+    ssize_t   ret_val = -1;
+    size_t    i;
+    jsize     rank;
+    jlong    *obj_id_listP = NULL;
+    hid_t    *id_list = NULL;
 
     UNUSED(clss);
 
@@ -372,7 +445,7 @@ Java_hdf_hdf5lib_H5_H5Fget_1obj_1ids(JNIEnv *env, jclass clss, jlong file_id, ji
         H5_BAD_ARGUMENT_ERROR(ENVONLY, "H5Fget_obj_ids: obj_id_list length < 0");
     }
 
-    if (NULL == (id_list = (hid_t *)HDmalloc((size_t)rank * sizeof(hid_t))))
+    if (NULL == (id_list = (hid_t *) HDmalloc((size_t)rank * sizeof(hid_t))))
         H5_OUT_OF_MEMORY_ERROR(ENVONLY, "H5Fget_obj_ids: malloc failed");
 
     if ((ret_val = H5Fget_obj_ids((hid_t)file_id, (unsigned int)types, (size_t)maxObjs, id_list)) < 0)
@@ -397,7 +470,8 @@ done:
  * Signature: (JI)J
  */
 JNIEXPORT jlong JNICALL
-Java_hdf_hdf5lib_H5_H5Fget_1obj_1count(JNIEnv *env, jclass clss, jlong file_id, jint types)
+Java_hdf_hdf5lib_H5_H5Fget_1obj_1count
+    (JNIEnv *env, jclass clss, jlong file_id, jint types)
 {
     ssize_t ret_val = -1;
 
@@ -416,7 +490,8 @@ done:
  * Signature: (J)J
  */
 JNIEXPORT jlong JNICALL
-Java_hdf_hdf5lib_H5_H5Fget_1filesize(JNIEnv *env, jclass clss, jlong file_id)
+Java_hdf_hdf5lib_H5_H5Fget_1filesize
+    (JNIEnv *env, jclass clss, jlong file_id)
 {
     hsize_t size = 0;
 
@@ -426,7 +501,7 @@ Java_hdf_hdf5lib_H5_H5Fget_1filesize(JNIEnv *env, jclass clss, jlong file_id)
         H5_LIBRARY_ERROR(ENVONLY);
 
 done:
-    return (jlong)size;
+    return (jlong) size;
 } /* end Java_hdf_hdf5lib_H5_H5Fget_1filesize */
 
 /*
@@ -435,7 +510,8 @@ done:
  * Signature: (J)D
  */
 JNIEXPORT jdouble JNICALL
-Java_hdf_hdf5lib_H5_H5Fget_1mdc_1hit_1rate(JNIEnv *env, jclass clss, jlong file_id)
+Java_hdf_hdf5lib_H5_H5Fget_1mdc_1hit_1rate
+    (JNIEnv *env, jclass clss, jlong file_id)
 {
     double rate = 0.0;
 
@@ -454,13 +530,14 @@ done:
  * Signature: (J[J)I
  */
 JNIEXPORT jint JNICALL
-Java_hdf_hdf5lib_H5_H5Fget_1mdc_1size(JNIEnv *env, jclass clss, jlong file_id, jlongArray metadata_cache)
+Java_hdf_hdf5lib_H5_H5Fget_1mdc_1size
+    (JNIEnv *env, jclass clss, jlong file_id, jlongArray metadata_cache)
 {
-    jboolean isCopy;
-    size_t   max_size = 0, min_clean_size = 0, cur_size = 0;
-    jlong   *metadata_cache_ptr = NULL;
-    jsize    size               = 0;
-    int      cur_num_entries    = -1;
+    jboolean  isCopy;
+    size_t    max_size = 0, min_clean_size = 0, cur_size = 0;
+    jlong    *metadata_cache_ptr = NULL;
+    jsize     size = 0;
+    int       cur_num_entries = -1;
 
     UNUSED(clss);
 
@@ -478,8 +555,7 @@ Java_hdf_hdf5lib_H5_H5Fget_1mdc_1size(JNIEnv *env, jclass clss, jlong file_id, j
     if (H5Fget_mdc_size((hid_t)file_id, &max_size, &min_clean_size, &cur_size, &cur_num_entries) < 0)
         H5_LIBRARY_ERROR(ENVONLY);
 
-    PIN_LONG_ARRAY(ENVONLY, metadata_cache, metadata_cache_ptr, &isCopy,
-                   "H5Fget_mdc_size: metadata_cache array not pinned");
+    PIN_LONG_ARRAY(ENVONLY, metadata_cache, metadata_cache_ptr, &isCopy, "H5Fget_mdc_size: metadata_cache array not pinned");
 
     metadata_cache_ptr[0] = (jlong)max_size;
     metadata_cache_ptr[1] = (jlong)min_clean_size;
@@ -498,7 +574,8 @@ done:
  * Signature: (J)Lhdf/hdf5lib/structs/H5F_info2_t;
  */
 JNIEXPORT jobject JNICALL
-Java_hdf_hdf5lib_H5_H5Fget_1info(JNIEnv *env, jclass clss, jlong obj_id)
+Java_hdf_hdf5lib_H5_H5Fget_1info
+    (JNIEnv *env, jclass clss, jlong obj_id)
 {
     H5F_info2_t finfo;
     jobject     ihinfobuf;
@@ -527,8 +604,7 @@ Java_hdf_hdf5lib_H5_H5Fget_1info(JNIEnv *env, jclass clss, jlong obj_id)
     args[7].j = (jlong)finfo.sohm.hdr_size;
     args[8].l = ihinfobuf;
 
-    CALL_CONSTRUCTOR(ENVONLY, "hdf/hdf5lib/structs/H5F_info2_t",
-                     "(IJJIJJIJLhdf/hdf5lib/structs/H5_ih_info_t;)V", args, ret_obj);
+    CALL_CONSTRUCTOR(ENVONLY, "hdf/hdf5lib/structs/H5F_info2_t", "(IJJIJJIJLhdf/hdf5lib/structs/H5_ih_info_t;)V", args, ret_obj);
 
 done:
     return ret_obj;
@@ -540,7 +616,8 @@ done:
  * Signature: (J)V
  */
 JNIEXPORT void JNICALL
-Java_hdf_hdf5lib_H5_H5Freset_1mdc_1hit_1rate_1stats(JNIEnv *env, jclass clss, jlong file_id)
+Java_hdf_hdf5lib_H5_H5Freset_1mdc_1hit_1rate_1stats
+    (JNIEnv *env, jclass clss, jlong file_id)
 {
     UNUSED(clss);
 
@@ -557,7 +634,8 @@ done:
  * Signature: (J)V
  */
 JNIEXPORT void JNICALL
-Java_hdf_hdf5lib_H5_H5Fclear_1elink_1file_1cache(JNIEnv *env, jclass clss, jlong file_id)
+Java_hdf_hdf5lib_H5_H5Fclear_1elink_1file_1cache
+    (JNIEnv *env, jclass clss, jlong file_id)
 {
     UNUSED(clss);
 
@@ -574,7 +652,8 @@ done:
  * Signature: (J)V
  */
 JNIEXPORT void JNICALL
-Java_hdf_hdf5lib_H5_H5Fstart_1swmr_1write(JNIEnv *env, jclass clss, jlong file_id)
+Java_hdf_hdf5lib_H5_H5Fstart_1swmr_1write
+    (JNIEnv *env, jclass clss, jlong file_id)
 {
     UNUSED(clss);
 
@@ -591,7 +670,8 @@ done:
  * Signature: (J)V
  */
 JNIEXPORT void JNICALL
-Java_hdf_hdf5lib_H5_H5Fstart_1mdc_1logging(JNIEnv *env, jclass clss, jlong file_id)
+Java_hdf_hdf5lib_H5_H5Fstart_1mdc_1logging
+    (JNIEnv *env, jclass clss, jlong file_id)
 {
     UNUSED(clss);
 
@@ -608,7 +688,8 @@ done:
  * Signature: (J)V
  */
 JNIEXPORT void JNICALL
-Java_hdf_hdf5lib_H5_H5Fstop_1mdc_1logging(JNIEnv *env, jclass clss, jlong file_id)
+Java_hdf_hdf5lib_H5_H5Fstop_1mdc_1logging
+    (JNIEnv *env, jclass clss, jlong file_id)
 {
     UNUSED(clss);
 
@@ -625,14 +706,14 @@ done:
  * Signature: (J[Z)V
  */
 JNIEXPORT void JNICALL
-Java_hdf_hdf5lib_H5_H5Fget_1mdc_1logging_1status(JNIEnv *env, jclass clss, jlong file_id,
-                                                 jbooleanArray mdc_logging_status)
+Java_hdf_hdf5lib_H5_H5Fget_1mdc_1logging_1status
+    (JNIEnv *env, jclass clss, jlong file_id, jbooleanArray mdc_logging_status)
 {
-    jboolean *mdc_logging_status_ptr = NULL;
-    jboolean  isCopy;
-    hbool_t   is_enabled;
-    hbool_t   is_currently_logging;
-    jsize     size;
+    jboolean  *mdc_logging_status_ptr = NULL;
+    jboolean   isCopy;
+    hbool_t    is_enabled;
+    hbool_t    is_currently_logging;
+    jsize      size;
 
     UNUSED(clss);
 
@@ -650,8 +731,7 @@ Java_hdf_hdf5lib_H5_H5Fget_1mdc_1logging_1status(JNIEnv *env, jclass clss, jlong
     if (H5Fget_mdc_logging_status((hid_t)file_id, &is_enabled, &is_currently_logging) < 0)
         H5_LIBRARY_ERROR(ENVONLY);
 
-    PIN_BOOL_ARRAY(ENVONLY, mdc_logging_status, mdc_logging_status_ptr, &isCopy,
-                   "H5Fget_mdc_logging_status: mdc_logging_status array not pinned");
+    PIN_BOOL_ARRAY(ENVONLY, mdc_logging_status, mdc_logging_status_ptr, &isCopy, "H5Fget_mdc_logging_status: mdc_logging_status array not pinned");
 
     mdc_logging_status_ptr[0] = (jboolean)is_enabled;
     mdc_logging_status_ptr[1] = (jboolean)is_currently_logging;
@@ -669,7 +749,8 @@ done:
  * Signature: (JZ)V
  */
 JNIEXPORT void JNICALL
-Java_hdf_hdf5lib_H5_H5Fset_1dset_1no_1attrs_1hint(JNIEnv *env, jclass clss, jlong file_id, jboolean minimize)
+Java_hdf_hdf5lib_H5_H5Fset_1dset_1no_1attrs_1hint
+(JNIEnv *env, jclass clss, jlong file_id, jboolean minimize)
 {
     hbool_t minimize_val;
     herr_t  retVal = FAIL;
@@ -683,7 +764,7 @@ Java_hdf_hdf5lib_H5_H5Fset_1dset_1no_1attrs_1hint(JNIEnv *env, jclass clss, jlon
 
 done:
     return;
-} /* end Java_hdf_hdf5lib_H5_H5Fset_1dset_1no_1attrs_1hint */
+}
 
 /*
  * Class:     hdf_hdf5lib_H5
@@ -691,9 +772,10 @@ done:
  * Signature: (J)Z
  */
 JNIEXPORT jboolean JNICALL
-Java_hdf_hdf5lib_H5_H5Fget_1dset_1no_1attrs_1hint(JNIEnv *env, jclass clss, jlong file_id)
+Java_hdf_hdf5lib_H5_H5Fget_1dset_1no_1attrs_1hint
+(JNIEnv *env, jclass clss, jlong file_id)
 {
-    jboolean bval     = JNI_FALSE;
+    jboolean bval = JNI_FALSE;
     hbool_t  minimize = FALSE;
 
     UNUSED(clss);
@@ -702,11 +784,11 @@ Java_hdf_hdf5lib_H5_H5Fget_1dset_1no_1attrs_1hint(JNIEnv *env, jclass clss, jlon
         H5_LIBRARY_ERROR(ENVONLY);
 
     if (minimize == TRUE)
-        bval = JNI_TRUE;
+        bval =  JNI_TRUE;
 
 done:
     return bval;
-} /* end Java_hdf_hdf5lib_H5_H5Fget_1dset_1no_1attrs_1hint */
+}
 
 /*
  * Class:     hdf_hdf5lib_H5
@@ -714,7 +796,8 @@ done:
  * Signature: (JII)V
  */
 JNIEXPORT void JNICALL
-Java_hdf_hdf5lib_H5_H5Fset_1libver_1bounds(JNIEnv *env, jclass clss, jlong file_id, jint low, jint high)
+Java_hdf_hdf5lib_H5_H5Fset_1libver_1bounds
+    (JNIEnv *env, jclass clss, jlong file_id, jint low, jint high)
 {
     herr_t retVal = FAIL;
 
@@ -727,6 +810,7 @@ done:
     return;
 } /* end Java_hdf_hdf5lib_H5_H5Fset_1libver_1bounds */
 
+
 #ifdef __cplusplus
 } /* end extern "C" */
 #endif /* __cplusplus */
