@@ -6,54 +6,32 @@
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://www.hdfgroup.org/licenses.               *
+ * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-#define H5F_PACKAGE /*suppress error about including H5Fpkg	  */
+#include "H5Fmodule.h"          /* This source code file is part of the H5F module */
 
-/* Interface initialization */
-#define H5_INTERFACE_INIT_FUNC H5F_init_mount_interface
 
 /* Packages needed by this file... */
-#include "H5private.h"   /* Generic Functions                        */
-#include "H5ACprivate.h" /* Metadata cache                           */
-#include "H5Eprivate.h"  /* Error handling                           */
-#include "H5Fpkg.h"      /* File access                              */
-#include "H5Gprivate.h"  /* Groups                                   */
-#include "H5Iprivate.h"  /* IDs                                      */
-#include "H5MMprivate.h" /* Memory management                        */
-#include "H5Pprivate.h"  /* Property lists                           */
+#include "H5private.h"          /* Generic Functions                        */
+#include "H5ACprivate.h"        /* Metadata cache                           */
+#include "H5CXprivate.h"        /* API Contexts                             */
+#include "H5Eprivate.h"         /* Error handling                           */
+#include "H5Fpkg.h"             /* File access                              */
+#include "H5Gprivate.h"         /* Groups                                   */
+#include "H5Iprivate.h"         /* IDs                                      */
+#include "H5MMprivate.h"        /* Memory management                        */
+#include "H5Pprivate.h"         /* Property lists                           */
+#include "H5VLprivate.h"        /* Virtual Object Layer                     */
 
 /* PRIVATE PROTOTYPES */
-static herr_t H5F_mount(H5G_loc_t *loc, const char *name, H5F_t *child, hid_t plist_id, hid_t dxpl_id);
-static herr_t H5F_unmount(H5G_loc_t *loc, const char *name, hid_t dxpl_id);
-static void   H5F_mount_count_ids_recurse(H5F_t *f, unsigned *nopen_files, unsigned *nopen_objs);
-
-/*--------------------------------------------------------------------------
-NAME
-   H5F_init_mount_interface -- Initialize interface-specific information
-USAGE
-    herr_t H5F_init_mount_interface()
-
-RETURNS
-    Non-negative on success/Negative on failure
-DESCRIPTION
-    Initializes any interface-specific data or routines.  (Just calls
-    H5F_init() currently).
-
---------------------------------------------------------------------------*/
-static herr_t
-H5F_init_mount_interface(void)
-{
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
-
-    FUNC_LEAVE_NOAPI(H5F_init())
-} /* H5F_init_mount_interface() */
+static void H5F__mount_count_ids_recurse(H5F_t *f, unsigned *nopen_files, unsigned *nopen_objs);
 
+
 /*-------------------------------------------------------------------------
- * Function:	H5F_close_mounts
+ * Function:	H5F__close_mounts
  *
  * Purpose:	Close all mounts for a given file
  *
@@ -65,12 +43,12 @@ H5F_init_mount_interface(void)
  *-------------------------------------------------------------------------
  */
 herr_t
-H5F_close_mounts(H5F_t *f)
+H5F__close_mounts(H5F_t *f)
 {
-    unsigned u;                   /* Local index */
-    herr_t   ret_value = SUCCEED; /* Return value */
+    unsigned    u;                          /* Local index */
+    herr_t      ret_value = SUCCEED;        /* Return value */
 
-    FUNC_ENTER_NOAPI(FAIL)
+    FUNC_ENTER_PACKAGE
 
     HDassert(f);
 
@@ -80,21 +58,21 @@ H5F_close_mounts(H5F_t *f)
      */
     for (u = f->shared->mtab.nmounts - 1; u < f->shared->mtab.nmounts; u--) {
         /* Only unmount children mounted to this top level file structure */
-        if (f->shared->mtab.child[u].file->parent == f) {
+        if(f->shared->mtab.child[u].file->parent == f) {
             /* Detach the child file from the parent file */
             f->shared->mtab.child[u].file->parent = NULL;
 
             /* Close the internal group maintaining the mount point */
-            if (H5G_close(f->shared->mtab.child[u].group) < 0)
+            if(H5G_close(f->shared->mtab.child[u].group) < 0)
                 HGOTO_ERROR(H5E_FILE, H5E_CANTCLOSEOBJ, FAIL, "can't close child group")
 
             /* Close the child file */
-            if (H5F_try_close(f->shared->mtab.child[u].file) < 0)
+            if(H5F_try_close(f->shared->mtab.child[u].file, NULL) < 0)
                 HGOTO_ERROR(H5E_FILE, H5E_CANTCLOSEFILE, FAIL, "can't close child file")
 
             /* Eliminate the mount point from the table */
             HDmemmove(f->shared->mtab.child + u, f->shared->mtab.child + u + 1,
-                      (f->shared->mtab.nmounts - u - 1) * sizeof(f->shared->mtab.child[0]));
+                (f->shared->mtab.nmounts - u - 1) * sizeof(f->shared->mtab.child[0]));
             f->shared->mtab.nmounts--;
             f->nmounts--;
         }
@@ -104,10 +82,11 @@ H5F_close_mounts(H5F_t *f)
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5F_close_mounts() */
+} /* end H5F__close_mounts() */
 
+
 /*-------------------------------------------------------------------------
- * Function:	H5F_mount
+ * Function:	H5F__mount
  *
  * Purpose:	Mount file CHILD onto the group specified by LOC and NAME,
  *		using mount properties in PLIST.  CHILD must not already be
@@ -120,21 +99,21 @@ done:
  *
  *-------------------------------------------------------------------------
  */
-static herr_t
-H5F_mount(H5G_loc_t *loc, const char *name, H5F_t *child, hid_t H5_ATTR_UNUSED plist_id, hid_t dxpl_id)
+herr_t
+H5F__mount(H5G_loc_t *loc, const char *name, H5F_t *child, hid_t H5_ATTR_UNUSED plist_id)
 {
-    H5G_t     *mount_point = NULL;  /*mount point group		*/
-    H5F_t     *ancestor    = NULL;  /*ancestor files		*/
-    H5F_t     *parent      = NULL;  /*file containing mount point	*/
-    unsigned   lt, rt, md;          /*binary search indices		*/
-    int        cmp;                 /*binary search comparison value*/
-    H5G_loc_t  mp_loc;              /* entry of moint point to be opened */
-    H5G_name_t mp_path;             /* Mount point group hier. path */
-    H5O_loc_t  mp_oloc;             /* Mount point object location */
-    H5G_loc_t  root_loc;            /* Group location of root of file to mount */
-    herr_t     ret_value = SUCCEED; /* Return value */
+    H5G_t	*mount_point = NULL;	/*mount point group		*/
+    H5F_t	*ancestor = NULL;	/*ancestor files		*/
+    H5F_t	*parent = NULL;		/*file containing mount point	*/
+    unsigned	lt, rt, md;		/*binary search indices		*/
+    int		cmp;			/*binary search comparison value*/
+    H5G_loc_t   mp_loc;                 /* entry of moint point to be opened */
+    H5G_name_t  mp_path;            	/* Mount point group hier. path */
+    H5O_loc_t   mp_oloc;            	/* Mount point object location */
+    H5G_loc_t   root_loc;               /* Group location of root of file to mount */
+    herr_t      ret_value = SUCCEED;        /* Return value */
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_PACKAGE
 
     HDassert(loc);
     HDassert(name && *name);
@@ -152,24 +131,24 @@ H5F_mount(H5G_loc_t *loc, const char *name, H5F_t *child, hid_t H5_ATTR_UNUSED p
      * the parent & child files have the same file close degree, and
      * that the mount wouldn't introduce a cycle in the mount tree.
      */
-    if (child->parent)
+    if(child->parent)
         HGOTO_ERROR(H5E_FILE, H5E_MOUNT, FAIL, "file is already mounted")
-    if (H5G_loc_find(loc, name, &mp_loc /*out*/, H5P_DEFAULT, dxpl_id) < 0)
+    if(H5G_loc_find(loc, name, &mp_loc) < 0)
         HGOTO_ERROR(H5E_SYM, H5E_NOTFOUND, FAIL, "group not found")
     /* If the mount location is holding its file open, that file will close
      * and remove the mount as soon as we exit this function.  Prevent the
      * user from doing this.
      */
-    if (mp_loc.oloc->holding_file != FALSE)
+    if(mp_loc.oloc->holding_file != FALSE)
         HGOTO_ERROR(H5E_FILE, H5E_MOUNT, FAIL, "mount path cannot contain links to external files")
 
     /* Open the mount point group */
-    if (NULL == (mount_point = H5G_open(&mp_loc, dxpl_id)))
+    if(NULL == (mount_point = H5G_open(&mp_loc)))
         HGOTO_ERROR(H5E_FILE, H5E_MOUNT, FAIL, "mount point not found")
 
     /* Check if the proposed mount point group is already a mount point */
-    if (H5G_MOUNTED(mount_point))
-        HGOTO_ERROR(H5E_FILE, H5E_MOUNT, FAIL, "mount point is already in use")
+    if(H5G_MOUNTED(mount_point))
+	HGOTO_ERROR(H5E_FILE, H5E_MOUNT, FAIL, "mount point is already in use")
 
     /* Retrieve information from the mount point group */
     /* (Some of which we had before but was reset in mp_loc when the group
@@ -181,13 +160,13 @@ H5F_mount(H5G_loc_t *loc, const char *name, H5F_t *child, hid_t H5_ATTR_UNUSED p
     HDassert(mp_loc.oloc);
     mp_loc.path = H5G_nameof(mount_point);
     HDassert(mp_loc.path);
-    for (ancestor = parent; ancestor; ancestor = ancestor->parent) {
-        if (ancestor->shared == child->shared)
+    for(ancestor = parent; ancestor; ancestor = ancestor->parent) {
+        if(ancestor->shared == child->shared)
             HGOTO_ERROR(H5E_FILE, H5E_MOUNT, FAIL, "mount would introduce a cycle")
     }
 
     /* Make certain that the parent & child files have the same "file close degree" */
-    if (parent->shared->fc_degree != child->shared->fc_degree)
+    if(parent->shared->fc_degree != child->shared->fc_degree)
         HGOTO_ERROR(H5E_FILE, H5E_MOUNT, FAIL, "mounted file has different file close degree than parent")
 
     /*
@@ -196,78 +175,78 @@ H5F_mount(H5G_loc_t *loc, const char *name, H5F_t *child, hid_t H5_ATTR_UNUSED p
      * `md' will be the index where the child should be inserted.
      */
     lt = md = 0;
-    rt      = parent->shared->mtab.nmounts;
-    cmp     = -1;
-    while (lt < rt && cmp) {
-        H5O_loc_t *oloc; /*temporary symbol table entry	*/
+    rt = parent->shared->mtab.nmounts;
+    cmp = -1;
+    while(lt < rt && cmp) {
+        H5O_loc_t	*oloc;		/*temporary symbol table entry	*/
 
-        md   = (lt + rt) / 2;
+        md = (lt + rt) / 2;
         oloc = H5G_oloc(parent->shared->mtab.child[md].group);
-        cmp  = H5F_addr_cmp(mp_loc.oloc->addr, oloc->addr);
-        if (cmp < 0)
+        cmp = H5F_addr_cmp(mp_loc.oloc->addr, oloc->addr);
+        if(cmp < 0)
             rt = md;
-        else if (cmp > 0)
+        else if(cmp > 0)
             lt = md + 1;
     }
-    if (cmp > 0)
+    if(cmp > 0)
         md++;
-    if (!cmp)
+    if(!cmp)
         HGOTO_ERROR(H5E_FILE, H5E_MOUNT, FAIL, "mount point is already in use")
 
     /* Make room in the table */
-    if (parent->shared->mtab.nmounts >= parent->shared->mtab.nalloc) {
-        unsigned     n = MAX(16, 2 * parent->shared->mtab.nalloc);
-        H5F_mount_t *x = (H5F_mount_t *)H5MM_realloc(parent->shared->mtab.child,
-                                                     n * sizeof(parent->shared->mtab.child[0]));
+    if(parent->shared->mtab.nmounts >= parent->shared->mtab.nalloc) {
+        unsigned n = MAX(16, 2 * parent->shared->mtab.nalloc);
+        H5F_mount_t *x = (H5F_mount_t *)H5MM_realloc(parent->shared->mtab.child, n * sizeof(parent->shared->mtab.child[0]));
 
-        if (!x)
+        if(!x)
             HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed for mount table")
-        parent->shared->mtab.child  = x;
+        parent->shared->mtab.child = x;
         parent->shared->mtab.nalloc = n;
     }
 
     /* Insert into table */
     HDmemmove(parent->shared->mtab.child + md + 1, parent->shared->mtab.child + md,
-              (parent->shared->mtab.nmounts - md) * sizeof(parent->shared->mtab.child[0]));
+            (parent->shared->mtab.nmounts-md) * sizeof(parent->shared->mtab.child[0]));
     parent->shared->mtab.nmounts++;
     parent->nmounts++;
     parent->shared->mtab.child[md].group = mount_point;
-    parent->shared->mtab.child[md].file  = child;
-    child->parent                        = parent;
+    parent->shared->mtab.child[md].file = child;
+    child->parent = parent;
 
     /* Set the group's mountpoint flag */
-    if (H5G_mount(parent->shared->mtab.child[md].group) < 0)
+    if(H5G_mount(parent->shared->mtab.child[md].group) < 0)
         HGOTO_ERROR(H5E_FILE, H5E_CANTCLOSEOBJ, FAIL, "unable to set group mounted flag")
 
     /* Get the group location for the root group in the file to unmount */
-    if (NULL == (root_loc.oloc = H5G_oloc(child->shared->root_grp)))
+    if(NULL == (root_loc.oloc = H5G_oloc(child->shared->root_grp)))
         HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "unable to get object location for root group")
-    if (NULL == (root_loc.path = H5G_nameof(child->shared->root_grp)))
+    if(NULL == (root_loc.path = H5G_nameof(child->shared->root_grp)))
         HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "unable to get path for root group")
 
     /* Search the open IDs and replace names for mount operation */
     /* We pass H5G_UNKNOWN as object type; search all IDs */
-    if (H5G_name_replace(NULL, H5G_NAME_MOUNT, mp_loc.oloc->file, mp_loc.path->full_path_r,
-                         root_loc.oloc->file, root_loc.path->full_path_r, dxpl_id) < 0)
+    if(H5G_name_replace(NULL, H5G_NAME_MOUNT, mp_loc.oloc->file,
+            mp_loc.path->full_path_r, root_loc.oloc->file, root_loc.path->full_path_r) < 0)
         HGOTO_ERROR(H5E_FILE, H5E_MOUNT, FAIL, "unable to replace name")
 
 done:
-    if (ret_value < 0) {
-        if (mount_point) {
-            if (H5G_close(mount_point) < 0)
+    if(ret_value < 0) {
+        if(mount_point) {
+            if(H5G_close(mount_point) < 0)
                 HDONE_ERROR(H5E_FILE, H5E_CANTCLOSEOBJ, FAIL, "unable to close mounted group")
         }
         else {
-            if (H5G_loc_free(&mp_loc) < 0)
+            if(H5G_loc_free(&mp_loc) < 0)
                 HDONE_ERROR(H5E_SYM, H5E_CANTRELEASE, FAIL, "unable to free mount location")
         }
     }
 
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5F_mount() */
+} /* end H5F__mount() */
 
+
 /*-------------------------------------------------------------------------
- * Function:	H5F_unmount
+ * Function:	H5F__unmount
  *
  * Purpose:	Unmount the child which is mounted at the group specified by
  *		LOC and NAME or fail if nothing is mounted there.  Neither
@@ -284,22 +263,22 @@ done:
  *
  *-------------------------------------------------------------------------
  */
-static herr_t
-H5F_unmount(H5G_loc_t *loc, const char *name, hid_t dxpl_id)
+herr_t
+H5F__unmount(H5G_loc_t *loc, const char *name)
 {
-    H5G_t     *child_group = NULL;   /* Child's group in parent mtab	*/
-    H5F_t     *child       = NULL;   /*mounted file			*/
-    H5F_t     *parent      = NULL;   /*file where mounted		*/
-    H5O_loc_t *mnt_oloc;             /* symbol table entry for root of mounted file */
-    H5G_name_t mp_path;              /* Mount point group hier. path */
-    H5O_loc_t  mp_oloc;              /* Mount point object location  */
-    H5G_loc_t  mp_loc;               /* entry used to open mount point*/
-    hbool_t    mp_loc_setup = FALSE; /* Whether mount point location is set up */
-    H5G_loc_t  root_loc;             /* Group location of root of file to unmount */
-    int        child_idx;            /* Index of child in parent's mtab */
-    herr_t     ret_value = SUCCEED;  /*return value			*/
+    H5G_t	*child_group = NULL;	/* Child's group in parent mtab	*/
+    H5F_t	*child = NULL;		/*mounted file			*/
+    H5F_t	*parent = NULL;		/*file where mounted		*/
+    H5O_loc_t   *mnt_oloc;            	/* symbol table entry for root of mounted file */
+    H5G_name_t  mp_path;            	/* Mount point group hier. path */
+    H5O_loc_t   mp_oloc;            	/* Mount point object location  */
+    H5G_loc_t   mp_loc;                 /* entry used to open mount point*/
+    hbool_t     mp_loc_setup = FALSE;   /* Whether mount point location is set up */
+    H5G_loc_t   root_loc;               /* Group location of root of file to unmount */
+    int         child_idx;              /* Index of child in parent's mtab */
+    herr_t	ret_value = SUCCEED;	/*return value			*/
 
-    FUNC_ENTER_NOAPI_NOINIT
+    FUNC_ENTER_PACKAGE
 
     HDassert(loc);
     HDassert(name && *name);
@@ -314,23 +293,23 @@ H5F_unmount(H5G_loc_t *loc, const char *name, hid_t dxpl_id)
      * If we get the root group and the file has a parent in the mount tree,
      * then we must have found the mount point.
      */
-    if (H5G_loc_find(loc, name, &mp_loc /*out*/, H5P_DEFAULT, dxpl_id) < 0)
+    if(H5G_loc_find(loc, name, &mp_loc/*out*/) < 0)
         HGOTO_ERROR(H5E_SYM, H5E_NOTFOUND, FAIL, "group not found")
     mp_loc_setup = TRUE;
-    child        = mp_loc.oloc->file;
-    mnt_oloc     = H5G_oloc(child->shared->root_grp);
-    child_idx    = -1;
+    child = mp_loc.oloc->file;
+    mnt_oloc = H5G_oloc(child->shared->root_grp);
+    child_idx = -1;
 
-    if (child->parent && H5F_addr_eq(mp_oloc.addr, mnt_oloc->addr)) {
-        unsigned u; /*counters			*/
+    if(child->parent && H5F_addr_eq(mp_oloc.addr, mnt_oloc->addr)) {
+        unsigned	u;		/*counters			*/
 
         /*
          * We've been given the root group of the child.  We do a reverse
          * lookup in the parent's mount table to find the correct entry.
          */
         parent = child->parent;
-        for (u = 0; u < parent->shared->mtab.nmounts; u++) {
-            if (parent->shared->mtab.child[u].file->shared == child->shared) {
+        for(u = 0; u < parent->shared->mtab.nmounts; u++) {
+            if(parent->shared->mtab.child[u].file->shared == child->shared) {
                 /* Found the correct index */
                 child_idx = (int)u;
                 break;
@@ -338,37 +317,37 @@ H5F_unmount(H5G_loc_t *loc, const char *name, hid_t dxpl_id)
         }
     }
     else {
-        unsigned lt, rt, md = 0; /*binary search indices		*/
-        int      cmp;            /*binary search comparison value*/
+        unsigned lt, rt, md = 0;        /*binary search indices		*/
+        int 	cmp;		        /*binary search comparison value*/
 
         /* We've been given the mount point in the parent.  We use a binary
          * search in the parent to locate the mounted file, if any.
          */
         parent = child; /*we guessed wrong*/
-        lt     = 0;
-        rt     = parent->shared->mtab.nmounts;
-        cmp    = -1;
+        lt = 0;
+        rt = parent->shared->mtab.nmounts;
+        cmp = -1;
 
-        while (lt < rt && cmp) {
-            md       = (lt + rt) / 2;
+        while(lt < rt && cmp) {
+            md = (lt + rt) / 2;
             mnt_oloc = H5G_oloc(parent->shared->mtab.child[md].group);
-            cmp      = H5F_addr_cmp(mp_oloc.addr, mnt_oloc->addr);
-            if (cmp < 0)
+            cmp = H5F_addr_cmp(mp_oloc.addr, mnt_oloc->addr);
+            if (cmp<0)
                 rt = md;
             else
                 lt = md + 1;
         }
 
-        if (cmp)
+        if(cmp)
             HGOTO_ERROR(H5E_FILE, H5E_MOUNT, FAIL, "not a mount point")
 
         /* Found the correct index, set the info about the child */
         child_idx = (int)md;
         H5G_loc_free(&mp_loc);
         mp_loc_setup = FALSE;
-        mp_loc.oloc  = mnt_oloc;
-        mp_loc.path  = H5G_nameof(parent->shared->mtab.child[md].group);
-        child        = parent->shared->mtab.child[child_idx].file;
+        mp_loc.oloc = mnt_oloc;
+        mp_loc.path = H5G_nameof(parent->shared->mtab.child[md].group);
+        child = parent->shared->mtab.child[child_idx].file;
 
         /* Set the parent to be the actual parent of the discovered child.
          * Could be different due to the shared mount table. */
@@ -380,43 +359,42 @@ H5F_unmount(H5G_loc_t *loc, const char *name, hid_t dxpl_id)
     child_group = parent->shared->mtab.child[child_idx].group;
 
     /* Get the group location for the root group in the file to unmount */
-    if (NULL == (root_loc.oloc = H5G_oloc(child->shared->root_grp)))
+    if(NULL == (root_loc.oloc = H5G_oloc(child->shared->root_grp)))
         HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "unable to get object location for root group")
-    if (NULL == (root_loc.path = H5G_nameof(child->shared->root_grp)))
+    if(NULL == (root_loc.path = H5G_nameof(child->shared->root_grp)))
         HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "unable to get path for root group")
 
     /* Search the open IDs replace names to reflect unmount operation */
-    if (H5G_name_replace(NULL, H5G_NAME_UNMOUNT, mp_loc.oloc->file, mp_loc.path->full_path_r,
-                         root_loc.oloc->file, root_loc.path->full_path_r, dxpl_id) < 0)
+    if(H5G_name_replace(NULL, H5G_NAME_UNMOUNT, mp_loc.oloc->file,
+            mp_loc.path->full_path_r, root_loc.oloc->file, root_loc.path->full_path_r) < 0)
         HGOTO_ERROR(H5E_SYM, H5E_CANTINIT, FAIL, "unable to replace name")
 
     /* Eliminate the mount point from the table */
-    HDmemmove(parent->shared->mtab.child + (unsigned)child_idx,
-              (parent->shared->mtab.child + (unsigned)child_idx) + 1,
-              ((parent->shared->mtab.nmounts - (unsigned)child_idx) - 1) *
-                  sizeof(parent->shared->mtab.child[0]));
+    HDmemmove(parent->shared->mtab.child + (unsigned)child_idx, (parent->shared->mtab.child + (unsigned)child_idx) + 1,
+            ((parent->shared->mtab.nmounts - (unsigned)child_idx) - 1) * sizeof(parent->shared->mtab.child[0]));
     parent->shared->mtab.nmounts -= 1;
     parent->nmounts -= 1;
 
     /* Unmount the child file from the parent file */
-    if (H5G_unmount(child_group) < 0)
+    if(H5G_unmount(child_group) < 0)
         HGOTO_ERROR(H5E_FILE, H5E_CANTCLOSEOBJ, FAIL, "unable to reset group mounted flag")
-    if (H5G_close(child_group) < 0)
+    if(H5G_close(child_group) < 0)
         HGOTO_ERROR(H5E_FILE, H5E_CANTCLOSEOBJ, FAIL, "unable to close unmounted group")
 
     /* Detach child file from parent & see if it should close */
     child->parent = NULL;
-    if (H5F_try_close(child) < 0)
+    if(H5F_try_close(child, NULL) < 0)
         HGOTO_ERROR(H5E_FILE, H5E_CANTCLOSEFILE, FAIL, "unable to close unmounted file")
 
 done:
     /* Free the mount point location's information, if it's been set up */
-    if (mp_loc_setup)
+    if(mp_loc_setup)
         H5G_loc_free(&mp_loc);
 
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5F_unmount() */
+} /* end H5F__unmount() */
 
+
 /*-------------------------------------------------------------------------
  * Function:	H5F_is_mount
  *
@@ -433,13 +411,13 @@ done:
 hbool_t
 H5F_is_mount(const H5F_t *file)
 {
-    hbool_t ret_value = FALSE; /* Return value */
+    hbool_t ret_value = FALSE;          /* Return value */
 
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
     HDassert(file);
 
-    if (file->parent != NULL)
+    if(file->parent != NULL)
         ret_value = TRUE;
     else
         ret_value = FALSE;
@@ -447,6 +425,7 @@ H5F_is_mount(const H5F_t *file)
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5F_is_mount() */
 
+
 /*-------------------------------------------------------------------------
  * Function:    H5Fmount
  *
@@ -460,33 +439,57 @@ H5F_is_mount(const H5F_t *file)
 herr_t
 H5Fmount(hid_t loc_id, const char *name, hid_t child_id, hid_t plist_id)
 {
-    H5G_loc_t loc;
-    H5F_t    *child     = NULL;
-    herr_t    ret_value = SUCCEED; /* Return value */
+    H5VL_object_t  *loc_vol_obj = NULL;         /* Parent object        */
+    H5VL_object_t  *child_vol_obj = NULL;       /* Child object         */
+    H5I_type_t      loc_type;                   /* ID type of location  */
+    H5I_type_t      child_type;                 /* ID type of child     */
+    herr_t          ret_value = SUCCEED;        /* Return value         */
 
     FUNC_ENTER_API(FAIL)
     H5TRACE4("e", "i*sii", loc_id, name, child_id, plist_id);
 
     /* Check arguments */
-    if (H5G_loc(loc_id, &loc) < 0)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a location")
-    if (!name || !*name)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "no name")
-    if (NULL == (child = (H5F_t *)H5I_object_verify(child_id, H5I_FILE)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a file")
-    if (H5P_DEFAULT == plist_id)
+    loc_type = H5I_get_type(loc_id);
+    if(H5I_FILE != loc_type && H5I_GROUP != loc_type)
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "loc_id parameter not a file or group ID")
+    if(!name)
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "name parameter cannot be NULL")
+    if(!*name)
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "name parameter cannot be the empty string")
+    child_type = H5I_get_type(child_id);
+    if(H5I_FILE != child_type)
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "child_id parameter not a file ID")
+    if(H5P_DEFAULT == plist_id)
         plist_id = H5P_FILE_MOUNT_DEFAULT;
-    else if (TRUE != H5P_isa_class(plist_id, H5P_FILE_MOUNT))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not property list")
+    else
+        if(TRUE != H5P_isa_class(plist_id, H5P_FILE_MOUNT))
+            HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "plist_id is not a file mount property list ID")
 
-    /* Do the mount */
-    if (H5F_mount(&loc, name, child, plist_id, H5AC_dxpl_id) < 0)
+    /* Set up collective metadata if appropriate */
+    if(H5CX_set_loc(loc_id) < 0)
+        HGOTO_ERROR(H5E_FILE, H5E_CANTSET, FAIL, "can't set collective metadata read info")
+
+    /* Get the location object */
+    if(NULL == (loc_vol_obj = (H5VL_object_t *)H5I_object(loc_id)))
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "could not get location object")
+
+    /* Get the child object */
+    if(NULL == (child_vol_obj = (H5VL_object_t *)H5I_object(child_id)))
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "could not get child object")
+
+    /* Check if both objects are associated with the same VOL connector */
+    if(loc_vol_obj->connector->cls->value != child_vol_obj->connector->cls->value)
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "Can't mount file onto object from different VOL connector")
+
+    /* Perform the mount operation */
+    if(H5VL_file_specific(loc_vol_obj, H5VL_FILE_MOUNT, H5P_DATASET_XFER_DEFAULT, H5_REQUEST_NULL, (int)loc_type, name, child_vol_obj->data, plist_id) < 0)
         HGOTO_ERROR(H5E_FILE, H5E_MOUNT, FAIL, "unable to mount file")
 
 done:
     FUNC_LEAVE_API(ret_value)
 } /* end H5Fmount() */
 
+
 /*-------------------------------------------------------------------------
  * Function:    H5Funmount
  *
@@ -506,28 +509,41 @@ done:
 herr_t
 H5Funmount(hid_t loc_id, const char *name)
 {
-    H5G_loc_t loc;
-    herr_t    ret_value = SUCCEED; /* Return value */
+    H5VL_object_t  *vol_obj = NULL;             /* Parent object        */
+    H5I_type_t      loc_type;                   /* ID type of location  */
+    herr_t          ret_value = SUCCEED;        /* Return value         */
 
     FUNC_ENTER_API(FAIL)
     H5TRACE2("e", "i*s", loc_id, name);
 
     /* Check arguments */
-    if (H5G_loc(loc_id, &loc) < 0)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a location")
-    if (!name || !*name)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "no name")
+    loc_type = H5I_get_type(loc_id);
+    if(H5I_FILE != loc_type && H5I_GROUP != loc_type)
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "loc_id parameter not a file or group ID")
+    if(!name)
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "name parameter cannot be NULL")
+    if(!*name)
+        HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "name parameter cannot be the empty string")
+
+    /* Set up collective metadata if appropriate */
+    if(H5CX_set_loc(loc_id) < 0)
+        HGOTO_ERROR(H5E_FILE, H5E_CANTSET, FAIL, "can't set collective metadata read info")
+
+    /* Get the location object */
+    if(NULL == (vol_obj = (H5VL_object_t *)H5I_object(loc_id)))
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "could not get location object")
 
     /* Perform the unmount operation */
-    if (H5F_unmount(&loc, name, H5AC_dxpl_id) < 0)
+    if(H5VL_file_specific(vol_obj, H5VL_FILE_UNMOUNT, H5P_DATASET_XFER_DEFAULT, H5_REQUEST_NULL, (int)loc_type, name) < 0)
         HGOTO_ERROR(H5E_FILE, H5E_MOUNT, FAIL, "unable to unmount file")
 
 done:
     FUNC_LEAVE_API(ret_value)
 } /* end H5Funmount() */
 
+
 /*-------------------------------------------------------------------------
- * Function:    H5F_mount_count_ids_recurse
+ * Function:    H5F__mount_count_ids_recurse
  *
  * Purpose:     Helper routine for counting number of open IDs in mount
  *              hierarchy.
@@ -540,11 +556,11 @@ done:
  *-------------------------------------------------------------------------
  */
 static void
-H5F_mount_count_ids_recurse(H5F_t *f, unsigned *nopen_files, unsigned *nopen_objs)
+H5F__mount_count_ids_recurse(H5F_t *f, unsigned *nopen_files, unsigned *nopen_objs)
 {
-    unsigned u; /* Local index value */
+    unsigned u;                         /* Local index value */
 
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_STATIC_NOERR
 
     /* Sanity check */
     HDassert(f);
@@ -552,7 +568,7 @@ H5F_mount_count_ids_recurse(H5F_t *f, unsigned *nopen_files, unsigned *nopen_obj
     HDassert(nopen_objs);
 
     /* If this file is still open, increment number of file IDs open */
-    if (f->file_id > 0)
+    if(H5F_ID_EXISTS(f))
         *nopen_files += 1;
 
     /* Increment number of open objects in file
@@ -562,22 +578,23 @@ H5F_mount_count_ids_recurse(H5F_t *f, unsigned *nopen_files, unsigned *nopen_obj
     *nopen_objs += (f->nopen_objs - f->nmounts);
 
     /* Iterate over files mounted in this file and add in their open ID counts also */
-    for (u = 0; u < f->shared->mtab.nmounts; u++) {
+    for(u = 0; u < f->shared->mtab.nmounts; u++) {
         /* Only recurse on children mounted to this top level file structure */
-        if (f->shared->mtab.child[u].file->parent == f) {
+        if(f->shared->mtab.child[u].file->parent == f) {
             /* Increment the open object count if the mount point group has an open ID */
-            if (H5G_get_shared_count(f->shared->mtab.child[u].group) > 1)
+            if(H5G_get_shared_count(f->shared->mtab.child[u].group) > 1)
                 *nopen_objs += 1;
 
-            H5F_mount_count_ids_recurse(f->shared->mtab.child[u].file, nopen_files, nopen_objs);
+            H5F__mount_count_ids_recurse(f->shared->mtab.child[u].file, nopen_files, nopen_objs);
         }
     }
 
     FUNC_LEAVE_NOAPI_VOID
-} /* end H5F_mount_count_ids_recurse() */
+} /* end H5F__mount_count_ids_recurse() */
 
+
 /*-------------------------------------------------------------------------
- * Function:    H5F_mount_count_ids
+ * Function:    H5F__mount_count_ids
  *
  * Purpose:     Count the number of open file & object IDs in a mount hierarchy
  *
@@ -589,9 +606,9 @@ H5F_mount_count_ids_recurse(H5F_t *f, unsigned *nopen_files, unsigned *nopen_obj
  *-------------------------------------------------------------------------
  */
 herr_t
-H5F_mount_count_ids(H5F_t *f, unsigned *nopen_files, unsigned *nopen_objs)
+H5F__mount_count_ids(H5F_t *f, unsigned *nopen_files, unsigned *nopen_objs)
 {
-    FUNC_ENTER_NOAPI_NOINIT_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
     /* Sanity check */
     HDassert(f);
@@ -599,15 +616,16 @@ H5F_mount_count_ids(H5F_t *f, unsigned *nopen_files, unsigned *nopen_objs)
     HDassert(nopen_objs);
 
     /* Find the top file in the mounting hierarchy */
-    while (f->parent)
+    while(f->parent)
         f = f->parent;
 
     /* Count open IDs in the hierarchy */
-    H5F_mount_count_ids_recurse(f, nopen_files, nopen_objs);
+    H5F__mount_count_ids_recurse(f, nopen_files, nopen_objs);
 
     FUNC_LEAVE_NOAPI(SUCCEED)
-} /* end H5F_mount_count_ids() */
+} /* end H5F__mount_count_ids() */
 
+
 /*-------------------------------------------------------------------------
  * Function:	H5F_flush_mounts_recurse
  *
@@ -621,11 +639,11 @@ H5F_mount_count_ids(H5F_t *f, unsigned *nopen_files, unsigned *nopen_objs)
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5F_flush_mounts_recurse(H5F_t *f, hid_t dxpl_id)
+H5F_flush_mounts_recurse(H5F_t *f)
 {
-    unsigned nerrors = 0;         /* Errors from recursive flushes */
-    unsigned u;                   /* Index variable */
-    herr_t   ret_value = SUCCEED; /* Return value */
+    unsigned	nerrors = 0;            /* Errors from recursive flushes */
+    unsigned    u;                      /* Index variable */
+    herr_t      ret_value = SUCCEED;    /* Return value */
 
     FUNC_ENTER_NOAPI_NOINIT
 
@@ -633,22 +651,23 @@ H5F_flush_mounts_recurse(H5F_t *f, hid_t dxpl_id)
     HDassert(f);
 
     /* Flush all child files, not stopping for errors */
-    for (u = 0; u < f->shared->mtab.nmounts; u++)
-        if (H5F_flush_mounts_recurse(f->shared->mtab.child[u].file, dxpl_id) < 0)
+    for(u = 0; u < f->shared->mtab.nmounts; u++)
+        if(H5F_flush_mounts_recurse(f->shared->mtab.child[u].file) < 0)
             nerrors++;
 
     /* Call the "real" flush routine, for this file */
-    if (H5F_flush(f, dxpl_id, FALSE) < 0)
+    if(H5F__flush(f) < 0)
         HGOTO_ERROR(H5E_FILE, H5E_CANTFLUSH, FAIL, "unable to flush file's cached information")
 
     /* Check flush errors for children - errors are already on the stack */
-    if (nerrors)
+    if(nerrors)
         HGOTO_ERROR(H5E_FILE, H5E_CANTFLUSH, FAIL, "unable to flush file's child mounts")
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5F_flush_mounts_recurse() */
 
+
 /*-------------------------------------------------------------------------
  * Function:    H5F_flush_mounts
  *
@@ -662,9 +681,9 @@ done:
  *-------------------------------------------------------------------------
  */
 herr_t
-H5F_flush_mounts(H5F_t *f, hid_t dxpl_id)
+H5F_flush_mounts(H5F_t *f)
 {
-    herr_t ret_value = SUCCEED; /* Return value */
+    herr_t      ret_value = SUCCEED;       /* Return value */
 
     FUNC_ENTER_NOAPI(FAIL)
 
@@ -672,17 +691,18 @@ H5F_flush_mounts(H5F_t *f, hid_t dxpl_id)
     HDassert(f);
 
     /* Find the top file in the mount hierarchy */
-    while (f->parent)
+    while(f->parent)
         f = f->parent;
 
     /* Flush the mounted file hierarchy */
-    if (H5F_flush_mounts_recurse(f, dxpl_id) < 0)
+    if(H5F_flush_mounts_recurse(f) < 0)
         HGOTO_ERROR(H5E_FILE, H5E_CANTFLUSH, FAIL, "unable to flush mounted file hierarchy")
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5F_flush_mounts() */
 
+
 /*-------------------------------------------------------------------------
  * Function:	H5F_traverse_mount
  *
@@ -697,14 +717,14 @@ done:
  *-------------------------------------------------------------------------
  */
 herr_t
-H5F_traverse_mount(H5O_loc_t *oloc /*in,out*/)
+H5F_traverse_mount(H5O_loc_t *oloc/*in,out*/)
 {
-    H5F_t *parent = oloc->file, /* File of object */
-        *child    = NULL;       /* Child file */
-    unsigned   lt, rt, md = 0;  /* Binary search indices */
-    int        cmp;
-    H5O_loc_t *mnt_oloc  = NULL;    /* Object location for mount points */
-    herr_t     ret_value = SUCCEED; /* Return value */
+    H5F_t *parent = oloc->file,         /* File of object */
+        *child = NULL;                  /* Child file */
+    unsigned	lt, rt, md = 0;         /* Binary search indices */
+    int cmp;
+    H5O_loc_t	*mnt_oloc = NULL;       /* Object location for mount points */
+    herr_t ret_value = SUCCEED;         /* Return value */
 
     FUNC_ENTER_NOAPI(FAIL)
 
@@ -720,21 +740,21 @@ H5F_traverse_mount(H5O_loc_t *oloc /*in,out*/)
          * Use a binary search to find the potential mount point in the mount
          * table for the parent
          */
-        lt  = 0;
-        rt  = parent->shared->mtab.nmounts;
+        lt = 0;
+        rt = parent->shared->mtab.nmounts;
         cmp = -1;
-        while (lt < rt && cmp) {
-            md       = (lt + rt) / 2;
+        while(lt < rt && cmp) {
+            md = (lt + rt) / 2;
             mnt_oloc = H5G_oloc(parent->shared->mtab.child[md].group);
-            cmp      = H5F_addr_cmp(oloc->addr, mnt_oloc->addr);
-            if (cmp < 0)
+            cmp = H5F_addr_cmp(oloc->addr, mnt_oloc->addr);
+            if(cmp < 0)
                 rt = md;
             else
                 lt = md + 1;
         }
 
         /* Copy root info over to ENT */
-        if (0 == cmp) {
+        if(0 == cmp) {
             /* Get the child file */
             child = parent->shared->mtab.child[md].file;
 
@@ -742,11 +762,11 @@ H5F_traverse_mount(H5O_loc_t *oloc /*in,out*/)
             mnt_oloc = H5G_oloc(child->shared->root_grp);
 
             /* Release the mount point */
-            if (H5O_loc_free(oloc) < 0)
+            if(H5O_loc_free(oloc) < 0)
                 HGOTO_ERROR(H5E_FILE, H5E_CANTFREE, FAIL, "unable to free object location")
 
             /* Copy the entry for the root group */
-            if (H5O_loc_copy(oloc, mnt_oloc, H5_COPY_DEEP) < 0)
+            if(H5O_loc_copy_deep(oloc, mnt_oloc) < 0)
                 HGOTO_ERROR(H5E_FILE, H5E_CANTCOPY, FAIL, "unable to copy object location")
 
             /* In case the shared root group info points to a different file handle
@@ -756,8 +776,9 @@ H5F_traverse_mount(H5O_loc_t *oloc /*in,out*/)
             /* Switch to child's file */
             parent = child;
         } /* end if */
-    } while (!cmp);
+    } while(!cmp);
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5F_traverse_mount() */
+
