@@ -6,7 +6,7 @@
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://www.hdfgroup.org/licenses.               *
+ * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -15,7 +15,7 @@
  *
  * Created:		H5HF.c
  *			Feb 24 2006
- *			Quincey Koziol
+ *			Quincey Koziol <koziol@ncsa.uiuc.edu>
  *
  * Purpose:		Implements a "fractal heap" for storing variable-
  *                      length objects in a file.
@@ -31,41 +31,53 @@
 /* Module Setup */
 /****************/
 
-#define H5HF_PACKAGE /*suppress error about including H5HFpkg  */
+#include "H5HFmodule.h"         /* This source code file is part of the H5HF module */
+
 
 /***********/
 /* Headers */
 /***********/
-#include "H5private.h"   /* Generic Functions			*/
-#include "H5Eprivate.h"  /* Error handling		  	*/
-#include "H5FOprivate.h" /* File objects                         */
-#include "H5HFpkg.h"     /* Fractal heaps			*/
-#include "H5MFprivate.h" /* File memory management		*/
+#include "H5private.h"		/* Generic Functions			*/
+#include "H5Eprivate.h"		/* Error handling		  	*/
+#include "H5FOprivate.h"        /* File objects                         */
+#include "H5HFpkg.h"		/* Fractal heaps			*/
+#include "H5MFprivate.h"	/* File memory management		*/
+#include "H5MMprivate.h"	/* Memory management			*/
+
 
 /****************/
 /* Local Macros */
 /****************/
 
+
 /******************/
 /* Local Typedefs */
 /******************/
 
+
 /********************/
 /* Package Typedefs */
 /********************/
 
+
 /********************/
 /* Local Prototypes */
 /********************/
 
+
 /*********************/
 /* Package Variables */
 /*********************/
 
+/* Package initialization variable */
+hbool_t H5_PKG_INIT_VAR = FALSE;
+
+
 /*****************************/
 /* Library Private Variables */
 /*****************************/
 
+
 /*******************/
 /* Local Variables */
 /*******************/
@@ -73,6 +85,8 @@
 /* Declare a free list to manage the H5HF_t struct */
 H5FL_DEFINE_STATIC(H5HF_t);
 
+
+
 /*-------------------------------------------------------------------------
  * Function:	H5HF_op_read
  *
@@ -81,6 +95,7 @@ H5FL_DEFINE_STATIC(H5HF_t);
  * Return:	SUCCEED/FAIL
  *
  * Programmer:	Quincey Koziol
+ *		koziol@hdfgroup.org
  *		Sep 11 2006
  *
  *-------------------------------------------------------------------------
@@ -91,11 +106,12 @@ H5HF_op_read(const void *obj, size_t obj_len, void *op_data)
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
     /* Perform "read", using memcpy() */
-    HDmemcpy(op_data, obj, obj_len);
+    H5MM_memcpy(op_data, obj, obj_len);
 
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* end H5HF_op_read() */
 
+
 /*-------------------------------------------------------------------------
  * Function:	H5HF_op_write
  *
@@ -104,6 +120,7 @@ H5HF_op_read(const void *obj, size_t obj_len, void *op_data)
  * Return:	SUCCEED/FAIL
  *
  * Programmer:	Quincey Koziol
+ *		koziol@hdfgroup.org
  *		Dec 18 2006
  *
  *-------------------------------------------------------------------------
@@ -114,11 +131,12 @@ H5HF_op_write(const void *obj, size_t obj_len, void *op_data)
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
     /* Perform "write", using memcpy() */
-    HDmemcpy((void *)obj, op_data, obj_len); /* Casting away const OK -QAK */
+    H5MM_memcpy((void *)obj, op_data, obj_len);    /* Casting away const OK -QAK */
 
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* end H5HF_op_write() */
 
+
 /*-------------------------------------------------------------------------
  * Function:	H5HF_create
  *
@@ -128,17 +146,18 @@ H5HF_op_write(const void *obj, size_t obj_len, void *op_data)
  *              NULL on failure
  *
  * Programmer:	Quincey Koziol
+ *		koziol@ncsa.uiuc.edu
  *		Feb 24 2006
  *
  *-------------------------------------------------------------------------
  */
 H5HF_t *
-H5HF_create(H5F_t *f, hid_t dxpl_id, const H5HF_create_t *cparam)
+H5HF_create(H5F_t *f, const H5HF_create_t *cparam)
 {
-    H5HF_t     *fh  = NULL;       /* Pointer to new fractal heap */
-    H5HF_hdr_t *hdr = NULL;       /* The fractal heap header information */
-    haddr_t     fh_addr;          /* Heap header address */
-    H5HF_t     *ret_value = NULL; /* Return value */
+    H5HF_t *fh = NULL;          /* Pointer to new fractal heap */
+    H5HF_hdr_t *hdr = NULL;     /* The fractal heap header information */
+    haddr_t fh_addr;            /* Heap header address */
+    H5HF_t *ret_value = NULL;   /* Return value */
 
     FUNC_ENTER_NOAPI(NULL)
 
@@ -149,25 +168,25 @@ H5HF_create(H5F_t *f, hid_t dxpl_id, const H5HF_create_t *cparam)
     HDassert(cparam);
 
     /* Create shared fractal heap header */
-    if (HADDR_UNDEF == (fh_addr = H5HF_hdr_create(f, dxpl_id, cparam)))
+    if(HADDR_UNDEF == (fh_addr = H5HF_hdr_create(f, cparam)))
         HGOTO_ERROR(H5E_HEAP, H5E_CANTINIT, NULL, "can't create fractal heap header")
 
     /* Allocate fractal heap wrapper */
-    if (NULL == (fh = H5FL_MALLOC(H5HF_t)))
+    if(NULL == (fh = H5FL_MALLOC(H5HF_t)))
         HGOTO_ERROR(H5E_HEAP, H5E_CANTALLOC, NULL, "memory allocation failed for fractal heap info")
 
     /* Lock the heap header into memory */
-    if (NULL == (hdr = H5HF_hdr_protect(f, dxpl_id, fh_addr, H5AC_WRITE)))
+    if(NULL == (hdr = H5HF__hdr_protect(f, fh_addr, H5AC__NO_FLAGS_SET)))
         HGOTO_ERROR(H5E_HEAP, H5E_CANTPROTECT, NULL, "unable to protect fractal heap header")
 
     /* Point fractal heap wrapper at header and bump it's ref count */
     fh->hdr = hdr;
-    if (H5HF_hdr_incr(fh->hdr) < 0)
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTINC, NULL, "can't increment reference count on shared heap header")
+    if(H5HF_hdr_incr(fh->hdr) < 0)
+	HGOTO_ERROR(H5E_HEAP, H5E_CANTINC, NULL, "can't increment reference count on shared heap header")
 
     /* Increment # of files using this heap header */
-    if (H5HF_hdr_fuse_incr(fh->hdr) < 0)
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTINC, NULL, "can't increment file reference count on shared heap header")
+    if(H5HF_hdr_fuse_incr(fh->hdr) < 0)
+	HGOTO_ERROR(H5E_HEAP, H5E_CANTINC, NULL, "can't increment file reference count on shared heap header")
 
     /* Set file pointer for this heap open context */
     fh->f = f;
@@ -176,15 +195,16 @@ H5HF_create(H5F_t *f, hid_t dxpl_id, const H5HF_create_t *cparam)
     ret_value = fh;
 
 done:
-    if (hdr && H5AC_unprotect(f, dxpl_id, H5AC_FHEAP_HDR, fh_addr, hdr, H5AC__NO_FLAGS_SET) < 0)
+    if(hdr && H5AC_unprotect(f, H5AC_FHEAP_HDR, fh_addr, hdr, H5AC__NO_FLAGS_SET) < 0)
         HDONE_ERROR(H5E_HEAP, H5E_CANTUNPROTECT, NULL, "unable to release fractal heap header")
-    if (!ret_value && fh)
-        if (H5HF_close(fh, dxpl_id) < 0)
+    if(!ret_value && fh)
+        if(H5HF_close(fh) < 0)
             HDONE_ERROR(H5E_HEAP, H5E_CANTCLOSEOBJ, NULL, "unable to close fractal heap")
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5HF_create() */
 
+
 /*-------------------------------------------------------------------------
  * Function:	H5HF_open
  *
@@ -194,16 +214,17 @@ done:
  *              NULL on failure
  *
  * Programmer:	Quincey Koziol
+ *		koziol@ncsa.uiuc.edu
  *		Apr 18 2006
  *
  *-------------------------------------------------------------------------
  */
 H5HF_t *
-H5HF_open(H5F_t *f, hid_t dxpl_id, haddr_t fh_addr)
+H5HF_open(H5F_t *f, haddr_t fh_addr)
 {
-    H5HF_t     *fh        = NULL; /* Pointer to new fractal heap */
-    H5HF_hdr_t *hdr       = NULL; /* The fractal heap header information */
-    H5HF_t     *ret_value = NULL; /* Return value */
+    H5HF_t *fh = NULL;          /* Pointer to new fractal heap */
+    H5HF_hdr_t *hdr = NULL;     /* The fractal heap header information */
+    H5HF_t *ret_value = NULL;   /* Return value */
 
     FUNC_ENTER_NOAPI(NULL)
 
@@ -214,25 +235,25 @@ H5HF_open(H5F_t *f, hid_t dxpl_id, haddr_t fh_addr)
     HDassert(H5F_addr_defined(fh_addr));
 
     /* Load the heap header into memory */
-    if (NULL == (hdr = H5HF_hdr_protect(f, dxpl_id, fh_addr, H5AC_READ)))
+    if(NULL == (hdr = H5HF__hdr_protect(f, fh_addr, H5AC__READ_ONLY_FLAG)))
         HGOTO_ERROR(H5E_HEAP, H5E_CANTPROTECT, NULL, "unable to protect fractal heap header")
 
     /* Check for pending heap deletion */
-    if (hdr->pending_delete)
+    if(hdr->pending_delete)
         HGOTO_ERROR(H5E_HEAP, H5E_CANTOPENOBJ, NULL, "can't open fractal heap pending deletion")
 
     /* Create fractal heap info */
-    if (NULL == (fh = H5FL_MALLOC(H5HF_t)))
+    if(NULL == (fh = H5FL_MALLOC(H5HF_t)))
         HGOTO_ERROR(H5E_HEAP, H5E_CANTALLOC, NULL, "memory allocation failed for fractal heap info")
 
     /* Point fractal heap wrapper at header */
     fh->hdr = hdr;
-    if (H5HF_hdr_incr(fh->hdr) < 0)
+    if(H5HF_hdr_incr(fh->hdr) < 0)
         HGOTO_ERROR(H5E_HEAP, H5E_CANTINC, NULL, "can't increment reference count on shared heap header")
 
     /* Increment # of files using this heap header */
-    if (H5HF_hdr_fuse_incr(fh->hdr) < 0)
-        HGOTO_ERROR(H5E_HEAP, H5E_CANTINC, NULL, "can't increment file reference count on shared heap header")
+    if(H5HF_hdr_fuse_incr(fh->hdr) < 0)
+	HGOTO_ERROR(H5E_HEAP, H5E_CANTINC, NULL, "can't increment file reference count on shared heap header")
 
     /* Set file pointer for this heap open context */
     fh->f = f;
@@ -241,15 +262,16 @@ H5HF_open(H5F_t *f, hid_t dxpl_id, haddr_t fh_addr)
     ret_value = fh;
 
 done:
-    if (hdr && H5AC_unprotect(f, dxpl_id, H5AC_FHEAP_HDR, fh_addr, hdr, H5AC__NO_FLAGS_SET) < 0)
+    if(hdr && H5AC_unprotect(f, H5AC_FHEAP_HDR, fh_addr, hdr, H5AC__NO_FLAGS_SET) < 0)
         HDONE_ERROR(H5E_HEAP, H5E_CANTUNPROTECT, NULL, "unable to release fractal heap header")
-    if (!ret_value && fh)
-        if (H5HF_close(fh, dxpl_id) < 0)
+    if(!ret_value && fh)
+        if(H5HF_close(fh) < 0)
             HDONE_ERROR(H5E_HEAP, H5E_CANTCLOSEOBJ, NULL, "unable to close fractal heap")
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5HF_open() */
 
+
 /*-------------------------------------------------------------------------
  * Function:	H5HF_get_id_len
  *
@@ -258,6 +280,7 @@ done:
  * Return:	SUCCEED/FAIL
  *
  * Programmer:	Quincey Koziol
+ *		koziol@ncsa.uiuc.edu
  *		Apr 17 2006
  *
  *-------------------------------------------------------------------------
@@ -279,6 +302,7 @@ H5HF_get_id_len(H5HF_t *fh, size_t *id_len_p)
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* end H5HF_get_id_len() */
 
+
 /*-------------------------------------------------------------------------
  * Function:	H5HF_get_heap_addr
  *
@@ -287,6 +311,7 @@ H5HF_get_id_len(H5HF_t *fh, size_t *id_len_p)
  * Return:	SUCCEED/FAIL
  *
  * Programmer:	Quincey Koziol
+ *		koziol@ncsa.uiuc.edu
  *		Apr 18 2006
  *
  *-------------------------------------------------------------------------
@@ -308,6 +333,7 @@ H5HF_get_heap_addr(const H5HF_t *fh, haddr_t *heap_addr_p)
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* end H5HF_get_heap_addr() */
 
+
 /*-------------------------------------------------------------------------
  * Function:	H5HF_insert
  *
@@ -317,15 +343,16 @@ H5HF_get_heap_addr(const H5HF_t *fh, haddr_t *heap_addr_p)
  *              filled in), negative on failure
  *
  * Programmer:	Quincey Koziol
+ *		koziol@ncsa.uiuc.edu
  *		Feb 24 2006
  *
  *-------------------------------------------------------------------------
  */
 herr_t
-H5HF_insert(H5HF_t *fh, hid_t dxpl_id, size_t size, const void *obj, void *id /*out*/)
+H5HF_insert(H5HF_t *fh, size_t size, const void *obj, void *id/*out*/)
 {
-    H5HF_hdr_t *hdr       = NULL; /* The fractal heap header information */
-    herr_t      ret_value = SUCCEED;
+    H5HF_hdr_t *hdr = NULL;                  /* The fractal heap header information */
+    herr_t ret_value = SUCCEED;
 
     FUNC_ENTER_NOAPI(FAIL)
 
@@ -335,7 +362,7 @@ H5HF_insert(H5HF_t *fh, hid_t dxpl_id, size_t size, const void *obj, void *id /*
     HDassert(id);
 
     /* Check arguments */
-    if (size == 0)
+    if(size == 0)
         HGOTO_ERROR(H5E_HEAP, H5E_BADRANGE, FAIL, "can't insert 0-sized objects")
 
     /* Set the shared heap header's file context for this operation */
@@ -345,34 +372,35 @@ H5HF_insert(H5HF_t *fh, hid_t dxpl_id, size_t size, const void *obj, void *id /*
     hdr = fh->hdr;
 
     /* Check for 'huge' object */
-    if (size > hdr->max_man_size) {
+    if(size > hdr->max_man_size) {
         /* Store 'huge' object in heap */
         /* (Casting away const OK - QAK) */
-        if (H5HF_huge_insert(hdr, dxpl_id, size, (void *)obj, id) < 0)
+        if(H5HF__huge_insert(hdr, size, (void *)obj, id) < 0)
             HGOTO_ERROR(H5E_HEAP, H5E_CANTINSERT, FAIL, "can't store 'huge' object in fractal heap")
     } /* end if */
     /* Check for 'tiny' object */
-    else if (size <= hdr->tiny_max_len) {
+    else if(size <= hdr->tiny_max_len) {
         /* Store 'tiny' object in heap */
-        if (H5HF_tiny_insert(hdr, size, obj, id) < 0)
+        if(H5HF_tiny_insert(hdr, size, obj, id) < 0)
             HGOTO_ERROR(H5E_HEAP, H5E_CANTINSERT, FAIL, "can't store 'tiny' object in fractal heap")
     } /* end if */
     else {
         /* Check if we are in "append only" mode, or if there's enough room for the object */
-        if (hdr->write_once) {
-            HGOTO_ERROR(H5E_HEAP, H5E_UNSUPPORTED, FAIL, "'write once' managed blocks not supported yet")
+        if(hdr->write_once) {
+HGOTO_ERROR(H5E_HEAP, H5E_UNSUPPORTED, FAIL, "'write once' managed blocks not supported yet")
         } /* end if */
         else {
             /* Allocate space for object in 'managed' heap */
-            if (H5HF_man_insert(hdr, dxpl_id, size, obj, id) < 0)
+            if(H5HF__man_insert(hdr, size, obj, id) < 0)
                 HGOTO_ERROR(H5E_HEAP, H5E_CANTINSERT, FAIL, "can't store 'managed' object in fractal heap")
         } /* end else */
-    }     /* end else */
+    } /* end else */
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5HF_insert() */
 
+
 /*-------------------------------------------------------------------------
  * Function:	H5HF_get_obj_len
  *
@@ -381,16 +409,17 @@ done:
  * Return:	SUCCEED/FAIL
  *
  * Programmer:	Quincey Koziol
+ *		koziol@ncsa.uiuc.edu
  *		May  9 2006
  *
  *-------------------------------------------------------------------------
  */
 herr_t
-H5HF_get_obj_len(H5HF_t *fh, hid_t dxpl_id, const void *_id, size_t *obj_len_p)
+H5HF_get_obj_len(H5HF_t *fh, const void *_id, size_t *obj_len_p)
 {
-    const uint8_t *id = (const uint8_t *)_id; /* Object ID */
-    uint8_t        id_flags;                  /* Heap ID flag bits */
-    herr_t         ret_value = SUCCEED;       /* Return value */
+    const uint8_t *id = (const uint8_t *)_id;   /* Object ID */
+    uint8_t id_flags;                   /* Heap ID flag bits */
+    herr_t ret_value = SUCCEED;         /* Return value */
 
     FUNC_ENTER_NOAPI(FAIL)
 
@@ -405,40 +434,97 @@ H5HF_get_obj_len(H5HF_t *fh, hid_t dxpl_id, const void *_id, size_t *obj_len_p)
     id_flags = *id;
 
     /* Check for correct heap ID version */
-    if ((id_flags & H5HF_ID_VERS_MASK) != H5HF_ID_VERS_CURR)
+    if((id_flags & H5HF_ID_VERS_MASK) != H5HF_ID_VERS_CURR)
         HGOTO_ERROR(H5E_HEAP, H5E_VERSION, FAIL, "incorrect heap ID version")
 
     /* Set the shared heap header's file context for this operation */
     fh->hdr->f = fh->f;
 
     /* Check type of object in heap */
-    if ((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_MAN) {
-        /* Skip over the flag byte */
-        id++;
-
-        /* Skip over object offset */
-        id += fh->hdr->heap_off_size;
-
-        /* Retrieve the entry length */
-        UINT64DECODE_VAR(id, *obj_len_p, fh->hdr->heap_len_size);
+    if((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_MAN) {
+        if(H5HF_man_get_obj_len(fh->hdr, id, obj_len_p) < 0)
+            HGOTO_ERROR(H5E_HEAP, H5E_CANTGET, FAIL, "can't get 'managed' object's length")
     } /* end if */
-    else if ((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_HUGE) {
-        if (H5HF_huge_get_obj_len(fh->hdr, dxpl_id, id, obj_len_p) < 0)
+    else if((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_HUGE) {
+        if(H5HF__huge_get_obj_len(fh->hdr, id, obj_len_p) < 0)
             HGOTO_ERROR(H5E_HEAP, H5E_CANTGET, FAIL, "can't get 'huge' object's length")
     } /* end if */
-    else if ((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_TINY) {
-        if (H5HF_tiny_get_obj_len(fh->hdr, id, obj_len_p) < 0)
+    else if((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_TINY) {
+        if(H5HF_tiny_get_obj_len(fh->hdr, id, obj_len_p) < 0)
             HGOTO_ERROR(H5E_HEAP, H5E_CANTGET, FAIL, "can't get 'tiny' object's length")
     } /* end if */
     else {
-        HDfprintf(stderr, "%s: Heap ID type not supported yet!\n", FUNC);
-        HGOTO_ERROR(H5E_HEAP, H5E_UNSUPPORTED, FAIL, "heap ID type not supported yet")
+HDfprintf(stderr, "%s: Heap ID type not supported yet!\n", FUNC);
+HGOTO_ERROR(H5E_HEAP, H5E_UNSUPPORTED, FAIL, "heap ID type not supported yet")
     } /* end else */
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5HF_get_obj_len() */
 
+
+/*-------------------------------------------------------------------------
+ * Function:	H5HF_get_obj_off
+ *
+ * Purpose:	Get the offset of an entry in a fractal heap
+ *
+ * Return:	SUCCEED/FAIL
+ *
+ * Programmer:	Quincey Koziol
+ *		koziol@hdfgroup.org
+ *		Aug 20 2015
+ *
+ *-------------------------------------------------------------------------
+ */
+herr_t
+H5HF_get_obj_off(H5HF_t *fh, const void *_id, hsize_t *obj_off_p)
+{
+    const uint8_t *id = (const uint8_t *)_id;   /* Object ID */
+    uint8_t id_flags;                   /* Heap ID flag bits */
+    herr_t ret_value = SUCCEED;         /* Return value */
+
+    FUNC_ENTER_NOAPI(FAIL)
+
+    /*
+     * Check arguments.
+     */
+    HDassert(fh);
+    HDassert(id);
+    HDassert(obj_off_p);
+
+    /* Get the ID flags */
+    id_flags = *id;
+
+    /* Check for correct heap ID version */
+    if((id_flags & H5HF_ID_VERS_MASK) != H5HF_ID_VERS_CURR)
+        HGOTO_ERROR(H5E_HEAP, H5E_VERSION, FAIL, "incorrect heap ID version")
+
+    /* Set the shared heap header's file context for this operation */
+    fh->hdr->f = fh->f;
+
+    /* Check type of object in heap */
+    if((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_MAN) {
+        H5HF__man_get_obj_off(fh->hdr, id, obj_off_p);
+    } /* end if */
+    else if((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_HUGE) {
+        /* Huge objects are located directly in the file */
+        if(H5HF__huge_get_obj_off(fh->hdr, id, obj_off_p) < 0)
+            HGOTO_ERROR(H5E_HEAP, H5E_CANTGET, FAIL, "can't get 'huge' object's offset")
+    } /* end if */
+    else if((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_TINY) {
+        /* Tiny objects are not stored in the heap */
+        *obj_off_p = (hsize_t)0;
+    } /* end if */
+    else {
+HDfprintf(stderr, "%s: Heap ID type not supported yet!\n", FUNC);
+HGOTO_ERROR(H5E_HEAP, H5E_UNSUPPORTED, FAIL, "heap ID type not supported yet")
+    } /* end else */
+
+done:
+    FUNC_LEAVE_NOAPI(ret_value)
+} /* end H5HF_get_obj_off() */
+
+
 /*-------------------------------------------------------------------------
  * Function:	H5HF_read
  *
@@ -447,16 +533,17 @@ done:
  * Return:	SUCCEED/FAIL
  *
  * Programmer:	Quincey Koziol
+ *		koziol@ncsa.uiuc.edu
  *		Mar 18 2006
  *
  *-------------------------------------------------------------------------
  */
 herr_t
-H5HF_read(H5HF_t *fh, hid_t dxpl_id, const void *_id, void *obj /*out*/)
+H5HF_read(H5HF_t *fh, const void *_id, void *obj/*out*/)
 {
-    const uint8_t *id = (const uint8_t *)_id; /* Object ID */
-    uint8_t        id_flags;                  /* Heap ID flag bits */
-    herr_t         ret_value = SUCCEED;       /* Return value */
+    const uint8_t *id = (const uint8_t *)_id;   /* Object ID */
+    uint8_t id_flags;                   /* Heap ID flag bits */
+    herr_t ret_value = SUCCEED;         /* Return value */
 
     FUNC_ENTER_NOAPI(FAIL)
 
@@ -471,37 +558,38 @@ H5HF_read(H5HF_t *fh, hid_t dxpl_id, const void *_id, void *obj /*out*/)
     id_flags = *id;
 
     /* Check for correct heap ID version */
-    if ((id_flags & H5HF_ID_VERS_MASK) != H5HF_ID_VERS_CURR)
+    if((id_flags & H5HF_ID_VERS_MASK) != H5HF_ID_VERS_CURR)
         HGOTO_ERROR(H5E_HEAP, H5E_VERSION, FAIL, "incorrect heap ID version")
 
     /* Set the shared heap header's file context for this operation */
     fh->hdr->f = fh->f;
 
     /* Check type of object in heap */
-    if ((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_MAN) {
+    if((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_MAN) {
         /* Read object from managed heap blocks */
-        if (H5HF_man_read(fh->hdr, dxpl_id, id, obj) < 0)
+        if(H5HF__man_read(fh->hdr, id, obj) < 0)
             HGOTO_ERROR(H5E_HEAP, H5E_CANTGET, FAIL, "can't read object from fractal heap")
     } /* end if */
-    else if ((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_HUGE) {
+    else if((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_HUGE) {
         /* Read 'huge' object from file */
-        if (H5HF_huge_read(fh->hdr, dxpl_id, id, obj) < 0)
+        if(H5HF__huge_read(fh->hdr, id, obj) < 0)
             HGOTO_ERROR(H5E_HEAP, H5E_CANTGET, FAIL, "can't read 'huge' object from fractal heap")
     } /* end if */
-    else if ((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_TINY) {
+    else if((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_TINY) {
         /* Read 'tiny' object from file */
-        if (H5HF_tiny_read(fh->hdr, id, obj) < 0)
+        if(H5HF_tiny_read(fh->hdr, id, obj) < 0)
             HGOTO_ERROR(H5E_HEAP, H5E_CANTGET, FAIL, "can't read 'tiny' object from fractal heap")
     } /* end if */
     else {
-        HDfprintf(stderr, "%s: Heap ID type not supported yet!\n", FUNC);
-        HGOTO_ERROR(H5E_HEAP, H5E_UNSUPPORTED, FAIL, "heap ID type not supported yet")
+HDfprintf(stderr, "%s: Heap ID type not supported yet!\n", FUNC);
+HGOTO_ERROR(H5E_HEAP, H5E_UNSUPPORTED, FAIL, "heap ID type not supported yet")
     } /* end else */
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5HF_read() */
 
+
 /*-------------------------------------------------------------------------
  * Function:	H5HF_write
  *
@@ -522,16 +610,17 @@ done:
  * Return:	SUCCEED/FAIL
  *
  * Programmer:	Quincey Koziol
+ *		koziol@hdfgroup.org
  *		Dec 18 2006
  *
  *-------------------------------------------------------------------------
  */
 herr_t
-H5HF_write(H5HF_t *fh, hid_t dxpl_id, void *_id, hbool_t H5_ATTR_UNUSED *id_changed, const void *obj)
+H5HF_write(H5HF_t *fh, void *_id, hbool_t H5_ATTR_UNUSED *id_changed, const void *obj)
 {
-    uint8_t *id = (uint8_t *)_id; /* Object ID */
-    uint8_t  id_flags;            /* Heap ID flag bits */
-    herr_t   ret_value = SUCCEED; /* Return value */
+    uint8_t *id = (uint8_t *)_id;       /* Object ID */
+    uint8_t id_flags;                   /* Heap ID flag bits */
+    herr_t ret_value = SUCCEED;         /* Return value */
 
     FUNC_ENTER_NOAPI(FAIL)
 
@@ -546,38 +635,39 @@ H5HF_write(H5HF_t *fh, hid_t dxpl_id, void *_id, hbool_t H5_ATTR_UNUSED *id_chan
     id_flags = *id;
 
     /* Check for correct heap ID version */
-    if ((id_flags & H5HF_ID_VERS_MASK) != H5HF_ID_VERS_CURR)
+    if((id_flags & H5HF_ID_VERS_MASK) != H5HF_ID_VERS_CURR)
         HGOTO_ERROR(H5E_HEAP, H5E_VERSION, FAIL, "incorrect heap ID version")
 
     /* Set the shared heap header's file context for this operation */
     fh->hdr->f = fh->f;
 
     /* Check type of object in heap */
-    if ((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_MAN) {
+    if((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_MAN) {
         /* Operate on object from managed heap blocks */
         /* (ID can't change and modifying object is "easy" to manage) */
-        if (H5HF_man_write(fh->hdr, dxpl_id, id, obj) < 0)
+        if(H5HF__man_write(fh->hdr, id, obj) < 0)
             HGOTO_ERROR(H5E_HEAP, H5E_WRITEERROR, FAIL, "can't write to 'managed' heap object")
     } /* end if */
-    else if ((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_HUGE) {
+    else if((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_HUGE) {
         /* Operate on "huge" object */
-        if (H5HF_huge_write(fh->hdr, dxpl_id, id, obj) < 0)
+        if(H5HF__huge_write(fh->hdr, id, obj) < 0)
             HGOTO_ERROR(H5E_HEAP, H5E_WRITEERROR, FAIL, "can't write to 'huge' heap object")
     } /* end if */
-    else if ((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_TINY) {
+    else if((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_TINY) {
         /* Check for writing a 'tiny' object */
         /* (which isn't supported yet - ID will change) */
         HGOTO_ERROR(H5E_HEAP, H5E_UNSUPPORTED, FAIL, "modifying 'tiny' object not supported yet")
     } /* end if */
     else {
-        HDfprintf(stderr, "%s: Heap ID type not supported yet!\n", FUNC);
-        HGOTO_ERROR(H5E_HEAP, H5E_UNSUPPORTED, FAIL, "heap ID type not supported yet")
+HDfprintf(stderr, "%s: Heap ID type not supported yet!\n", FUNC);
+HGOTO_ERROR(H5E_HEAP, H5E_UNSUPPORTED, FAIL, "heap ID type not supported yet")
     } /* end else */
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5HF_write() */
 
+
 /*-------------------------------------------------------------------------
  * Function:	H5HF_op
  *
@@ -591,16 +681,17 @@ done:
  * Return:	SUCCEED/FAIL
  *
  * Programmer:	Quincey Koziol
+ *		koziol@hdfgroup.org
  *		Sept 11 2006
  *
  *-------------------------------------------------------------------------
  */
 herr_t
-H5HF_op(H5HF_t *fh, hid_t dxpl_id, const void *_id, H5HF_operator_t op, void *op_data)
+H5HF_op(H5HF_t *fh, const void *_id, H5HF_operator_t op, void *op_data)
 {
-    const uint8_t *id = (const uint8_t *)_id; /* Object ID */
-    uint8_t        id_flags;                  /* Heap ID flag bits */
-    herr_t         ret_value = SUCCEED;       /* Return value */
+    const uint8_t *id = (const uint8_t *)_id;   /* Object ID */
+    uint8_t id_flags;                   /* Heap ID flag bits */
+    herr_t ret_value = SUCCEED;         /* Return value */
 
     FUNC_ENTER_NOAPI(FAIL)
 
@@ -615,37 +706,38 @@ H5HF_op(H5HF_t *fh, hid_t dxpl_id, const void *_id, H5HF_operator_t op, void *op
     id_flags = *id;
 
     /* Check for correct heap ID version */
-    if ((id_flags & H5HF_ID_VERS_MASK) != H5HF_ID_VERS_CURR)
+    if((id_flags & H5HF_ID_VERS_MASK) != H5HF_ID_VERS_CURR)
         HGOTO_ERROR(H5E_HEAP, H5E_VERSION, FAIL, "incorrect heap ID version")
 
     /* Set the shared heap header's file context for this operation */
     fh->hdr->f = fh->f;
 
     /* Check type of object in heap */
-    if ((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_MAN) {
+    if((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_MAN) {
         /* Operate on object from managed heap blocks */
-        if (H5HF_man_op(fh->hdr, dxpl_id, id, op, op_data) < 0)
+        if(H5HF__man_op(fh->hdr, id, op, op_data) < 0)
             HGOTO_ERROR(H5E_HEAP, H5E_CANTOPERATE, FAIL, "can't operate on object from fractal heap")
     } /* end if */
-    else if ((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_HUGE) {
+    else if((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_HUGE) {
         /* Operate on 'huge' object from file */
-        if (H5HF_huge_op(fh->hdr, dxpl_id, id, op, op_data) < 0)
+        if(H5HF__huge_op(fh->hdr, id, op, op_data) < 0)
             HGOTO_ERROR(H5E_HEAP, H5E_CANTOPERATE, FAIL, "can't operate on 'huge' object from fractal heap")
     } /* end if */
-    else if ((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_TINY) {
+    else if((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_TINY) {
         /* Operate on 'tiny' object from file */
-        if (H5HF_tiny_op(fh->hdr, id, op, op_data) < 0)
+        if(H5HF_tiny_op(fh->hdr, id, op, op_data) < 0)
             HGOTO_ERROR(H5E_HEAP, H5E_CANTOPERATE, FAIL, "can't operate on 'tiny' object from fractal heap")
     } /* end if */
     else {
-        HDfprintf(stderr, "%s: Heap ID type not supported yet!\n", FUNC);
-        HGOTO_ERROR(H5E_HEAP, H5E_UNSUPPORTED, FAIL, "heap ID type not supported yet")
+HDfprintf(stderr, "%s: Heap ID type not supported yet!\n", FUNC);
+HGOTO_ERROR(H5E_HEAP, H5E_UNSUPPORTED, FAIL, "heap ID type not supported yet")
     } /* end else */
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5HF_op() */
 
+
 /*-------------------------------------------------------------------------
  * Function:	H5HF_remove
  *
@@ -654,16 +746,17 @@ done:
  * Return:	SUCCEED/FAIL
  *
  * Programmer:	Quincey Koziol
+ *		koziol@ncsa.uiuc.edu
  *		May 15 2006
  *
  *-------------------------------------------------------------------------
  */
 herr_t
-H5HF_remove(H5HF_t *fh, hid_t dxpl_id, const void *_id)
+H5HF_remove(H5HF_t *fh, const void *_id)
 {
-    const uint8_t *id = (const uint8_t *)_id; /* Object ID */
-    uint8_t        id_flags;                  /* Heap ID flag bits */
-    herr_t         ret_value = SUCCEED;       /* Return value */
+    const uint8_t *id = (const uint8_t *)_id;   /* Object ID */
+    uint8_t id_flags;                   /* Heap ID flag bits */
+    herr_t ret_value = SUCCEED;         /* Return value */
 
     FUNC_ENTER_NOAPI(FAIL)
 
@@ -678,37 +771,38 @@ H5HF_remove(H5HF_t *fh, hid_t dxpl_id, const void *_id)
     id_flags = *id;
 
     /* Check for correct heap ID version */
-    if ((id_flags & H5HF_ID_VERS_MASK) != H5HF_ID_VERS_CURR)
+    if((id_flags & H5HF_ID_VERS_MASK) != H5HF_ID_VERS_CURR)
         HGOTO_ERROR(H5E_HEAP, H5E_VERSION, FAIL, "incorrect heap ID version")
 
     /* Set the shared heap header's file context for this operation */
     fh->hdr->f = fh->f;
 
     /* Check type of object in heap */
-    if ((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_MAN) {
+    if((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_MAN) {
         /* Remove object from managed heap blocks */
-        if (H5HF_man_remove(fh->hdr, dxpl_id, id) < 0)
+        if(H5HF__man_remove(fh->hdr, id) < 0)
             HGOTO_ERROR(H5E_HEAP, H5E_CANTREMOVE, FAIL, "can't remove object from fractal heap")
     } /* end if */
-    else if ((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_HUGE) {
+    else if((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_HUGE) {
         /* Remove 'huge' object from file & v2 B-tree tracker */
-        if (H5HF_huge_remove(fh->hdr, dxpl_id, id) < 0)
+        if(H5HF__huge_remove(fh->hdr, id) < 0)
             HGOTO_ERROR(H5E_HEAP, H5E_CANTREMOVE, FAIL, "can't remove 'huge' object from fractal heap")
     } /* end if */
-    else if ((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_TINY) {
+    else if((id_flags & H5HF_ID_TYPE_MASK) == H5HF_ID_TYPE_TINY) {
         /* Remove 'tiny' object from heap statistics */
-        if (H5HF_tiny_remove(fh->hdr, id) < 0)
+        if(H5HF_tiny_remove(fh->hdr, id) < 0)
             HGOTO_ERROR(H5E_HEAP, H5E_CANTREMOVE, FAIL, "can't remove 'tiny' object from fractal heap")
     } /* end if */
     else {
-        HDfprintf(stderr, "%s: Heap ID type not supported yet!\n", FUNC);
-        HGOTO_ERROR(H5E_HEAP, H5E_UNSUPPORTED, FAIL, "heap ID type not supported yet")
+HDfprintf(stderr, "%s: Heap ID type not supported yet!\n", FUNC);
+HGOTO_ERROR(H5E_HEAP, H5E_UNSUPPORTED, FAIL, "heap ID type not supported yet")
     } /* end else */
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5HF_remove() */
 
+
 /*-------------------------------------------------------------------------
  * Function:	H5HF_close
  *
@@ -717,16 +811,17 @@ done:
  * Return:	SUCCEED/FAIL
  *
  * Programmer:	Quincey Koziol
+ *		koziol@ncsa.uiuc.edu
  *		Apr 17 2006
  *
  *-------------------------------------------------------------------------
  */
 herr_t
-H5HF_close(H5HF_t *fh, hid_t dxpl_id)
+H5HF_close(H5HF_t *fh)
 {
-    hbool_t pending_delete = FALSE;       /* Whether the heap is pending deletion */
-    haddr_t heap_addr      = HADDR_UNDEF; /* Address of heap (for deletion) */
-    herr_t  ret_value      = SUCCEED;     /* Return value */
+    hbool_t pending_delete = FALSE;     /* Whether the heap is pending deletion */
+    haddr_t heap_addr = HADDR_UNDEF;    /* Address of heap (for deletion) */
+    herr_t ret_value = SUCCEED;         /* Return value */
 
     FUNC_ENTER_NOAPI(FAIL)
 
@@ -736,7 +831,7 @@ H5HF_close(H5HF_t *fh, hid_t dxpl_id)
     HDassert(fh);
 
     /* Decrement file reference & check if this is the last open fractal heap using the shared heap header */
-    if (0 == H5HF_hdr_fuse_decr(fh->hdr)) {
+    if(0 == H5HF_hdr_fuse_decr(fh->hdr)) {
         /* Set the shared heap header's file context for this operation */
         fh->hdr->f = fh->f;
 
@@ -746,7 +841,7 @@ H5HF_close(H5HF_t *fh, hid_t dxpl_id)
          *      a reference loop and the objects couldn't be removed from
          *      the metadata cache - QAK)
          */
-        if (H5HF_space_close(fh->hdr, dxpl_id) < 0)
+        if(H5HF__space_close(fh->hdr) < 0)
             HGOTO_ERROR(H5E_HEAP, H5E_CANTRELEASE, FAIL, "can't release free space info")
 
         /* Reset the block iterator, if necessary */
@@ -755,8 +850,8 @@ H5HF_close(H5HF_t *fh, hid_t dxpl_id)
          *      a reference loop and the objects couldn't be removed from
          *      the metadata cache - QAK)
          */
-        if (H5HF_man_iter_ready(&fh->hdr->next_block))
-            if (H5HF_man_iter_reset(&fh->hdr->next_block) < 0)
+        if(H5HF_man_iter_ready(&fh->hdr->next_block))
+            if(H5HF_man_iter_reset(&fh->hdr->next_block) < 0)
                 HGOTO_ERROR(H5E_HEAP, H5E_CANTRELEASE, FAIL, "can't reset block iterator")
 
         /* Shut down the huge object information */
@@ -764,33 +859,36 @@ H5HF_close(H5HF_t *fh, hid_t dxpl_id)
          *      has the address of an object in the file, which might be
          *      modified by the shutdown routine - QAK)
          */
-        if (H5HF_huge_term(fh->hdr, dxpl_id) < 0)
+        if(H5HF__huge_term(fh->hdr) < 0)
             HGOTO_ERROR(H5E_HEAP, H5E_CANTRELEASE, FAIL, "can't release 'huge' object info")
 
         /* Check for pending heap deletion */
-        if (fh->hdr->pending_delete) {
+        if(fh->hdr->pending_delete) {
             /* Set local info, so heap deletion can occur after decrementing the
              *  header's ref count
              */
             pending_delete = TRUE;
-            heap_addr      = fh->hdr->heap_addr;
+            heap_addr = fh->hdr->heap_addr;
         } /* end if */
-    }     /* end if */
+    } /* end if */
 
     /* Decrement the reference count on the heap header */
-    if (H5HF_hdr_decr(fh->hdr) < 0)
+    /* (don't put in H5HF_hdr_fuse_decr() as the heap header may be evicted
+     *  immediately -QAK)
+     */
+    if(H5HF_hdr_decr(fh->hdr) < 0)
         HGOTO_ERROR(H5E_HEAP, H5E_CANTDEC, FAIL, "can't decrement reference count on shared heap header")
 
     /* Check for pending heap deletion */
-    if (pending_delete) {
-        H5HF_hdr_t *hdr; /* Another pointer to fractal heap header */
+    if(pending_delete) {
+        H5HF_hdr_t *hdr;            /* Another pointer to fractal heap header */
 
         /* Lock the heap header into memory */
-        if (NULL == (hdr = H5HF_hdr_protect(fh->f, dxpl_id, heap_addr, H5AC_WRITE)))
+        if(NULL == (hdr = H5HF__hdr_protect(fh->f, heap_addr, H5AC__NO_FLAGS_SET)))
             HGOTO_ERROR(H5E_HEAP, H5E_CANTPROTECT, FAIL, "unable to protect fractal heap header")
 
         /* Delete heap, starting with header (unprotects header) */
-        if (H5HF_hdr_delete(hdr, dxpl_id) < 0)
+        if(H5HF__hdr_delete(hdr) < 0)
             HGOTO_ERROR(H5E_HEAP, H5E_CANTDELETE, FAIL, "unable to delete fractal heap")
     } /* end if */
 
@@ -801,6 +899,7 @@ done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5HF_close() */
 
+
 /*-------------------------------------------------------------------------
  * Function:	H5HF_delete
  *
@@ -809,15 +908,16 @@ done:
  * Return:	SUCCEED/FAIL
  *
  * Programmer:	Quincey Koziol
+ *		koziol@ncsa.uiuc.edu
  *		Aug  4 2006
  *
  *-------------------------------------------------------------------------
  */
 herr_t
-H5HF_delete(H5F_t *f, hid_t dxpl_id, haddr_t fh_addr)
+H5HF_delete(H5F_t *f, haddr_t fh_addr)
 {
-    H5HF_hdr_t *hdr       = NULL;    /* The fractal heap header information */
-    herr_t      ret_value = SUCCEED; /* Return value */
+    H5HF_hdr_t *hdr = NULL;             /* The fractal heap header information */
+    herr_t ret_value = SUCCEED;         /* Return value */
 
     FUNC_ENTER_NOAPI(FAIL)
 
@@ -828,23 +928,24 @@ H5HF_delete(H5F_t *f, hid_t dxpl_id, haddr_t fh_addr)
     HDassert(H5F_addr_defined(fh_addr));
 
     /* Lock the heap header into memory */
-    if (NULL == (hdr = H5HF_hdr_protect(f, dxpl_id, fh_addr, H5AC_WRITE)))
+    if(NULL == (hdr = H5HF__hdr_protect(f, fh_addr, H5AC__NO_FLAGS_SET)))
         HGOTO_ERROR(H5E_HEAP, H5E_CANTPROTECT, FAIL, "unable to protect fractal heap header")
 
     /* Check for files using shared heap header */
-    if (hdr->file_rc)
+    if(hdr->file_rc)
         hdr->pending_delete = TRUE;
     else {
         /* Delete heap now, starting with header (unprotects header) */
-        if (H5HF_hdr_delete(hdr, dxpl_id) < 0)
+        if(H5HF__hdr_delete(hdr) < 0)
             HGOTO_ERROR(H5E_HEAP, H5E_CANTDELETE, FAIL, "unable to delete fractal heap")
         hdr = NULL;
     } /* end if */
 
 done:
     /* Unprotect the header, if an error occurred */
-    if (hdr && H5AC_unprotect(f, dxpl_id, H5AC_FHEAP_HDR, fh_addr, hdr, H5AC__NO_FLAGS_SET) < 0)
+    if(hdr && H5AC_unprotect(f, H5AC_FHEAP_HDR, fh_addr, hdr, H5AC__NO_FLAGS_SET) < 0)
         HDONE_ERROR(H5E_HEAP, H5E_CANTUNPROTECT, FAIL, "unable to release fractal heap header")
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5HF_delete() */
+
