@@ -6,7 +6,7 @@
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://www.hdfgroup.org/licenses.               *
+ * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -14,15 +14,33 @@
 /*
  * This file contains private information about the H5R module
  */
-#ifndef H5Rprivate_H
-#define H5Rprivate_H
+#ifndef _H5Rprivate_H
+#define _H5Rprivate_H
 
 #include "H5Rpublic.h"
 
 /* Private headers needed by this file */
 
-/* Internal data structures */
+/**************************/
+/* Library Private Macros */
+/**************************/
 
-/* Private functions */
+#define H5R_ENCODE_VERSION      0x1     /* Version for encoding references */
+
+
+/****************************/
+/* Library Private Typedefs */
+/****************************/
+
+
+/*****************************/
+/* Library Private Variables */
+/*****************************/
+
+
+/******************************/
+/* Library Private Prototypes */
+/******************************/
+
+#endif  /* _H5Rprivate_H */
 
-#endif /* H5Rprivate_H */
