@@ -15,6 +15,7 @@
 
 
 #include "H5private.h"          /* Generic Functions   */
+#include "H5CXprivate.h"        /* API Contexts        */
 #include "H5Dprivate.h"         /* Dataset functions   */
 #include "H5Eprivate.h"         /* Error handling      */
 #include "H5Fprivate.h"         /* File                */
@@ -42,8 +43,11 @@ typedef struct H5Z_stats_t {
 #endif /* H5Z_DEBUG */
 
 typedef struct H5Z_object_t {
-    H5Z_filter_t filter_id;     /* ID of the filter we're looking for */
-    htri_t       found;         /* Whether we find an object using the filter */
+    H5Z_filter_t    filter_id;      /* ID of the filter we're looking for */
+    htri_t          found;          /* Whether we find an object using the filter */
+#ifdef H5_HAVE_PARALLEL
+    hbool_t         sanity_checked; /* Whether the sanity check for collectively calling H5Zunregister has been done */
+#endif /* H5_HAVE_PARALLEL */
 } H5Z_object_t;
 
 /* Enumerated type for dataset creation prelude callbacks */
@@ -211,8 +215,10 @@ herr_t
 H5Zregister(const void *cls)
 {
     const H5Z_class2_t  *cls_real = (const H5Z_class2_t *) cls; /* "Real" class pointer */
-    H5Z_class2_t        cls_new;                  /* Translated class struct */
     herr_t              ret_value = SUCCEED;      /* Return value */
+#ifndef H5_NO_DEPRECATED_SYMBOLS
+    H5Z_class2_t        cls_new;    /* Translated class struct */
+#endif
 
     FUNC_ENTER_API(FAIL)
     H5TRACE1("e", "*x", cls);
@@ -318,7 +324,7 @@ H5Z_register (const H5Z_class2_t *cls)
 
         /* Initialize */
         i = H5Z_table_used_g++;
-        HDmemcpy(H5Z_table_g+i, cls, sizeof(H5Z_class2_t));
+        H5MM_memcpy(H5Z_table_g+i, cls, sizeof(H5Z_class2_t));
 #ifdef H5Z_DEBUG
         HDmemset(H5Z_stat_table_g+i, 0, sizeof(H5Z_stats_t));
 #endif /* H5Z_DEBUG */
@@ -326,7 +332,7 @@ H5Z_register (const H5Z_class2_t *cls)
     /* Filter already registered */
     else {
         /* Replace old contents */
-        HDmemcpy(H5Z_table_g+i, cls, sizeof(H5Z_class2_t));
+        H5MM_memcpy(H5Z_table_g+i, cls, sizeof(H5Z_class2_t));
     } /* end else */
 
 done:
@@ -335,12 +341,12 @@ done:
 
 
 /*-------------------------------------------------------------------------
- * Function: H5Zunregister
+ * Function:    H5Zunregister
  *
- * Purpose:  This function unregisters a filter.
+ * Purpose:     This function unregisters a filter.
+ *
+ * Return:      SUCCEED/FAIL
  *
- * Return:   Non-negative on success
- *           Negative on failure
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -358,7 +364,7 @@ H5Zunregister(H5Z_filter_t id)
         HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "unable to modify predefined filters")
 
     /* Do it */
-    if (H5Z_unregister(id) < 0)
+    if(H5Z__unregister(id) < 0)
         HGOTO_ERROR(H5E_PLINE, H5E_CANTINIT, FAIL, "unable to unregister filter")
 
 done:
@@ -367,25 +373,25 @@ done:
 
 
 /*-------------------------------------------------------------------------
- * Function: H5Z_unregister
+ * Function:    H5Z__unregister
  *
- * Purpose:  Same as the public version except this one allows filters
- *           to be unset for predefined method numbers <H5Z_FILTER_RESERVED
+ * Purpose:     Same as the public version except this one allows filters
+ *               to be unset for predefined method numbers <H5Z_FILTER_RESERVED
+ *
+ * Return:      SUCCEED/FAIL
  *
- * Return:   Non-negative on success
- *           Negative on failure
  *-------------------------------------------------------------------------
  */
 herr_t
-H5Z_unregister(H5Z_filter_t filter_id)
+H5Z__unregister(H5Z_filter_t filter_id)
 {
     size_t       filter_index;          /* Local index variable for filter */
-    H5Z_object_t object;
+    H5Z_object_t object;                /* Object to pass to callbacks */
     herr_t       ret_value = SUCCEED;   /* Return value */
 
-    FUNC_ENTER_NOAPI(FAIL)
+    FUNC_ENTER_PACKAGE
 
-    HDassert(filter_id>=0 && filter_id<=H5Z_FILTER_MAX);
+    HDassert(filter_id >= 0 && filter_id <= H5Z_FILTER_MAX);
 
     /* Is the filter already registered? */
     for (filter_index = 0; filter_index < H5Z_table_used_g; filter_index++)
@@ -397,8 +403,11 @@ H5Z_unregister(H5Z_filter_t filter_id)
         HGOTO_ERROR(H5E_PLINE, H5E_NOTFOUND, FAIL, "filter is not registered")
 
     /* Initialize the structure object for iteration */
-    object.filter_id = filter_id;
-    object.found = FALSE;
+    object.filter_id        = filter_id;
+    object.found            = FALSE;
+#ifdef H5_HAVE_PARALLEL
+    object.sanity_checked   = FALSE;
+#endif /* H5_HAVE_PARALLEL */
 
     /* Iterate through all opened datasets, returns a failure if any of them uses the filter */
     if (H5I_iterate(H5I_DATASET, H5Z__check_unregister_dset_cb, &object, FALSE) < 0)
@@ -415,7 +424,7 @@ H5Z_unregister(H5Z_filter_t filter_id)
         HGOTO_ERROR(H5E_PLINE, H5E_CANTRELEASE, FAIL, "can't unregister filter because a group is still using it")
 
     /* Iterate through all opened files and flush them */
-    if (H5I_iterate(H5I_FILE, H5Z__flush_file_cb, NULL, FALSE) < 0)
+    if (H5I_iterate(H5I_FILE, H5Z__flush_file_cb, &object, FALSE) < 0)
         HGOTO_ERROR(H5E_FILE, H5E_BADITER, FAIL, "iteration failed")
 
     /* Remove filter from table */
@@ -428,16 +437,18 @@ H5Z_unregister(H5Z_filter_t filter_id)
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5Z_unregister() */
+} /* end H5Z__unregister() */
 
 
 /*-------------------------------------------------------------------------
- * Function: H5Z__check_unregister
+ * Function:    H5Z__check_unregister
  *
- * Purpose: Check if an object uses the filter to be unregistered.
+ * Purpose:     Check if an object uses the filter to be unregistered.
+ *
+ * Return:      TRUE if the object uses the filter
+ *              FALSE if not
+ *              NEGATIVE on error
  *
- * Return:  TRUE if the object uses the filter.
- *          FALSE if not, NEGATIVE on error.
  *-------------------------------------------------------------------------
  */
 static htri_t
@@ -462,15 +473,17 @@ done:
 
 
 /*-------------------------------------------------------------------------
- * Function: H5Z__check_unregister_group_cb
+ * Function:    H5Z__check_unregister_group_cb
  *
- * Purpose:  The callback function for H5Z_unregister. It iterates
- *           through all opened objects.  If the object is a dataset
- *           or a group and it uses the filter to be unregistered, the
- *           function returns TRUE.
+ * Purpose:     The callback function for H5Z__unregister. It iterates
+ *              through all opened objects.  If the object is a dataset
+ *              or a group and it uses the filter to be unregistered, the
+ *              function returns TRUE.
+ *
+ * Return:      TRUE if the object uses the filter
+ *              FALSE if not
+ *              NEGATIVE on error
  *
- * Return:   TRUE if the object uses the filter.
- *           FALSE otherwise.
  *-------------------------------------------------------------------------
  */
 static int
@@ -486,7 +499,7 @@ H5Z__check_unregister_group_cb(void *obj_ptr, hid_t H5_ATTR_UNUSED obj_id, void
     HDassert(obj_ptr);
 
     /* Get the group creation property */
-    if ((ocpl_id = H5G_get_create_plist((H5G_t *)obj_ptr)) < 0)
+    if((ocpl_id = H5G_get_create_plist((H5G_t *)obj_ptr)) < 0)
         HGOTO_ERROR(H5E_PLINE, H5E_CANTGET, FAIL, "can't get group creation property list")
 
     /* Check if the filter is in the group creation property list */
@@ -494,12 +507,12 @@ H5Z__check_unregister_group_cb(void *obj_ptr, hid_t H5_ATTR_UNUSED obj_id, void
         HGOTO_ERROR(H5E_PLINE, H5E_CANTGET, FAIL, "can't check filter in pipeline")
 
     /* H5I_iterate expects TRUE to stop the loop over objects. Stop the loop and
-     * let H5Z_unregister return failure.
+     * let H5Z__unregister return failure.
      */
     if (filter_in_pline) {
         object->found = TRUE;
         ret_value = TRUE;
-    } /* end if */
+    }
 
 done:
     if (ocpl_id > 0)
@@ -511,15 +524,17 @@ done:
 
 
 /*-------------------------------------------------------------------------
- * Function: H5Z__check_unregister_dset_cb
+ * Function:    H5Z__check_unregister_dset_cb
  *
- * Purpose: The callback function for H5Z_unregister. It iterates
- *          through all opened objects.  If the object is a dataset
- *          or a group and it uses the filter to be unregistered, the
- *          function returns TRUE.
+ * Purpose:     The callback function for H5Z__unregister. It iterates
+ *              through all opened objects.  If the object is a dataset
+ *              or a group and it uses the filter to be unregistered, the
+ *              function returns TRUE.
+ *
+ * Return:      TRUE if the object uses the filter
+ *              FALSE if not
+ *              NEGATIVE on error
  *
- * Return:  TRUE if the object uses the filter.
- *          FALSE otherwise.
  *-------------------------------------------------------------------------
  */
 static int
@@ -543,12 +558,12 @@ H5Z__check_unregister_dset_cb(void *obj_ptr, hid_t H5_ATTR_UNUSED obj_id, void *
         HGOTO_ERROR(H5E_PLINE, H5E_CANTGET, FAIL, "can't check filter in pipeline")
 
     /* H5I_iterate expects TRUE to stop the loop over objects. Stop the loop and
-     * let H5Z_unregister return failure.
+     * let H5Z__unregister return failure.
      */
     if (filter_in_pline) {
         object->found = TRUE;
         ret_value = TRUE;
-    } /* end if */
+    }
 
 done:
     if (ocpl_id > 0)
@@ -560,28 +575,70 @@ done:
 
 
 /*-------------------------------------------------------------------------
- * Function: H5Z__flush_file_cb
+ * Function:    H5Z__flush_file_cb
  *
- * Purpose:  The callback function for H5Z_unregister. It iterates
- *           through all opened files and flush them.
+ * Purpose:     The callback function for H5Z__unregister. It iterates
+ *              through all opened files and flush them.
  *
- * Return:   FALSE if finishes flushing and moves on
- *           FAIL if there is an error
+ * Return:      NON-NEGATIVE if finishes flushing and moves on
+ *              NEGATIVE if there is an error
  *-------------------------------------------------------------------------
  */
 static int
-H5Z__flush_file_cb(void *obj_ptr, hid_t H5_ATTR_UNUSED obj_id, void H5_ATTR_UNUSED *key)
+H5Z__flush_file_cb(void *obj_ptr, hid_t H5_ATTR_UNUSED obj_id, void *key)
 {
-    int    ret_value = FALSE;    /* Return value */
+    H5F_t          *f           = (H5F_t *)obj_ptr;     /* File object for operations */
+#ifdef H5_HAVE_PARALLEL
+    H5Z_object_t   *object      = (H5Z_object_t *)key;
+#endif /* H5_HAVE_PARALLEL */
+    int             ret_value   = FALSE;                /* Return value */
 
     FUNC_ENTER_STATIC
 
+    /* Sanity checks */
     HDassert(obj_ptr);
+    HDassert(key);
 
-    /* Call the flush routine for mounted file hierarchies. Do a global flush
-     * if the file is opened for write */
-    if (H5F_ACC_RDWR & H5F_INTENT((H5F_t *)obj_ptr)) {
-        if (H5F_flush_mounts((H5F_t *)obj_ptr, H5AC_ind_read_dxpl_id, H5AC_rawdata_dxpl_id) < 0)
+    /* Do a global flush if the file is opened for write */
+    if(H5F_ACC_RDWR & H5F_INTENT(f)) {
+
+/* When parallel HDF5 is defined, check for collective metadata reads on this
+ *      file and set the flag for metadata I/O in the API context.  -QAK, 2018/02/14
+ */
+#ifdef H5_HAVE_PARALLEL
+        /* Check if MPIO driver is used */
+        if(H5F_HAS_FEATURE(f, H5FD_FEAT_HAS_MPI)) {
+            H5P_coll_md_read_flag_t coll_md_read;  /* Do all metadata reads collectively */
+
+            /* Sanity check for collectively calling H5Zunregister, if requested */
+            /* (Sanity check assumes that a barrier on one file's comm
+             *  is sufficient (i.e. that there aren't different comms for
+             *  different files).  -QAK, 2018/02/14)
+             */
+            if(H5_coll_api_sanity_check_g && !object->sanity_checked) {
+                MPI_Comm mpi_comm;      /* File's communicator */
+
+                /* Retrieve the file communicator */
+                if(MPI_COMM_NULL == (mpi_comm = H5F_mpi_get_comm(f)))
+                    HGOTO_ERROR(H5E_PLINE, H5E_CANTGET, FAIL, "can't get MPI communicator")
+
+                /* Issue the barrier */
+                if(mpi_comm != MPI_COMM_NULL)
+                    MPI_Barrier(mpi_comm);
+
+                /* Set the "sanity checked" flag */
+                object->sanity_checked = TRUE;
+            } /* end if */
+
+            /* Check whether to use the collective metadata read DXPL */
+            coll_md_read = H5F_COLL_MD_READ(f);
+            if(H5P_USER_TRUE == coll_md_read)
+                H5CX_set_coll_metadata_read(TRUE);
+        } /* end if */
+#endif /* H5_HAVE_PARALLEL */
+
+        /* Call the flush routine for mounted file hierarchies */
+        if(H5F_flush_mounts((H5F_t *)obj_ptr) < 0)
             HGOTO_ERROR(H5E_PLINE, H5E_CANTFLUSH, FAIL, "unable to flush file hierarchy")
     } /* end if */
 
@@ -642,11 +699,11 @@ H5Z_filter_avail(H5Z_filter_t id)
             HGOTO_DONE(TRUE)
 
     key.id = (int)id;
-    if (NULL != (filter_info = (const H5Z_class2_t *)H5PL_load(H5PL_TYPE_FILTER, key))) {
-        if (H5Z_register(filter_info) < 0)
+    if(NULL != (filter_info = (const H5Z_class2_t *)H5PL_load(H5PL_TYPE_FILTER, &key))) {
+        if(H5Z_register(filter_info) < 0)
             HGOTO_ERROR(H5E_PLINE, H5E_CANTINIT, FAIL, "unable to register loaded filter")
         HGOTO_DONE(TRUE)
-    }
+    } /* end if */
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -770,11 +827,11 @@ H5Z_prepare_prelude_callback_dcpl(hid_t dcpl_id, hid_t type_id, H5Z_prelude_type
 
         /* Get dataset creation property list object */
         if (NULL == (dc_plist = (H5P_genplist_t *)H5I_object(dcpl_id)))
-            HGOTO_ERROR (H5E_ARGS, H5E_BADTYPE, FAIL, "can't get dataset creation property list")
+            HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "can't get dataset creation property list")
 
         /* Peek at the layout information */
         if (H5P_peek(dc_plist, H5D_CRT_LAYOUT_NAME, dcpl_layout) < 0)
-            HGOTO_ERROR (H5E_PLIST, H5E_CANTGET, FAIL, "can't retrieve layout")
+            HGOTO_ERROR(H5E_PLIST, H5E_CANTGET, FAIL, "can't retrieve layout")
 
         /* Check if the dataset is chunked */
         if (H5D_CHUNKED == dcpl_layout->type) {
@@ -782,7 +839,7 @@ H5Z_prepare_prelude_callback_dcpl(hid_t dcpl_id, hid_t type_id, H5Z_prelude_type
 
             /* Get I/O pipeline information */
             if (H5P_peek(dc_plist, H5O_CRT_PIPELINE_NAME, &dcpl_pline) < 0)
-                HGOTO_ERROR (H5E_PLIST, H5E_CANTGET, FAIL, "can't retrieve pipeline filter")
+                HGOTO_ERROR(H5E_PLIST, H5E_CANTGET, FAIL, "can't retrieve pipeline filter")
 
             /* Check if the chunks have filters */
             if (dcpl_pline.nused > 0) {
@@ -791,20 +848,20 @@ H5Z_prepare_prelude_callback_dcpl(hid_t dcpl_id, hid_t type_id, H5Z_prelude_type
                 size_t  u;               /* Local index variable */
 
                 /* Create a dataspace for a chunk & set the extent */
-                for (u = 0; u < dcpl_layout->u.chunk.ndims; u++)
+                for(u = 0; u < dcpl_layout->u.chunk.ndims; u++)
                     chunk_dims[u] = dcpl_layout->u.chunk.dim[u];
-                if (NULL == (space = H5S_create_simple(dcpl_layout->u.chunk.ndims, chunk_dims, NULL)))
-                    HGOTO_ERROR (H5E_DATASPACE, H5E_CANTCREATE, FAIL, "can't create simple dataspace")
+                if(NULL == (space = H5S_create_simple(dcpl_layout->u.chunk.ndims, chunk_dims, NULL)))
+                    HGOTO_ERROR(H5E_DATASPACE, H5E_CANTCREATE, FAIL, "can't create simple dataspace")
 
                 /* Get ID for dataspace to pass to filter routines */
                 if ((space_id = H5I_register(H5I_DATASPACE, space, FALSE)) < 0) {
                     (void)H5S_close(space);
-                    HGOTO_ERROR (H5E_ATOM, H5E_CANTREGISTER, FAIL, "unable to register dataspace ID")
+                    HGOTO_ERROR(H5E_ATOM, H5E_CANTREGISTER, FAIL, "unable to register dataspace ID")
                 }
 
                 /* Make the callbacks */
                 if (H5Z_prelude_callback(&dcpl_pline, dcpl_id, type_id, space_id, prelude_type) < 0)
-                    HGOTO_ERROR (H5E_PLINE, H5E_CANAPPLY, FAIL, "unable to apply filter")
+                    HGOTO_ERROR(H5E_PLINE, H5E_CANAPPLY, FAIL, "unable to apply filter")
             }
         }
     }
@@ -1234,7 +1291,7 @@ H5Z_pipeline(const H5O_pline_t *pline, unsigned flags,
 
                 /* Try loading the filter */
                 key.id = (int)(pline->filter[idx].id);
-                if(NULL != (filter_info = (const H5Z_class2_t *)H5PL_load(H5PL_TYPE_FILTER, key))) {
+                if(NULL != (filter_info = (const H5Z_class2_t *)H5PL_load(H5PL_TYPE_FILTER, &key))) {
                     /* Register the filter we loaded */
                     if(H5Z_register(filter_info) < 0)
                         HGOTO_ERROR(H5E_PLINE, H5E_CANTINIT, FAIL, "unable to register filter")
@@ -1448,7 +1505,6 @@ done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5Z_all_filters_avail() */
 
-
 
 /*-------------------------------------------------------------------------
  * Function: H5Z_delete
@@ -1473,7 +1529,7 @@ H5Z_delete(H5O_pline_t *pline, H5Z_filter_t filter)
 
     /* if the pipeline has no filters, just return */
     if (pline->nused == 0)
-        HGOTO_DONE (SUCCEED)
+        HGOTO_DONE(SUCCEED)
 
     /* Delete all filters */
     if (H5Z_FILTER_ALL == filter) {
@@ -1522,7 +1578,7 @@ H5Z_delete(H5O_pline_t *pline, H5Z_filter_t filter)
         pline->nused--;
 
         /* Reset information for previous last filter in pipeline */
-        HDmemset (&pline->filter[pline->nused], 0, sizeof(H5Z_filter_info_t));
+        HDmemset(&pline->filter[pline->nused], 0, sizeof(H5Z_filter_info_t));
     } /* end else */
 
 done:
@@ -1550,7 +1606,7 @@ H5Zget_filter_info(H5Z_filter_t filter, unsigned int *filter_config_flags)
 
     /* Get the filter info */
     if (H5Z_get_filter_info(filter, filter_config_flags) < 0)
-        HGOTO_ERROR (H5E_PLINE, H5E_CANTGET, FAIL, "Filter info not retrieved")
+        HGOTO_ERROR(H5E_PLINE, H5E_CANTGET, FAIL, "Filter info not retrieved")
 
 done:
     FUNC_LEAVE_API(ret_value)
