@@ -6,7 +6,7 @@
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://www.hdfgroup.org/licenses.               *
+ * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -30,13 +30,13 @@
 /**********/
 /* Macros */
 /**********/
-#define BUF_LEN 3093 /* No particular value */
+#define BUF_LEN 3093    /* No particular value */
 
 /*******************/
 /* Local variables */
 /*******************/
-uint8_t large_buf[BUF_LEN];
 
+
 /****************************************************************
 **
 **  test_chksum_size_one(): Checksum 1 byte buffer
@@ -45,8 +45,8 @@ uint8_t large_buf[BUF_LEN];
 static void
 test_chksum_size_one(void)
 {
-    uint8_t  buf[1] = {23}; /* Buffer to checksum */
-    uint32_t chksum;        /* Checksum value */
+    uint8_t buf[1] = {23};      /* Buffer to checksum */
+    uint32_t chksum;    /* Checksum value */
 
     /* Buffer w/real data */
     chksum = H5_checksum_fletcher32(buf, sizeof(buf));
@@ -70,6 +70,7 @@ test_chksum_size_one(void)
     VERIFY(chksum, 0x8ba9414b, "H5_checksum_lookup3");
 } /* test_chksum_size_one() */
 
+
 /****************************************************************
 **
 **  test_chksum_size_two(): Checksum 2 byte buffer
@@ -78,8 +79,8 @@ test_chksum_size_one(void)
 static void
 test_chksum_size_two(void)
 {
-    uint8_t  buf[2] = {23, 187}; /* Buffer to checksum */
-    uint32_t chksum;             /* Checksum value */
+    uint8_t buf[2] = {23, 187};         /* Buffer to checksum */
+    uint32_t chksum;                    /* Checksum value */
 
     /* Buffer w/real data */
     chksum = H5_checksum_fletcher32(buf, sizeof(buf));
@@ -103,6 +104,7 @@ test_chksum_size_two(void)
     VERIFY(chksum, 0x62cd61b3, "H5_checksum_lookup3");
 } /* test_chksum_size_two() */
 
+
 /****************************************************************
 **
 **  test_chksum_size_three(): Checksum 3 byte buffer
@@ -111,8 +113,8 @@ test_chksum_size_two(void)
 static void
 test_chksum_size_three(void)
 {
-    uint8_t  buf[3] = {23, 187, 98}; /* Buffer to checksum */
-    uint32_t chksum;                 /* Checksum value */
+    uint8_t buf[3] = {23, 187, 98};     /* Buffer to checksum */
+    uint32_t chksum;                    /* Checksum value */
 
     /* Buffer w/real data */
     chksum = H5_checksum_fletcher32(buf, sizeof(buf));
@@ -136,6 +138,7 @@ test_chksum_size_three(void)
     VERIFY(chksum, 0x6bd0060f, "H5_checksum_lookup3");
 } /* test_chksum_size_three() */
 
+
 /****************************************************************
 **
 **  test_chksum_size_four(): Checksum 4 byte buffer
@@ -144,8 +147,8 @@ test_chksum_size_three(void)
 static void
 test_chksum_size_four(void)
 {
-    uint8_t  buf[4] = {23, 187, 98, 217}; /* Buffer to checksum */
-    uint32_t chksum;                      /* Checksum value */
+    uint8_t buf[4] = {23, 187, 98, 217};/* Buffer to checksum */
+    uint32_t chksum;                    /* Checksum value */
 
     /* Buffer w/real data */
     chksum = H5_checksum_fletcher32(buf, sizeof(buf));
@@ -169,6 +172,7 @@ test_chksum_size_four(void)
     VERIFY(chksum, 0x049396b8, "H5_checksum_lookup3");
 } /* test_chksum_size_four() */
 
+
 /****************************************************************
 **
 **  test_chksum_large(): Checksum larger buffer
@@ -177,35 +181,44 @@ test_chksum_size_four(void)
 static void
 test_chksum_large(void)
 {
-    uint32_t chksum; /* Checksum value */
-    size_t   u;      /* Local index variable */
+    uint8_t *large_buf;         /* Buffer for checksum calculations */
+    uint32_t chksum;            /* Checksum value */
+    size_t u;                   /* Local index variable */
+
+    /* Allocate the buffer */
+    large_buf = (uint8_t *)HDmalloc((size_t)BUF_LEN);
+    CHECK_PTR(large_buf, "HDmalloc");
 
     /* Initialize buffer w/known data */
-    for (u = 0; u < BUF_LEN; u++)
-        large_buf[u] = u * 3;
+    for(u = 0; u < BUF_LEN; u++)
+        large_buf[u] = (uint8_t)(u * 3);
 
     /* Buffer w/real data */
-    chksum = H5_checksum_fletcher32(large_buf, sizeof(large_buf));
+    chksum = H5_checksum_fletcher32(large_buf, (size_t)BUF_LEN);
     VERIFY(chksum, 0x85b4e2a, "H5_checksum_fletcher32");
 
-    chksum = H5_checksum_crc(large_buf, sizeof(large_buf));
+    chksum = H5_checksum_crc(large_buf, (size_t)BUF_LEN);
     VERIFY(chksum, 0xfbd0f7c0, "H5_checksum_crc");
 
-    chksum = H5_checksum_lookup3(large_buf, sizeof(large_buf), 0);
+    chksum = H5_checksum_lookup3(large_buf, (size_t)BUF_LEN, 0);
     VERIFY(chksum, 0x1bd2ee7b, "H5_checksum_lookup3");
 
     /* Buffer w/zero(s) for data */
-    HDmemset(large_buf, 0, sizeof(large_buf));
-    chksum = H5_checksum_fletcher32(large_buf, sizeof(large_buf));
+    HDmemset(large_buf, 0, (size_t)BUF_LEN);
+    chksum = H5_checksum_fletcher32(large_buf, (size_t)BUF_LEN);
     VERIFY(chksum, 0, "H5_checksum_fletcher32");
 
-    chksum = H5_checksum_crc(large_buf, sizeof(large_buf));
+    chksum = H5_checksum_crc(large_buf, (size_t)BUF_LEN);
     VERIFY(chksum, 0xfac8b4c4, "H5_checksum_crc");
 
-    chksum = H5_checksum_lookup3(large_buf, sizeof(large_buf), 0);
+    chksum = H5_checksum_lookup3(large_buf, (size_t)BUF_LEN, 0);
     VERIFY(chksum, 0x930c7afc, "H5_checksum_lookup3");
+
+    /* Release memory for buffer */
+    HDfree(large_buf);
 } /* test_chksum_large() */
 
+
 /****************************************************************
 **
 **  test_checksum(): Main checksum testing routine.
@@ -218,14 +231,15 @@ test_checksum(void)
     MESSAGE(5, ("Testing checksum algorithms\n"));
 
     /* Various checks for fletcher32 checksum algorithm */
-    test_chksum_size_one();   /* Test buffer w/only 1 byte */
-    test_chksum_size_two();   /* Test buffer w/only 2 bytes */
-    test_chksum_size_three(); /* Test buffer w/only 3 bytes */
-    test_chksum_size_four();  /* Test buffer w/only 4 bytes */
-    test_chksum_large();      /* Test buffer w/larger # of bytes */
+    test_chksum_size_one();		/* Test buffer w/only 1 byte */
+    test_chksum_size_two();		/* Test buffer w/only 2 bytes */
+    test_chksum_size_three();		/* Test buffer w/only 3 bytes */
+    test_chksum_size_four();		/* Test buffer w/only 4 bytes */
+    test_chksum_large();		/* Test buffer w/larger # of bytes */
 
 } /* test_checksum() */
 
+
 /*-------------------------------------------------------------------------
  * Function:	cleanup_checksum
  *
@@ -243,3 +257,4 @@ cleanup_checksum(void)
 {
     /* no file to clean */
 }
+
