@@ -1,11 +1,12 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
+ * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://www.hdfgroup.org/licenses.               *
+ * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -42,34 +43,36 @@ main(int argc, char *argv[])
 
     /* Tests are generally arranged from least to most complexity... */
     AddTest("config", test_configure, cleanup_configure, "Configure definitions", NULL);
-    AddTest("h5system", test_h5_system, cleanup_h5_system, "H5system routines", NULL);
     AddTest("metadata", test_metadata, cleanup_metadata, "Encoding/decoding metadata", NULL);
     AddTest("checksum", test_checksum, cleanup_checksum, "Checksum algorithm", NULL);
-    AddTest("skiplist", test_skiplist, NULL, "Skip Lists", NULL);
-    AddTest("refstr", test_refstr, NULL, "Reference Counted Strings", NULL);
+    AddTest("tst", test_tst, NULL,  "Ternary Search Trees", NULL);
+    AddTest("heap", test_heap, NULL,  "Memory Heaps", NULL);
+    AddTest("skiplist", test_skiplist, NULL,  "Skip Lists", NULL);
+    AddTest("refstr", test_refstr, NULL,  "Reference Counted Strings", NULL);
     AddTest("file", test_file, cleanup_file, "Low-Level File I/O", NULL);
     AddTest("objects", test_h5o, cleanup_h5o, "Generic Object Functions", NULL);
-    AddTest("h5s", test_h5s, cleanup_h5s, "Dataspaces", NULL);
-    AddTest("coords", test_coords, cleanup_coords, "Dataspace coordinates", NULL);
-    AddTest("sohm", test_sohm, cleanup_sohm, "Shared Object Header Messages", NULL);
-    AddTest("attr", test_attr, cleanup_attr, "Attributes", NULL);
-    AddTest("select", test_select, cleanup_select, "Selections", NULL);
-    AddTest("time", test_time, cleanup_time, "Time Datatypes", NULL);
-    AddTest("reference", test_reference, cleanup_reference, "References", NULL);
-    AddTest("vltypes", test_vltypes, cleanup_vltypes, "Variable-Length Datatypes", NULL);
-    AddTest("vlstrings", test_vlstrings, cleanup_vlstrings, "Variable-Length Strings", NULL);
-    AddTest("iterate", test_iterate, cleanup_iterate, "Group & Attribute Iteration", NULL);
-    AddTest("array", test_array, cleanup_array, "Array Datatypes", NULL);
-    AddTest("genprop", test_genprop, cleanup_genprop, "Generic Properties", NULL);
-    AddTest("unicode", test_unicode, cleanup_unicode, "UTF-8 Encoding", NULL);
-    AddTest("id", test_ids, NULL, "User-Created Identifiers", NULL);
-    AddTest("misc", test_misc, cleanup_misc, "Miscellaneous", NULL);
+    AddTest("h5s",  test_h5s,  cleanup_h5s,  "Dataspaces", NULL);
+    AddTest("coords",  test_coords,  cleanup_coords,  "Dataspace coordinates", NULL);
+    AddTest("sohm", test_sohm, cleanup_sohm,  "Shared Object Header Messages", NULL);
+    AddTest("attr", test_attr, cleanup_attr,  "Attributes", NULL);
+    AddTest("select", test_select, cleanup_select,  "Selections", NULL);
+    AddTest("time", test_time, cleanup_time,  "Time Datatypes", NULL);
+    AddTest("ref_deprec", test_reference_deprec, cleanup_reference_deprec,  "Deprecated References", NULL);
+    AddTest("ref", test_reference, cleanup_reference,  "References", NULL);
+    AddTest("vltypes", test_vltypes, cleanup_vltypes,  "Variable-Length Datatypes", NULL);
+    AddTest("vlstrings", test_vlstrings, cleanup_vlstrings,  "Variable-Length Strings", NULL);
+    AddTest("iterate", test_iterate, cleanup_iterate,  "Group & Attribute Iteration", NULL);
+    AddTest("array", test_array, cleanup_array,  "Array Datatypes", NULL);
+    AddTest("genprop", test_genprop, cleanup_genprop,  "Generic Properties", NULL);
+    AddTest("unicode", test_unicode, cleanup_unicode,  "UTF-8 Encoding", NULL);
+    AddTest("id", test_ids, NULL,  "User-Created Identifiers", NULL);
+    AddTest("misc", test_misc, cleanup_misc,  "Miscellaneous", NULL);
 
     /* Display testing information */
     TestInfo(argv[0]);
 
     /* Parse command line arguments */
-    TestParseCmdLine(argc, argv);
+    TestParseCmdLine(argc,argv);
 
     /* Perform requested testing */
     PerformTests();
@@ -79,7 +82,7 @@ main(int argc, char *argv[])
         TestSummary();
 
     /* Clean up test files, if allowed */
-    if (GetTestCleanup() && !HDgetenv("HDF5_NOCLEANUP"))
+    if (GetTestCleanup() && !getenv("HDF5_NOCLEANUP"))
         TestCleanup();
 
     /* Release test infrastructure */
@@ -91,4 +94,5 @@ main(int argc, char *argv[])
         HDexit(EXIT_FAILURE);
     else
         HDexit(EXIT_SUCCESS);
-} /* end main() */
+}   /* end main() */
+
