@@ -22,7 +22,7 @@
  */
 
 static const char* MapIdToName(hid_t refobj_id,trav_table_t *travt);
-static int copy_refs_attr(hid_t loc_in, hid_t loc_out, pack_opt_t *options,
+static int copy_refs_attr(hid_t loc_in, hid_t loc_out,
                           trav_table_t *travt, hid_t fidout);
 static herr_t update_ref_value(hid_t obj_id, H5R_type_t ref_type, void *ref_in,
         hid_t fid_out, void *ref_out, trav_table_t *travt);
@@ -42,16 +42,15 @@ int do_copy_refobjs(hid_t fidin,
                     trav_table_t *travt,
                     pack_opt_t *options) /* repack options */
 {
-    int       ret_value = 0;          /*no need to LEAVE() on ERROR: HERR_INIT(int, SUCCEED) */
-    hid_t     grp_in = -1;            /* read group ID */
-    hid_t     grp_out = -1;           /* write group ID */
-    hid_t     dset_in = -1;           /* read dataset ID */
-    hid_t     dset_out = -1;          /* write dataset ID */
-    hid_t     type_in = -1;           /* named type ID */
-    hid_t     dcpl_id = -1;           /* dataset creation property list ID */
-    hid_t     space_id = -1;          /* space ID */
-    hid_t     ftype_id = -1;          /* file data type ID */
-    hid_t     mtype_id = -1;          /* memory data type ID */
+    hid_t     grp_in = H5I_INVALID_HID;            /* read group ID */
+    hid_t     grp_out = H5I_INVALID_HID;           /* write group ID */
+    hid_t     dset_in = H5I_INVALID_HID;           /* read dataset ID */
+    hid_t     dset_out = H5I_INVALID_HID;          /* write dataset ID */
+    hid_t     type_in = H5I_INVALID_HID;           /* named type ID */
+    hid_t     dcpl_id = H5I_INVALID_HID;           /* dataset creation property list ID */
+    hid_t     space_id = H5I_INVALID_HID;          /* space ID */
+    hid_t     ftype_id = H5I_INVALID_HID;          /* file data type ID */
+    hid_t     mtype_id = H5I_INVALID_HID;          /* memory data type ID */
     size_t    msize;                  /* memory size of memory type */
     hsize_t   nelmts;                 /* number of elements in dataset */
     int       rank;                   /* rank of dataset */
@@ -59,6 +58,7 @@ int do_copy_refobjs(hid_t fidin,
     unsigned int i, j;
     int       k;
     named_dt_t *named_dt_head = NULL; /* Pointer to the stack of named datatypes copied */
+    int       ret_value = 0;
 
     /*-------------------------------------------------------------------------
     * browse
@@ -76,18 +76,18 @@ int do_copy_refobjs(hid_t fidin,
                  *-------------------------------------------------------------------------
                  */
                 if((grp_out = H5Gopen2(fidout, travt->objs[i].name, H5P_DEFAULT)) < 0)
-                    HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Gopen2 failed");
+                    H5TOOLS_GOTO_ERROR((-1), "H5Gopen2 failed");
 
                 if((grp_in = H5Gopen2(fidin, travt->objs[i].name, H5P_DEFAULT)) < 0)
-                    HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Gopen2 failed");
+                    H5TOOLS_GOTO_ERROR((-1), "H5Gopen2 failed");
 
-                if(copy_refs_attr(grp_in, grp_out, options, travt, fidout) < 0)
-                    HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "copy_refs_attr failed");
+                if(copy_refs_attr(grp_in, grp_out, travt, fidout) < 0)
+                    H5TOOLS_GOTO_ERROR((-1), "copy_refs_attr failed");
 
                 if(H5Gclose(grp_out) < 0)
-                    HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Gclose failed");
+                    H5TOOLS_GOTO_ERROR((-1), "H5Gclose failed");
                 if(H5Gclose(grp_in) < 0)
-                    HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Gclose failed");
+                    H5TOOLS_GOTO_ERROR((-1), "H5Gclose failed");
 
                 /*-------------------------------------------------------------------------
                  * check for hard links
@@ -104,26 +104,26 @@ int do_copy_refobjs(hid_t fidin,
              */
             case H5TRAV_TYPE_DATASET:
                 if((dset_in = H5Dopen2(fidin, travt->objs[i].name, H5P_DEFAULT)) < 0)
-                    HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Dopen2 failed");
+                    H5TOOLS_GOTO_ERROR((-1), "H5Dopen2 failed");
                 if((space_id = H5Dget_space(dset_in)) < 0)
-                    HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Dget_space failed");
+                    H5TOOLS_GOTO_ERROR((-1), "H5Dget_space failed");
                 if((ftype_id = H5Dget_type(dset_in)) < 0)
-                    HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Dget_type failed");
+                    H5TOOLS_GOTO_ERROR((-1), "H5Dget_type failed");
                 if((dcpl_id = H5Dget_create_plist(dset_in)) < 0)
-                    HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Dget_create_plist failed");
+                    H5TOOLS_GOTO_ERROR((-1), "H5Dget_create_plist failed");
                 if((rank = H5Sget_simple_extent_ndims(space_id)) < 0)
-                    HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Sget_simple_extent_ndims failed");
+                    H5TOOLS_GOTO_ERROR((-1), "H5Sget_simple_extent_ndims failed");
                 if(H5Sget_simple_extent_dims(space_id, dims, NULL) < 0)
-                    HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Sget_simple_extent_dims failed");
+                    H5TOOLS_GOTO_ERROR((-1), "H5Sget_simple_extent_dims failed");
                 nelmts = 1;
                 for(k = 0; k < rank; k++)
                     nelmts *= dims[k];
 
                 if((mtype_id = H5Tget_native_type(ftype_id, H5T_DIR_DEFAULT)) < 0)
-                    HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Tget_native_type failed");
+                    H5TOOLS_GOTO_ERROR((-1), "H5Tget_native_type failed");
 
                 if((msize = H5Tget_size(mtype_id)) == 0)
-                    HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Tget_size failed");
+                    H5TOOLS_GOTO_ERROR((-1), "H5Tget_size failed");
 
                 /*-------------------------------------------------------------------------
                  * check if the dataset creation property list has filters that
@@ -145,7 +145,7 @@ int do_copy_refobjs(hid_t fidin,
                      *-------------------------------------------------------------------------
                      */
                     if(H5Tequal(mtype_id, H5T_STD_REF_OBJ)) {
-                        hid_t            refobj_id = -1;
+                        hid_t            refobj_id = H5I_INVALID_HID;
                         hobj_ref_t       *refbuf = NULL; /* buffer for object references */
                         hobj_ref_t       *buf = NULL;
                         const char*      refname;
@@ -158,16 +158,16 @@ int do_copy_refobjs(hid_t fidin,
                         if(nelmts) {
                             buf = (hobj_ref_t *)HDmalloc((unsigned)(nelmts * msize));
                             if(buf==NULL) {
-                                printf("cannot read into memory\n" );
-                                HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "HDmalloc failed");
+                                HDprintf("cannot read into memory\n" );
+                                H5TOOLS_GOTO_ERROR((-1), "HDmalloc failed");
                             } /* end if */
                             if(H5Dread(dset_in, mtype_id, H5S_ALL, H5S_ALL, H5P_DEFAULT, buf) < 0)
-                                HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Dread failed");
+                                H5TOOLS_GOTO_ERROR((-1), "H5Dread failed");
 
                             refbuf = (hobj_ref_t*) HDcalloc((unsigned)nelmts, msize);
                             if(refbuf == NULL){
-                                printf("cannot allocate memory\n" );
-                                HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "HDcalloc failed");
+                                HDprintf("cannot allocate memory\n" );
+                                H5TOOLS_GOTO_ERROR((-1), "HDcalloc failed");
                             } /* end if */
                             for(u = 0; u < nelmts; u++) {
                                 H5E_BEGIN_TRY {
@@ -181,16 +181,16 @@ int do_copy_refobjs(hid_t fidin,
                                 if((refname = MapIdToName(refobj_id, travt)) != NULL) {
                                     /* create the reference, -1 parameter for objects */
                                     if(H5Rcreate(&refbuf[u], fidout, refname, H5R_OBJECT, (hid_t)-1) < 0)
-                                        HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Rcreate failed");
+                                        H5TOOLS_GOTO_ERROR((-1), "H5Rcreate failed");
                                     if(options->verbose) {
-                                        printf(FORMAT_OBJ,"dset",travt->objs[i].name );
-                                        printf("object <%s> object reference created to <%s>\n",
+                                        HDprintf(FORMAT_OBJ,"dset",travt->objs[i].name );
+                                        HDprintf("object <%s> object reference created to <%s>\n",
                                             travt->objs[i].name,
                                             refname);
                                     }
                                 } /*refname*/
                                 if (H5Oclose(refobj_id) < 0)
-                                    H5TOOLS_INFO(H5E_tools_min_id_g, "H5Oclose refob failed");
+                                    H5TOOLS_ERROR((-1), "H5Oclose refob failed");
                             } /* u */
                         } /*nelmts*/
 
@@ -199,10 +199,10 @@ int do_copy_refobjs(hid_t fidin,
                          *-------------------------------------------------------------------------
                          */
                         if((dset_out = H5Dcreate2(fidout, travt->objs[i].name, mtype_id, space_id, H5P_DEFAULT, dcpl_id, H5P_DEFAULT)) < 0)
-                            HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Dcreate2 failed");
+                            H5TOOLS_GOTO_ERROR((-1), "H5Dcreate2 failed");
                         if(nelmts)
                             if(H5Dwrite(dset_out, mtype_id, H5S_ALL, H5S_ALL, H5P_DEFAULT, refbuf) < 0)
-                                HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Dwrite failed");
+                                H5TOOLS_GOTO_ERROR((-1), "H5Dwrite failed");
 
                         if(buf)
                             HDfree(buf);
@@ -213,7 +213,7 @@ int do_copy_refobjs(hid_t fidin,
                         * copy attrs
                         *----------------------------------------------------*/
                         if(copy_attr(dset_in, dset_out, &named_dt_head, travt, options) < 0)
-                            HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "copy_attr failed");
+                            H5TOOLS_GOTO_ERROR((-1), "copy_attr failed");
                     } /*H5T_STD_REF_OBJ*/
 
                     /*-------------------------------------------------------------------------
@@ -221,7 +221,7 @@ int do_copy_refobjs(hid_t fidin,
                      *-------------------------------------------------------------------------
                      */
                     else if(H5Tequal(mtype_id, H5T_STD_REF_DSETREG)) {
-                        hid_t            refobj_id = -1;
+                        hid_t            refobj_id = H5I_INVALID_HID;
                         hdset_reg_ref_t  *refbuf = NULL; /* input buffer for region references */
                         hdset_reg_ref_t  *buf = NULL;    /* output buffer */
                         const char*      refname;
@@ -234,11 +234,11 @@ int do_copy_refobjs(hid_t fidin,
                         if(nelmts) {
                             buf = (hdset_reg_ref_t *)HDmalloc((unsigned)(nelmts * msize));
                             if(buf == NULL) {
-                                printf("cannot read into memory\n");
-                                HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "HDmalloc failed");
+                                HDprintf("cannot read into memory\n");
+                                H5TOOLS_GOTO_ERROR((-1), "HDmalloc failed");
                             } /* end if */
                             if(H5Dread(dset_in, mtype_id, H5S_ALL, H5S_ALL, H5P_DEFAULT, buf) < 0)
-                                HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Dread failed");
+                                H5TOOLS_GOTO_ERROR((-1), "H5Dread failed");
 
                             /*-------------------------------------------------------------------------
                              * create output
@@ -246,8 +246,8 @@ int do_copy_refobjs(hid_t fidin,
                              */
                             refbuf = (hdset_reg_ref_t *)HDcalloc(sizeof(hdset_reg_ref_t), (size_t)nelmts); /*init to zero */
                             if(refbuf == NULL) {
-                                printf("cannot allocate memory\n");
-                                HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "HDcalloc failed");
+                                HDprintf("cannot allocate memory\n");
+                                H5TOOLS_GOTO_ERROR((-1), "HDcalloc failed");
                             } /* end if */
 
                             for(u = 0; u < nelmts; u++) {
@@ -260,25 +260,25 @@ int do_copy_refobjs(hid_t fidin,
                                  * in the second traversal of the file
                                  */
                                 if((refname = MapIdToName(refobj_id, travt)) != NULL) {
-                                    hid_t region_id = -1;    /* region id of the referenced dataset */
+                                    hid_t region_id = H5I_INVALID_HID;    /* region id of the referenced dataset */
 
                                     if((region_id = H5Rget_region(dset_in, H5R_DATASET_REGION, &buf[u])) < 0)
-                                        HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Rget_region failed");
+                                        H5TOOLS_GOTO_ERROR((-1), "H5Rget_region failed");
 
                                     /* create the reference, we need the space_id */
                                     if(H5Rcreate(&refbuf[u], fidout, refname, H5R_DATASET_REGION, region_id) < 0)
-                                        HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Rcreate failed");
+                                        H5TOOLS_GOTO_ERROR((-1), "H5Rcreate failed");
                                     if(H5Sclose(region_id) < 0)
-                                        HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Sclose failed");
+                                        H5TOOLS_GOTO_ERROR((-1), "H5Sclose failed");
                                     if(options->verbose) {
-                                        printf(FORMAT_OBJ,"dset",travt->objs[i].name );
-                                        printf("object <%s> region reference created to <%s>\n",
+                                        HDprintf(FORMAT_OBJ,"dset",travt->objs[i].name );
+                                        HDprintf("object <%s> region reference created to <%s>\n",
                                             travt->objs[i].name,
                                             refname);
                                     }
                                 } /*refname*/
                                 if (H5Oclose(refobj_id) < 0)
-                                    H5TOOLS_INFO(H5E_tools_min_id_g, "H5Oclose refobj_id failed");
+                                    H5TOOLS_ERROR((-1), "H5Oclose refobj_id failed");
                             } /* u */
                         } /*nelmts*/
 
@@ -287,10 +287,10 @@ int do_copy_refobjs(hid_t fidin,
                          *-------------------------------------------------------------------------
                          */
                         if((dset_out = H5Dcreate2(fidout, travt->objs[i].name, mtype_id, space_id, H5P_DEFAULT, dcpl_id, H5P_DEFAULT)) < 0)
-                            HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Dcreate2 failed");
+                            H5TOOLS_GOTO_ERROR((-1), "H5Dcreate2 failed");
                         if(nelmts)
                             if(H5Dwrite(dset_out, mtype_id, H5S_ALL, H5S_ALL, H5P_DEFAULT, refbuf) < 0)
-                                HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Dwrite failed");
+                                H5TOOLS_GOTO_ERROR((-1), "H5Dwrite failed");
 
                         if(buf)
                             HDfree(buf);
@@ -301,7 +301,7 @@ int do_copy_refobjs(hid_t fidin,
                         * copy attrs
                         *----------------------------------------------------*/
                         if(copy_attr(dset_in, dset_out, &named_dt_head, travt, options) < 0)
-                            HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "copy_attr failed");
+                            H5TOOLS_GOTO_ERROR((-1), "copy_attr failed");
                     } /* H5T_STD_REF_DSETREG */
                     /*-------------------------------------------------------------------------
                      * not references, open previously created object in 1st traversal
@@ -309,15 +309,15 @@ int do_copy_refobjs(hid_t fidin,
                      */
                     else {
                         if((dset_out = H5Dopen2(fidout, travt->objs[i].name, H5P_DEFAULT)) < 0)
-                            HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Dopen2 failed");
+                            H5TOOLS_GOTO_ERROR((-1), "H5Dopen2 failed");
                     } /* end else */
 
                     /*-------------------------------------------------------------------------
                      * copy referenced objects in attributes
                      *-------------------------------------------------------------------------
                      */
-                    if(copy_refs_attr(dset_in, dset_out, options, travt, fidout) < 0)
-                        HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "copy_refs_attr failed");
+                    if(copy_refs_attr(dset_in, dset_out, travt, fidout) < 0)
+                        H5TOOLS_GOTO_ERROR((-1), "copy_refs_attr failed");
 
                     /*-------------------------------------------------------------------------
                      * check for hard links
@@ -328,7 +328,7 @@ int do_copy_refobjs(hid_t fidin,
                             H5Lcreate_hard(fidout, travt->objs[i].name, H5L_SAME_LOC, travt->objs[i].links[j].new_name, H5P_DEFAULT, H5P_DEFAULT);
 
                     if(H5Dclose(dset_out) < 0)
-                        HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Dclose failed");
+                        H5TOOLS_GOTO_ERROR((-1), "H5Dclose failed");
                 } /*can_read*/
 
                 /*-------------------------------------------------------------------------
@@ -336,15 +336,15 @@ int do_copy_refobjs(hid_t fidin,
                  *-------------------------------------------------------------------------
                  */
                 if(H5Tclose(ftype_id) < 0)
-                    HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Tclose failed");
+                    H5TOOLS_GOTO_ERROR((-1), "H5Tclose failed");
                 if(H5Tclose(mtype_id) < 0)
-                    HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Tclose failed");
+                    H5TOOLS_GOTO_ERROR((-1), "H5Tclose failed");
                 if(H5Pclose(dcpl_id) < 0)
-                    HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Pclose failed");
+                    H5TOOLS_GOTO_ERROR((-1), "H5Pclose failed");
                 if(H5Sclose(space_id) < 0)
-                    HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Sclose failed");
+                    H5TOOLS_GOTO_ERROR((-1), "H5Sclose failed");
                 if(H5Dclose(dset_in) < 0)
-                    HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Dclose failed");
+                    H5TOOLS_GOTO_ERROR((-1), "H5Dclose failed");
                 break;
 
             /*-------------------------------------------------------------------------
@@ -353,9 +353,9 @@ int do_copy_refobjs(hid_t fidin,
              */
             case H5TRAV_TYPE_NAMED_DATATYPE:
                 if((type_in = H5Topen2(fidin, travt->objs[i].name, H5P_DEFAULT)) < 0)
-                    HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Topen2 failed");
+                    H5TOOLS_GOTO_ERROR((-1), "H5Topen2 failed");
                 if(H5Tclose(type_in) < 0)
-                    HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Tclose failed");
+                    H5TOOLS_GOTO_ERROR((-1), "H5Tclose failed");
                 break;
 
             /*-------------------------------------------------------------------------
@@ -368,7 +368,8 @@ int do_copy_refobjs(hid_t fidin,
 
             case H5TRAV_TYPE_UNKNOWN:
             case H5TRAV_TYPE_UDLINK:
-                HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5TRAV invalid type");
+                H5TOOLS_GOTO_ERROR((-1), "H5TRAV invalid type");
+                break;
 
             default:
                 break;
@@ -380,7 +381,7 @@ int do_copy_refobjs(hid_t fidin,
      * in copy_attr(), so need to free.
      */
     if (named_datatype_free(&named_dt_head, 0) < 0)
-        H5TOOLS_INFO(H5E_tools_min_id_g, "named_datatype_free failed");
+        H5TOOLS_ERROR((-1), "named_datatype_free failed");
 
     return ret_value;
 
@@ -426,21 +427,19 @@ done:
 
 static int copy_refs_attr(hid_t loc_in,
                           hid_t loc_out,
-                          pack_opt_t *options,
                           trav_table_t *travt,
                           hid_t fidout)         /* for saving references */
 {
-    int         ret_value = 0;     /*no need to LEAVE() on ERROR: HERR_INIT(int, SUCCEED) */
-    hid_t       attr_id = -1;      /* attr ID */
-    hid_t       attr_out = -1;     /* attr ID */
-    hid_t       space_id = -1;     /* space ID */
-    hid_t       ftype_id = -1;     /* file data type ID */
-    hid_t       mtype_id = -1;     /* memory data type ID */
+    hid_t       attr_id = H5I_INVALID_HID;      /* attr ID */
+    hid_t       attr_out = H5I_INVALID_HID;     /* attr ID */
+    hid_t       space_id = H5I_INVALID_HID;     /* space ID */
+    hid_t       ftype_id = H5I_INVALID_HID;     /* file data type ID */
+    hid_t       mtype_id = H5I_INVALID_HID;     /* memory data type ID */
     size_t      msize;             /* memory size of type */
     hsize_t     nelmts;            /* number of elements in dataset */
     hsize_t     dims[H5S_MAX_RANK];/* dimensions of dataset */
     char        name[255];
-    H5O_info_t  oinfo;             /* Object info */
+    H5O_info2_t oinfo;             /* Object info */
     unsigned    u, i, j;
     int         rank;
     H5T_class_t type_class = -1;
@@ -450,33 +449,32 @@ static int copy_refs_attr(hid_t loc_in,
                 is_ref_comp = 0;
     void       *refbuf = NULL;
     void       *buf = NULL;
-    const char *refname = NULL;
     unsigned   *ref_comp_index = NULL;
     size_t     *ref_comp_size = NULL;
     int         ref_comp_field_n = 0;
+    int         ret_value = 0;
 
-
-    if(H5Oget_info2(loc_in, &oinfo, H5O_INFO_NUM_ATTRS) < 0)
-        HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Oget_info failed");
+    if(H5Oget_info3(loc_in, &oinfo, H5O_INFO_NUM_ATTRS) < 0)
+        H5TOOLS_GOTO_ERROR((-1), "H5Oget_info failed");
 
     for(u = 0; u < (unsigned)oinfo.num_attrs; u++) {
         is_ref = is_ref_vlen = is_ref_array = is_ref_comp = 0;
 
         /* open attribute */
         if((attr_id = H5Aopen_by_idx(loc_in, ".", H5_INDEX_CRT_ORDER, H5_ITER_INC, (hsize_t)u, H5P_DEFAULT, H5P_DEFAULT)) < 0)
-            HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Aopen_by_idx failed");
+            H5TOOLS_GOTO_ERROR((-1), "H5Aopen_by_idx failed");
 
         /* get the file datatype  */
         if((ftype_id = H5Aget_type(attr_id)) < 0)
-            HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Aget_type failed");
+            H5TOOLS_GOTO_ERROR((-1), "H5Aget_type failed");
 
         type_class = H5Tget_class(ftype_id);
 
         if((mtype_id = H5Tget_native_type(ftype_id, H5T_DIR_DEFAULT)) < 0)
-            HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Tget_native_type failed");
+            H5TOOLS_GOTO_ERROR((-1), "H5Tget_native_type failed");
 
         if((msize = H5Tget_size(mtype_id)) == 0)
-            HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Tget_size failed");
+            H5TOOLS_GOTO_ERROR((-1), "H5Tget_size failed");
 
         is_ref = (type_class == H5T_REFERENCE);
 
@@ -486,7 +484,7 @@ static int copy_refs_attr(hid_t loc_in,
             is_ref_vlen = (H5Tget_class(base_type) == H5T_REFERENCE);
             msize = H5Tget_size(base_type);
             if (H5Tclose(base_type) < 0)
-                H5TOOLS_INFO(H5E_tools_min_id_g, "H5Tclose base_type failed");
+                H5TOOLS_ERROR((-1), "H5Tclose base_type failed");
         }
         else if(type_class == H5T_ARRAY ) {
             hid_t base_type = H5Tget_super(ftype_id);
@@ -494,13 +492,13 @@ static int copy_refs_attr(hid_t loc_in,
             is_ref_array = (H5Tget_class(base_type) == H5T_REFERENCE);
             msize = H5Tget_size(base_type);
             if (H5Tclose(base_type) < 0)
-                H5TOOLS_INFO(H5E_tools_min_id_g, "H5Tclose base_type failed");
+                H5TOOLS_GOTO_ERROR((-1), "H5Tclose base_type failed");
         }
         else if(type_class == H5T_COMPOUND) {
             int nmembers = H5Tget_nmembers(ftype_id) ;
 
             if (nmembers < 1)
-                HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Tget_nmembers failed");
+                H5TOOLS_GOTO_ERROR((-1), "H5Tget_nmembers failed");
 
             ref_comp_index = (unsigned *)HDmalloc((size_t)nmembers*sizeof(unsigned));
             ref_comp_size = (size_t *)HDmalloc((size_t)nmembers*sizeof(ref_comp_size));
@@ -515,7 +513,7 @@ static int copy_refs_attr(hid_t loc_in,
                     ref_comp_field_n++;
                 }
                 if (H5Tclose(mtid) < 0)
-                    H5TOOLS_INFO(H5E_tools_min_id_g, "H5Tclose mtid failed");
+                    H5TOOLS_ERROR((-1), "H5Tclose mtid failed");
             }
 
             /* if compound don't contain reference type member, free the above
@@ -532,31 +530,38 @@ static int copy_refs_attr(hid_t loc_in,
                     ref_comp_size = NULL;
                 }
             }
+            /* This line below needs to be moved in this loop instead of inserting outside. Otherwise,
+               ref_comp_field_n may be >0 for the next attribute, which may not be
+               the reference type and will be accidently treated as the reference type.
+               It will then cause the H5Acreate2 failed since that attribute is already created.
+               KY 2020-02-10
+            */
+            is_ref_comp = (ref_comp_field_n > 0);
+
         }
 
-        is_ref_comp = (ref_comp_field_n > 0);
 
         if (!(is_ref || is_ref_vlen || is_ref_array || is_ref_comp)) {
             if (H5Tclose(mtype_id) < 0)
-                H5TOOLS_INFO(H5E_tools_min_id_g, "H5Tclose mtype_id failed");
+                H5TOOLS_ERROR((-1), "H5Tclose mtype_id failed");
             if (H5Tclose(ftype_id) < 0)
-                H5TOOLS_INFO(H5E_tools_min_id_g, "H5Tclose ftype_id failed");
+                H5TOOLS_ERROR((-1), "H5Tclose ftype_id failed");
             if (H5Aclose(attr_id) < 0)
-                H5TOOLS_INFO(H5E_tools_min_id_g, "H5Aclose attr_id failed");
+                H5TOOLS_ERROR((-1), "H5Aclose attr_id failed");
             continue;
         }
 
         /* get name */
         if(H5Aget_name(attr_id, 255, name) < 0)
-            HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Aget_name failed");
+            H5TOOLS_GOTO_ERROR((-1), "H5Aget_name failed");
 
         /* get the dataspace handle  */
         if((space_id = H5Aget_space(attr_id)) < 0)
-            HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Aget_space failed");
+            H5TOOLS_GOTO_ERROR((-1), "H5Aget_space failed");
 
         /* get dimensions  */
         if((rank = H5Sget_simple_extent_dims(space_id, dims, NULL)) < 0)
-            HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Sget_simple_extent_dims failed");
+            H5TOOLS_GOTO_ERROR((-1), "H5Sget_simple_extent_dims failed");
 
 
         /*-------------------------------------------------------------------------
@@ -575,7 +580,7 @@ static int copy_refs_attr(hid_t loc_in,
 
             msize = H5Tget_size(base_type);
             if (H5Tclose(base_type) < 0)
-                H5TOOLS_INFO(H5E_tools_min_id_g, "H5Tclose base_type failed");
+                H5TOOLS_ERROR((-1), "H5Tclose base_type failed");
 
             array_rank = (unsigned)H5Tget_array_ndims(mtype_id);
             H5Tget_array_dims2(mtype_id, array_dims);
@@ -585,42 +590,39 @@ static int copy_refs_attr(hid_t loc_in,
         }
 
         if((attr_out = H5Acreate2(loc_out, name, ftype_id, space_id, H5P_DEFAULT, H5P_DEFAULT)) < 0)
-            HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Acreate2 failed");
+            H5TOOLS_GOTO_ERROR((-1), "H5Acreate2 failed");
 
         if (nelmts>0) {
             /* handle object references */
             if((is_ref || is_ref_array) && (H5R_OBJ_REF_BUF_SIZE==msize)) {
                 buf = (hobj_ref_t *)HDmalloc((unsigned)(nelmts * msize));
                 if(buf == NULL) {
-                    printf("cannot read into memory\n");
-                    HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "HDmalloc failed");
+                    HDprintf("cannot read into memory\n");
+                    H5TOOLS_GOTO_ERROR((-1), "HDmalloc failed");
                 } /* end if */
                 if(H5Aread(attr_id, mtype_id, buf) < 0)
-                    HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Aread failed");
+                    H5TOOLS_GOTO_ERROR((-1), "H5Aread failed");
 
                 refbuf = (hobj_ref_t *)HDcalloc((unsigned)nelmts, msize);
                 if(refbuf == NULL) {
-                    printf("cannot allocate memory\n");
-                    HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "HDcalloc failed");
+                    HDprintf("cannot allocate memory\n");
+                    H5TOOLS_GOTO_ERROR((-1), "HDcalloc failed");
                 } /* end if */
 
-                for(i = 0; i < (unsigned)nelmts; i++) {
-                    if (update_ref_value(attr_id, H5R_OBJECT, &((hobj_ref_t *)buf)[i], fidout, &((hobj_ref_t *)refbuf)[i], travt)<0)
+                for(i = 0; i < (unsigned)nelmts; i++)
+                    if(update_ref_value(attr_id, H5R_OBJECT, &((hobj_ref_t *)buf)[i], fidout, &((hobj_ref_t *)refbuf)[i], travt) < 0)
                         continue;
-                    if(options->verbose)
-                        printf("object <%s> reference created to <%s>\n", name, refname);
-                } /* i */
             } /* H5T_STD_REF_OBJ */
             /* handle region references */
             else if((is_ref || is_ref_array) && (H5R_DSET_REG_REF_BUF_SIZE == msize)) {
                 buf = (hdset_reg_ref_t *)HDmalloc((unsigned)(nelmts * msize));
 
                 if(buf == NULL) {
-                    printf( "cannot read into memory\n" );
-                    HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "HDmalloc failed");
+                    HDprintf( "cannot read into memory\n" );
+                    H5TOOLS_GOTO_ERROR((-1), "HDmalloc failed");
                 } /* end if */
                 if(H5Aread(attr_id, mtype_id, buf) < 0)
-                    HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Aread failed");
+                    H5TOOLS_GOTO_ERROR((-1), "H5Aread failed");
 
                 /*-------------------------------------------------------------------------
                  * create output
@@ -628,16 +630,13 @@ static int copy_refs_attr(hid_t loc_in,
                  */
                 refbuf = (hdset_reg_ref_t *)HDcalloc(sizeof(hdset_reg_ref_t), (size_t)nelmts); /*init to zero */
                 if(refbuf == NULL) {
-                    printf( "cannot allocate memory\n" );
-                    HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "HDcalloc failed");
+                    HDprintf( "cannot allocate memory\n" );
+                    H5TOOLS_GOTO_ERROR((-1), "HDcalloc failed");
                 } /* end if */
 
-                for(i = 0; i < (unsigned)nelmts; i++) {
-                    if (update_ref_value(attr_id, H5R_DATASET_REGION, &((hdset_reg_ref_t *)buf)[i], fidout, &((hdset_reg_ref_t *)refbuf)[i], travt)<0)
+                for(i = 0; i < (unsigned)nelmts; i++)
+                    if(update_ref_value(attr_id, H5R_DATASET_REGION, &((hdset_reg_ref_t *)buf)[i], fidout, &((hdset_reg_ref_t *)refbuf)[i], travt) < 0)
                         continue;
-                    if(options->verbose)
-                        printf("object <%s> region reference created to <%s>\n", name, refname);
-                }
             } /* H5T_STD_REF_DSETREG */
             else if (is_ref_vlen) {
                 /* handle VLEN of references */
@@ -646,12 +645,12 @@ static int copy_refs_attr(hid_t loc_in,
                 refbuf = buf; /* reuse the read buffer for write */
 
                 if(buf == NULL) {
-                    printf( "cannot read into memory\n" );
-                    HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "HDmalloc failed");
+                    HDprintf( "cannot read into memory\n" );
+                    H5TOOLS_GOTO_ERROR((-1), "HDmalloc failed");
                 } /* end if */
 
                 if(H5Aread(attr_id, mtype_id, buf) < 0)
-                    HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Aread failed");
+                    H5TOOLS_GOTO_ERROR((-1), "H5Aread failed");
 
                 if (H5R_OBJ_REF_BUF_SIZE==msize) {
                     hobj_ref_t ref_out;
@@ -687,12 +686,12 @@ static int copy_refs_attr(hid_t loc_in,
                 refbuf = buf; /* reuse the read buffer for write */
 
                 if(buf == NULL) {
-                    printf( "cannot read into memory\n" );
-                    HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "HDmalloc failed");
+                    HDprintf( "cannot read into memory\n" );
+                    H5TOOLS_GOTO_ERROR((-1), "HDmalloc failed");
                 } /* end if */
 
                 if(H5Aread(attr_id, mtype_id, buf) < 0)
-                    HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Aread failed");
+                    H5TOOLS_GOTO_ERROR((-1), "H5Aread failed");
 
                 for (i=0; i<(unsigned)nelmts; i++) {
                     for (j=0; j<(unsigned)ref_comp_field_n; j++) {
@@ -700,7 +699,7 @@ static int copy_refs_attr(hid_t loc_in,
                             size_t idx = (i * msize) + H5Tget_member_offset(mtype_id, ref_comp_index[j]);
                             hobj_ref_t ref_out;
 
-                            if (update_ref_value(attr_id, H5R_OBJECT, (hobj_ref_t *)(((char *)buf)+idx), fidout, &ref_out, travt)<0)
+                            if (update_ref_value(attr_id, H5R_OBJECT, (hobj_ref_t *)((void *)(((char *)buf)+idx)), fidout, &ref_out, travt) < 0) /* Extra (void *) cast to quiet "cast to create alignment" warning - 2019/07/05, QAK */
                                 continue;
                             HDmemcpy(((char *)buf)+idx, &ref_out, ref_comp_size[j]);
                         } /* if */
@@ -717,10 +716,10 @@ static int copy_refs_attr(hid_t loc_in,
             } /* else if (is_ref_comp) */
 
             if(H5Awrite(attr_out, mtype_id, refbuf) < 0)
-                HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Awrite failed");
+                H5TOOLS_GOTO_ERROR((-1), "H5Awrite failed");
 
             if (is_ref_vlen && buf)
-                H5Dvlen_reclaim (mtype_id, space_id, H5P_DEFAULT, buf);
+                H5Treclaim (mtype_id, space_id, H5P_DEFAULT, buf);
         } /* if (nelmts) */
 
         if (refbuf == buf)
@@ -747,20 +746,20 @@ static int copy_refs_attr(hid_t loc_in,
         }
 
         if(H5Aclose(attr_out) < 0)
-            HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Aclose failed");
+            H5TOOLS_GOTO_ERROR((-1), "H5Aclose failed");
 
         /*-------------------------------------------------------------------------
         * close
         *-------------------------------------------------------------------------
         */
         if(H5Tclose(ftype_id) < 0)
-            HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Tclose failed");
+            H5TOOLS_GOTO_ERROR((-1), "H5Tclose failed");
         if(H5Tclose(mtype_id) < 0)
-            HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Tclose failed");
+            H5TOOLS_GOTO_ERROR((-1), "H5Tclose failed");
         if(H5Sclose(space_id) < 0)
-            HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Sclose failed");
+            H5TOOLS_GOTO_ERROR((-1), "H5Sclose failed");
         if(H5Aclose(attr_id) < 0)
-            HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Aclose failed");
+            H5TOOLS_GOTO_ERROR((-1), "H5Aclose failed");
     } /* for(u = 0; u < (unsigned)oinfo.num_attrs; u++) */
 
 done:
@@ -804,16 +803,19 @@ MapIdToName(hid_t refobj_id, trav_table_t *travt)
         if(travt->objs[u].type == (h5trav_type_t)H5O_TYPE_DATASET ||
                 travt->objs[u].type == (h5trav_type_t)H5O_TYPE_GROUP ||
                 travt->objs[u].type == (h5trav_type_t)H5O_TYPE_NAMED_DATATYPE) {
-            H5O_info_t   ref_oinfo;     /* Stat for the refobj id */
+            H5O_info2_t ref_oinfo;     /* Stat for the refobj id */
+            int         token_cmp;
 
             /* obtain information to identify the referenced object uniquely */
-            if(H5Oget_info2(refobj_id, &ref_oinfo, H5O_INFO_BASIC) < 0)
+            if(H5Oget_info3(refobj_id, &ref_oinfo, H5O_INFO_BASIC) < 0)
                 goto out;
 
-            if(ref_oinfo.addr == travt->objs[u].objno) {
+            if(H5Otoken_cmp(refobj_id, &ref_oinfo.token, &travt->objs[u].obj_token, &token_cmp) < 0)
+                goto out;
+            if(!token_cmp) {
                 ret = travt->objs[u].name;
                 goto out;
-            } /* end if */
+            }
         }  /* end if */
     } /* u */
 
@@ -830,27 +832,27 @@ out:
 static herr_t update_ref_value(hid_t obj_id, H5R_type_t ref_type, void *ref_in,
         hid_t fid_out, void *ref_out, trav_table_t *travt)
 {
-    int         ret_value = 0;   /*no need to LEAVE() on ERROR: HERR_INIT(int, SUCCEED) */
     const char *ref_obj_name;
-    hid_t       space_id = -1;
-    hid_t       ref_obj_id = -1;
+    hid_t       space_id = H5I_INVALID_HID;
+    hid_t       ref_obj_id = H5I_INVALID_HID;
+    herr_t      ret_value = SUCCEED;
 
     ref_obj_id = H5Rdereference2(obj_id, H5P_DEFAULT, ref_type, ref_in);
     if (ref_obj_id < 0)
-        HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Rdereference2 failed");
+        H5TOOLS_GOTO_ERROR(FAIL, "H5Rdereference2 failed");
 
     ref_obj_name = MapIdToName(ref_obj_id, travt);
     if (ref_obj_name == NULL)
-        HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "MapIdToName failed");
+        H5TOOLS_GOTO_ERROR(FAIL, "MapIdToName failed");
 
     if (ref_type == H5R_DATASET_REGION) {
         space_id = H5Rget_region(obj_id, H5R_DATASET_REGION, ref_in);
         if (space_id < 0)
-            HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Rget_region failed");
+            H5TOOLS_GOTO_ERROR(FAIL, "H5Rget_region failed");
     }
 
     if(H5Rcreate(ref_out, fid_out, ref_obj_name, ref_type, space_id) < 0)
-        HGOTO_ERROR(FAIL, H5E_tools_min_id_g, "H5Rcreate failed");
+        H5TOOLS_GOTO_ERROR(FAIL, "H5Rcreate failed");
 
 done:
     H5E_BEGIN_TRY {
