@@ -12,9 +12,11 @@
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*
- * Purpose: A tool to clear the status_flags field from the file's superblock via -s option.
- *          A tool to remove cache image from the file via -m option.
- *          
+ * Purpose: A tool used to do the following:
+ *      (1) -s, --status:   clear the status_flags field from the file's superblock
+ *      (2) -m, --image:    remove the metadata cache image from the file
+ *      (3) --increment=C:  set the file's EOA to the maximum of (EOA, EOF) + C
+ *      (4) --filesize:     print the file's EOA and EOF
  */
 #include "hdf5.h"
 #include "H5private.h"
@@ -24,18 +26,25 @@
 /* Name of tool */
 #define PROGRAMNAME     "h5clear"
 
-/* Make this private property (defined in H5Fprivate.h) available to h5clear. */
-#define H5F_ACS_CLEAR_STATUS_FLAGS_NAME            "clear_status_flags"
+/* Make these private properties (defined in H5Fprivate.h) available to h5clear. */
+#define H5F_ACS_CLEAR_STATUS_FLAGS_NAME         "clear_status_flags"
+#define H5F_ACS_NULL_FSM_ADDR_NAME              "null_fsm_addr"
+#define H5F_ACS_SKIP_EOF_CHECK_NAME             "skip_eof_check"
+
+/* Default increment is 1 megabytes for the --increment option */
+#define DEFAULT_INCREMENT   1024*1024
 
 static char *fname_g = NULL;
 static hbool_t clear_status_flags = FALSE;
 static hbool_t remove_cache_image = FALSE;
+static hbool_t print_filesize = FALSE;
+static hbool_t increment_eoa_eof = FALSE;
+static hsize_t increment = DEFAULT_INCREMENT;
 
 /*
- * Command-line options: The user can specify short or long-named
- * parameters.
+ * Command-line options: only publicize long options
  */
-static const char *s_opts = "hVsm";
+static const char *s_opts = "hVsmzi*";
 static struct long_options l_opts[] = {
         { "help", no_arg, 'h' },
         { "hel", no_arg, 'h'},
@@ -54,11 +63,26 @@ static struct long_options l_opts[] = {
         { "imag", no_arg, 'm' },
         { "ima", no_arg, 'm' },
         { "im", no_arg, 'm' },
+        { "filesize", no_arg, 'z' },
+        { "filesiz", no_arg, 'z' },
+        { "filesi", no_arg, 'z' },
+        { "files", no_arg, 'z' },
+        { "file", no_arg, 'z' },
+        { "fil", no_arg, 'z' },
+        { "fi", no_arg, 'z' },
+        { "increment", optional_arg, 'i' },
+        { "incremen", optional_arg, 'i' },
+        { "increme", optional_arg, 'i' },
+        { "increm", optional_arg, 'i' },
+        { "incre", optional_arg, 'i' },
+        { "incr", optional_arg, 'i' },
+        { "inc", optional_arg, 'i' },
+        { "in", optional_arg, 'i' },
         { NULL, 0, '\0' }
 };
 
 
-
+
 /*-------------------------------------------------------------------------
  * Function:    usage
  *
@@ -76,6 +100,9 @@ static void usage(const char *prog)
     HDfprintf(stdout, "   -V, --version             Print version number and exit\n");
     HDfprintf(stdout, "   -s, --status              Clear the status_flags field in the file's superblock\n");
     HDfprintf(stdout, "   -m, --image               Remove the metadata cache image from the file\n");
+    HDfprintf(stdout, "   --filesize                Print the file's EOA and EOF\n");
+    HDfprintf(stdout, "   --increment=C             Set the file's EOA to the maximum of (EOA, EOF) + C for the file <file_name>\n");
+    HDfprintf(stdout, "                             C is >= 0; C is optional and will default to 1M when not set");
     HDfprintf(stdout, "\n");
     HDfprintf(stdout, "Examples of use:\n");
     HDfprintf(stdout, "\n");
@@ -84,9 +111,15 @@ static void usage(const char *prog)
     HDfprintf(stdout, "\n");
     HDfprintf(stdout, "h5clear -m file_name\n");
     HDfprintf(stdout, "  Remove the metadata cache image from the HDF5 file <file_name>.\n");
+    HDfprintf(stdout, "\n");
+    HDfprintf(stdout, "h5clear --increment file_name\n");
+    HDfprintf(stdout, "  Set the EOA to the maximum of (EOA, EOF) + 1M for the file <file_name>.\n");
+    HDfprintf(stdout, "\n");
+    HDfprintf(stdout, "h5clear --increment=512 file_name\n");
+    HDfprintf(stdout, "  Set the EOA to the maximum of (EOA, EOF) + 512 for the file <file_name>.\n");
 } /* usage() */
 
-
+
 /*-------------------------------------------------------------------------
  * Function: parse_command_line
  *
@@ -131,6 +164,21 @@ parse_command_line(int argc, const char **argv)
                 remove_cache_image = TRUE;
                 break;
 
+            case 'z':
+                print_filesize = TRUE;
+                break;
+
+            case 'i':
+                increment_eoa_eof = TRUE;
+                if(opt_arg != NULL) {
+                    if (HDatoi(opt_arg) < 0) {
+                        usage(h5tools_getprogname());
+                        goto done;
+                    }
+                    increment = (hsize_t)HDatoi(opt_arg);
+                }
+                break;
+
             default:
                 usage(h5tools_getprogname());
                 h5tools_setstatus(EXIT_FAILURE);
@@ -172,12 +220,28 @@ leave(int ret)
 } /* leave() */
 
 
-
+
 /*-------------------------------------------------------------------------
  * Function:    main
  *
- * Purpose:     To clear the status_flags field in the file's superblock (-s option).
- *              To remove the cache image from the file (-m option).
+ * Purpose: The options are:
+ *          (1) -s, --status:   clear the status_flags field from the file's superblock
+ *          (2) -m, --image:    remove the metadata cache image from the file
+ *          (3) --increment=C:  set the file's EOA to the maximum of (EOA, EOF) + C
+ *          (4) --filesize:     print the file's EOA and EOF
+ *
+ *          The three options: -s, -m, and --increment will modify the file
+ *          so the file is opened with write access.
+ *          The --filesize option just prints the EOA and EOF, so the file
+ *          is opened with read access.
+ *
+ *          The -s option will activate the private property:
+ *              --H5F_ACS_CLEAR_STATUS_FLAGS_NAME
+ *          The --increment option will active these two private properties:
+ *              --H5F_ACS_NULL_FSM_ADDR_NAME
+ *              --H5F_ACS_SKIP_EOF_CHECK_NAME
+ *          The --filesize will activate the private property:
+ *              --H5F_ACS_SKIP_EOF_CHECK_NAME
  *
  * Return:      Success: 0
  *              Failure: 1
@@ -187,11 +251,12 @@ leave(int ret)
 int
 main (int argc, const char *argv[])
 {
-    char *fname = NULL;    /* File name */
-    hid_t fapl = -1;       /* File access property list */
-    hid_t fid = -1;        /* File ID */
+    char *fname = NULL;             /* File name */
+    hid_t fapl = H5I_INVALID_HID;                /* File access property list */
+    hid_t fid = H5I_INVALID_HID;                 /* File ID */
     haddr_t image_addr;
     hsize_t image_len;
+    unsigned flags = H5F_ACC_RDWR;    /* file access flags */
 
     h5tools_setprogname(PROGRAMNAME);
     h5tools_setstatus(EXIT_SUCCESS);
@@ -209,12 +274,22 @@ main (int argc, const char *argv[])
     if(fname_g == NULL)
         goto done;
 
-    if(!clear_status_flags && !remove_cache_image) {
+    /* Print usage/exit if not using at least one of the options */
+    if(!clear_status_flags && !remove_cache_image &&
+       !increment_eoa_eof && !print_filesize) {
         usage(h5tools_getprogname());
         h5tools_setstatus(EXIT_FAILURE);
         goto done;
     }
 
+    /* Cannot combine the --filesize option with other options */
+    if(print_filesize &&
+       (clear_status_flags || remove_cache_image || increment_eoa_eof)) {
+        error_msg("Cannot combine --filesize with other options\n");
+        h5tools_setstatus(EXIT_FAILURE);
+        goto done;
+    }
+
     /* Duplicate the file name */
     fname = HDstrdup(fname_g);
 
@@ -226,9 +301,9 @@ main (int argc, const char *argv[])
      }
 
     /* -s option */
-    if(clear_status_flags) { 
+    if(clear_status_flags) {
         /* Set to clear the status_flags in the file's superblock */
-        /* This is a private property used by h5clear only */
+        /* Activate this private property */
         if(H5Pset(fapl, H5F_ACS_CLEAR_STATUS_FLAGS_NAME, &clear_status_flags) < 0) {
             error_msg("H5Pset\n");
             h5tools_setstatus(EXIT_FAILURE);
@@ -236,14 +311,66 @@ main (int argc, const char *argv[])
         }
     }
 
-    if((fid = h5tools_fopen(fname, H5F_ACC_RDWR, fapl, NULL, NULL, (size_t)0)) < 0) {
+    /* --increment option */
+    if(increment_eoa_eof) {
+        /* Activate this private property */
+        if(H5Pset(fapl, H5F_ACS_SKIP_EOF_CHECK_NAME, &increment_eoa_eof) < 0) {
+            error_msg("H5Pset\n");
+            h5tools_setstatus(EXIT_FAILURE);
+            goto done;
+        }
+        /* Activate this private property */
+        if(H5Pset(fapl, H5F_ACS_NULL_FSM_ADDR_NAME, &increment_eoa_eof) < 0) {
+            error_msg("H5Pset\n");
+            h5tools_setstatus(EXIT_FAILURE);
+            goto done;
+        }
+    }
+
+    /* --filesize option; open the file read-only */
+    if(print_filesize) {
+        /* Activate this private property */
+        if(H5Pset(fapl, H5F_ACS_SKIP_EOF_CHECK_NAME, &print_filesize) < 0) {
+            error_msg("H5Pset\n");
+            h5tools_setstatus(EXIT_FAILURE);
+            goto done;
+        }
+        flags = H5F_ACC_RDONLY;
+    }
+
+    /* Open the file */
+    if((fid = h5tools_fopen(fname, flags, fapl, NULL, NULL, (size_t)0)) < 0) {
         error_msg("h5tools_fopen\n");
         h5tools_setstatus(EXIT_FAILURE);
         goto done;
     }
 
+    /* --filesize option */
+    if(print_filesize) {
+        h5_stat_t st;   /* Stat info call */
+        haddr_t eoa;    /* The EOA value */
+
+        /* Get the file's EOA and EOF */
+        if(H5Fget_eoa(fid, &eoa) < 0 || HDstat(fname, &st) < 0) {
+            error_msg("H5Fget_eoa or HDstat\n");
+            h5tools_setstatus(EXIT_FAILURE);
+            goto done;
+        }
+        HDfprintf(stdout, "EOA is %a; EOF is %a \n", eoa, st.st_size);
+    }
+
+    /* --increment option */
+    if(increment_eoa_eof) {
+        /* Set the file's EOA to the maximum of (EOA, EOF) + increment */
+        if(H5Fincrement_filesize(fid, increment) < 0) {
+            error_msg("H5Fset_eoa\n");
+            h5tools_setstatus(EXIT_FAILURE);
+            goto done;
+        }
+    }
+
     /* -m option */
-    if(remove_cache_image) { 
+    if(remove_cache_image) {
         if(H5Fget_mdc_image_info(fid, &image_addr, &image_len) < 0) {
             error_msg("H5Fget_mdc_image_info\n");
             h5tools_setstatus(EXIT_FAILURE);
@@ -251,9 +378,11 @@ main (int argc, const char *argv[])
         }
         if(image_addr == HADDR_UNDEF && image_len == 0)
             warn_msg("No cache image in the file\n");
-    } 
+    }
+
 
     h5tools_setstatus(EXIT_SUCCESS);
+
 done:
     if(fname)
         HDfree(fname);
